<?php

/**
 * agenda actions.
 *
 * @package    anbnws
 * @subpackage agenda
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 443 2010-09-29 12:39:29Z hlecorche $
 */
class agendaActions extends sfActions
{
	/*
	 * *************************************
	 *
	 * Actions
	 *
	 * *************************************
	 */


	//Template qui affiche la liste des lieux
	public function executeIndex(sfWebRequest $request)
	{
		$this->prepareInfosAfficheListe($request);
	}

	//Action qui affiche le formulaire d'ajout d'un nouveau evenemement
	public function executeNew(sfWebRequest $request)
	{
		$this->form = new EvenementForm();
	}

	//Action qui creer un nouveau lieu
	public function executeCreate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$this->form = new EvenementForm();
		$this->processForm($request, $this->form);
		$this->setTemplate('new');
	}


	//Action qui affiche le formulaire d'edition d'un evenement
	public function executeEdit(sfWebRequest $request)
	{
		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		$this->form = new EvenementForm($evenement);
	}

	//Action qui fait la mise à jour d'un evenement
	public function executeUpdate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		$this->form = new EvenementForm($evenement);
		$this->processForm($request, $this->form);
		$this->setTemplate('edit');
	}
	
	//Action qui affiche le formulaire de creation d'une image tronquée
	public function executeEditImageTronquee(sfWebRequest $request)
	{
		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		
		$this->forward404Unless($image_id = $request->getParameter('image'), sprintf('Image non precisee'));

		//On ne peut que éditer les images 1, 2
		$images_autorisees = array(1, 2);
		$this->forward404Unless(in_array($image_id, $images_autorisees));
		$this->image_id = $image_id;
		
		$this->form = new EvenementImageTruncateForm($evenement, array('num_image' => $image_id));
	}
	
	
	//Action qui traite le formulaire de creation d'une image tronquée
	public function executeUpdateImageTronquee(sfWebRequest $request)
	{
		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		
		$this->forward404Unless($image_id = $request->getParameter('image'), sprintf('Image non precisee'));

		//On ne peut que éditer les images 1, 2
		$images_autorisees = array(1, 2);
		$this->forward404Unless(in_array($image_id, $images_autorisees));
		$this->image_id = $image_id;
		
		$this->form = new EvenementImageTruncateForm($evenement, array('num_image' => $image_id));
		$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
		if ($this->form->isValid())
		{
			$evenement = $this->form->processForm();
			$this->redirect('agenda/edit?id='.$evenement->getId());
		}
		$this->setTemplate('editImageTronquee');
	}
	
	//Action qui copie un evenement
	public function executeCopy(sfWebRequest $request)
	{
		$this->forward404Unless($event = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		
		//Copie de l'evenement (false pour ne pas copier les relations)
		$new_event = $event->copy(false);
		
		//Modifie auteur
		$membre_id = MembreTable::getMembreIdConnecte();
		$new_event->setAuteurMembreId($membre_id);
		
		//Rend inactif
		$new_event->setActive(0);
		
		//Rend inactif sur la page d'accueil
		$new_event->setActiveIndex(0);
		
		//Change la date de création
		$new_event->setCreatedAt(date('Y-m-d H:i:s', time()));
		
		//On sauvegarde
		$new_event->save();
		
		//On copie les images (en changeant le nom de images)
		$dossier_images = sfConfig::get('app_uploads_images_agenda');
		$images = array('image_1', 'image_1_truncate', 'image_2', 'image_2_truncate');
		foreach($images as $image_name)
		{
			$image_source = $event->get($image_name);
			if(!empty($image_source))
			{
				//Change le nom
				preg_match('/(\..+?)$/', $image_source, $matches);
				if(!empty($matches[1]))
				{
					$extension = $matches[1];
				}
				else
				{
					$extension = '.jpeg';
				}
				$new_image = 'event_'.$new_event->getId().'_'.$image_name.$extension;
				$new_event->set($image_name, $new_image);
				
				//Copie
				copy($dossier_images.'/'.$image_source, $dossier_images.'/'.$new_image);
			}
		}
		
		//On sauvegarde
		$new_event->save();
		
		//On redirige vers le formulaire d'édition avec un message de confirmation
		$this->getUser()->setFlash('bo_agenda_form_ok', 'Evénement copié et sauvegardé');
		$this->redirect('agenda/edit?id='.$new_event->getId());
	}



	/*
	 * *************************************
	 *
	 * Methodes AJAX
	 *
	 * *************************************
	 */

	//Action ajax qui affiche la pagination des evenements
	public function executeAjaxShowList(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}

	//Action ajax qui affiche affiche un evenement sur la page d'accueil
	public function executeAjaxActiveIndex(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		$user = $this->getUser();

		//On ne peut pas activer sur la page principale un evenement qui n'est pas actif
		$this->forward404Unless($evenement->getActive(), 'Evenement non actif');

		$evenement->setActiveIndex(1);
		$evenement->save();
		$user->setFlash('bo_agenda_message_ok', 'Evenement activé sur la page principale du site', false);

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}

	//Action ajax qui desactive un evenement sur la page d'accueil
	public function executeAjaxInactiveIndex(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		$user = $this->getUser();

		$evenement->setActiveIndex(0);
		$evenement->save();
		$user->setFlash('bo_agenda_message_ok', 'Evenement désactivé sur la page principale du site', false);

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}


	//Action ajax qui supprime un evenement
	public function executeAjaxDelete(sfWebRequest $request)
	{
		/*
		 * ATTENTION !!!!!!!!!!!!!!!!!!
		 * Si modification de cette methode, modifier
		 * celle de lieuxActions
		 */
		
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		$user = $this->getUser();

		if(count($evenement->getReportages()) > 0)
		{
			//Des reportages sont associes à ce lieu, on ne peut pas supprimer
			$user->setFlash('bo_agenda_message_error', 'Impossible de supprimer cet événement: Des reportages sont associés à cet événement.', false);
		}

		else
		{
			//On supprime les inscriptions associees à cet évenement
			$q = Doctrine::getTable('EvenementInscription')->createQuery('i')
			->delete()->where('i.evenement_id = ?', $evenement->getId())
			->execute();
			
			//On supprime les images de l'événement
			$dossier = sfConfig::get('app_uploads_images_agenda');
			$images = array($evenement->getImage_1(), $evenement->getImage_2(), $evenement->getImage_1_Truncate(), $evenement->getImage_2_Truncate());
			foreach($images as $image)
			{
				if(!empty($image) && file_exists($dossier.'/'.$image))
				{
					unlink($dossier.'/'.$image);
				}
			}
			
			//On vide le cache des images de l'évenement
			$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_agenda').'/'.$evenement->getId();
			Util::deleteFolder($folder_cache);
			
			//On supprime l'évenement
			$evenement->delete();
			$user->setFlash('bo_agenda_message_ok', 'Evenement supprimé', false);
		}

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
		
		/*
		 * ATTENTION !!!!!!!!!!!!!!!!!!
		 * Si modification de cette methode, modifier
		 * celle de lieuxActions
		 */
	}



	//Action ajax qui supprime une image d'un lieu
	public function executeAjaxDeleteImage(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		$this->forward404Unless($image_id = $request->getParameter('image'), sprintf('Image non precisee'));

		//On ne peut supprimer que les images 1, 2
		$images_autorisees = array(1, 2);
		$this->forward404Unless(in_array($image_id, $images_autorisees));

		//Si le fichier est présent sur le serveur, on le supprime
		$dossier = sfConfig::get('app_uploads_images_agenda');
		$file_name = $evenement->get('image_'.$image_id);
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//Si fichier tronqué présent, on le supprime
		$file_name = $evenement->get('image_'.$image_id.'_truncate');
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On vide le cache des images de l'évenement
		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_agenda').'/'.$evenement->getId();
		Util::deleteFolder($folder_cache);

		//On supprime l'image de la base de données
		$evenement->set('image_'.$image_id, null);
		$evenement->set('image_'.$image_id.'_truncate', null);
		$evenement->save();

		//On envoie un message de confirmation
		return $this->renderText('<span style="color: red;">Image supprimée</span>');
	}
	
	
	//Action ajax qui supprime une image tronquee d'un lieu
	public function executeAjaxDeleteImageTronquee(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($evenement = Doctrine::getTable('Evenement')->find($request->getParameter('id')), sprintf('Object Evenement does not exist (%s).', $request->getParameter('id')));
		$this->forward404Unless($image_id = $request->getParameter('image'), sprintf('Image non precisee'));

		//On ne peut supprimer que les images 1, 2
		$images_autorisees = array(1, 2);
		$this->forward404Unless(in_array($image_id, $images_autorisees));

		//Si le fichier est présent sur le serveur, on le supprime
		$dossier = sfConfig::get('app_uploads_images_agenda');
		$file_name = $evenement->get('image_'.$image_id.'_truncate');
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On vide le cache des images de l'évenement
		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_agenda').'/'.$evenement->getId();
		Util::deleteFolder($folder_cache);

		//On supprime l'image de la base de données
		$evenement->set('image_'.$image_id.'_truncate', null);
		$evenement->save();

		//On envoie un message de confirmation
		return $this->renderText('<span style="color: red;">Image tronquée supprimée</span>');
	}
	
	
	
	//Action Ajax qui envoi un SELECT contenant la liste des lieux
	//associes à un type_id passe dans le request
	public function executeAjaxListeLieux(sfWebRequest $request)
	{
		//Vérification ajax
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On recupere le type_id et on le change dans le formulaire
		$type_id = $request->getParameter('type_id');
		
		$form = new EvenementForm();
		$form->setSelectTypeId($type_id);
		
		//On envoie le nouveau widget
		$this->setLayout(false);
		echo $form['lieu_id']->render();
		
		exit();
	}



	/*
	 * *************************************
	 *
	 * Methodes privees
	 *
	 * *************************************
	 */


	/**
	 * Methode qui prepare les informations (pour envoyer au template)
	 * pour l'affichage de la liste des lieux
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	protected function prepareInfosAfficheListe(sfWebRequest $request)
	{
		$page = $request->getParameter('page', 1);

		$this->liste_evenements_non_actifs = array();
		if($page == 1)
		{
			//On est à la première page, on affiche le tableau des lieux
			//non actifs
			$this->liste_evenements_non_actifs  = Doctrine::getTable('Evenement')->getEvenementsNonActifsBo();
		}

		//On cree le pager de résultats
		$this->pager = EvenementTable::generatePagerBo();
		$this->pager->setPage($page);
		$this->pager->init();
	}


	//Traitement du formulaire
	protected function processForm(sfWebRequest $request, EvenementForm $form)
	{
		$form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
		if ($form->isValid())
		{
			$evenement = $form->processForm($this);
			$this->redirect('agenda/edit?id='.$evenement->getId());
		}

	}
}
