<?php

/**
 * categories_galeries_arts actions.
 *
 * @package    anbnws
 * @subpackage categories_galeries_arts
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 378 2010-08-25 12:19:33Z hlecorche $
 */
class categories_galeries_artsActions extends sfActions
{
 	//Affiche la liste des categories
	public function executeIndex(sfWebRequest $request)
	{
		$this->liste_categories = Doctrine::getTable('GalerieArtsCategorie')->createQuery()
		->execute();
	}
	
	//Action qui affiche le formulaire d'ajout d'une nouvelle categorie
	public function executeNew(sfWebRequest $request)
	{
		$this->form = new GalerieArtsCategorieForm();
	}
	
	//Action qui creer une nouvelle categorie
	public function executeCreate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$this->form = new GalerieArtsCategorieForm();
		$this->processForm($request, $this->form);
		$this->setTemplate('new');
	}
	
	
	//Action qui affiche le formulaire d'edition d'une catégorie
	public function executeEdit(sfWebRequest $request)
	{
		$this->forward404Unless($categorie = Doctrine::getTable('GalerieArtsCategorie')->find($request->getParameter('id')), sprintf('Object GalerieArtsCategorie does not exist (%s).', $request->getParameter('id')));
		$this->form = new GalerieArtsCategorieForm($categorie);
	}
	
	//Action qui fait la mise à jour d'une catégorie
	public function executeUpdate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
		$this->forward404Unless($categorie = Doctrine::getTable('GalerieArtsCategorie')->find($request->getParameter('id')), sprintf('Object GalerieArtsCategorie does not exist (%s).', $request->getParameter('id')));
		$this->form = new GalerieArtsCategorieForm($categorie);
		$this->processForm($request, $this->form);
		$this->setTemplate('edit');
	}
	
	
	//Action qui supprime les categories
	public function executeDelete(sfWebRequest $request)
	{
		$request->checkCSRFProtection();
		$this->forward404Unless($categorie = Doctrine::getTable('GalerieArtsCategorie')->find($request->getParameter('id')), sprintf('Object GalerieArtsCategorie does not exist (%s).', $request->getParameter('id')));
		
		$user = $this->getUser();
		
		if(count($categorie->getGaleriesArts()) > 0)
		{
			//Des galeries sont associees à cette categorie, on ne peut pas supprimer
			$user->setFlash('bo_categories_galeries_delete_error', 'Impossible de supprimer cette catégorie : Des galeries sont associées à cette catégorie.');
		}
		
		else
		{
			//On supprime
			
			//Si vignette sur le serveur, on la supprime
			$dossier = sfConfig::get('app_uploads_images_galeries');
			$file_name = $categorie->getVignette();
			$file = $dossier.'/'.$file_name;
			if(!empty($file_name) && file_exists($file))
			{
				unlink($file);
			}
			
			//On vide le cache des images
			$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_galeries').'/categories';
			Util::deleteFolder($folder_cache);
			
			$categorie->delete();
			$user->setFlash('bo_categories_galeries_delete_ok', 'Catégorie supprimée');
		}
		
		$this->redirect('categories_galeries_arts/index');
	}
	
	
	
	
	//Action ajax qui supprime la vingette
	public function executeAjaxDeleteImage(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($categorie = Doctrine::getTable('GalerieArtsCategorie')->find($request->getParameter('id')), sprintf('Object GalerieArtsCategorie does not exist (%s).', $request->getParameter('id')));

		//Si le fichier est présent sur le serveur, on le supprime
		$dossier = sfConfig::get('app_uploads_images_galeries');
		$file_name = $categorie->getVignette();
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On vide le cache des images
		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_galeries').'/categories';
		Util::deleteFolder($folder_cache);

		//On supprime l'image de la base de données
		$categorie->setVignette(null);
		$categorie->save();

		//On envoie un message de confirmation
		return $this->renderText('<span style="color: red;">Image supprimée</span>');
	}
	
	
	/*
	 * *************************************
	 *
	 * Methodes privees
	 * 
	 * *************************************
	 */
	
	
	//Traitement du formulaire
	protected function processForm(sfWebRequest $request, sfForm $form)
	{
		$form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
		if ($form->isValid())
		{	
			$categorie = $form->processForm($this);
			
			$user = $this->getUser();
			$user->setFlash('bo_categories_galeries_form_ok', 'Categorie sauvegardée');
			$this->redirect('categories_galeries_arts/edit?id='.$categorie->getId());
		}
		
	}
}
