<?php

/**
 * categories_videos actions.
 *
 * @package    anbnws
 * @subpackage categories_videos
 * @author     Hubert LECORCHE
 * @version    SVN: $Id: actions.class.php 430 2010-09-27 13:41:54Z hlecorche $
 */
class categories_videosActions extends sfActions
{
	//Affiche la liste des categories
	public function executeIndex(sfWebRequest $request)
	{
		$this->liste_categories = Doctrine::getTable('VideoCategorie')->createQuery()
		->execute();
	}
	
	//Action qui affiche le formulaire d'ajout d'une nouvelle categorie
	public function executeNew(sfWebRequest $request)
	{
		$this->form = new VideoCategorieForm();
	}
	
	//Action qui creer une nouvelle categorie
	public function executeCreate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$this->form = new VideoCategorieForm();
		$this->processForm($request, $this->form);
		$this->setTemplate('new');
	}
	
	
	//Action qui affiche le formulaire d'edition d'une catégorie
	public function executeEdit(sfWebRequest $request)
	{
		$this->forward404Unless($categorie = Doctrine::getTable('VideoCategorie')->find($request->getParameter('id')), sprintf('Object VideoCategorie does not exist (%s).', $request->getParameter('id')));
		$this->form = new VideoCategorieForm($categorie);
	}
	
	//Action qui fait la mise à jour d'une catégorie
	public function executeUpdate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
		$this->forward404Unless($categorie = Doctrine::getTable('VideoCategorie')->find($request->getParameter('id')), sprintf('Object VideoCategorie does not exist (%s).', $request->getParameter('id')));
		$this->form = new VideoCategorieForm($categorie);
		$this->processForm($request, $this->form);
		$this->setTemplate('edit');
	}
	
	
	//Action qui supprime les categories
	public function executeDelete(sfWebRequest $request)
	{
		$request->checkCSRFProtection();
		$this->forward404Unless($categorie = Doctrine::getTable('VideoCategorie')->find($request->getParameter('id')), sprintf('Object VideoCategorie does not exist (%s).', $request->getParameter('id')));
		
		$user = $this->getUser();
		
		if(count($categorie->getVideos()) > 0)
		{
			//Des albums sont associees à cette categorie, on ne peut pas supprimer
			$user->setFlash('bo_categories_videos_delete_error', 'Impossible de supprimer cette catégorie : Des vidéos sont associées à cette catégorie.');
		}
		
		else
		{
			//On supprime
			$categorie->delete();
			$user->setFlash('bo_categories_videos_delete_ok', 'Catégorie supprimée');
		}
		
		$this->redirect('categories_videos/index');
	}
	
	
	
	/*
	 * *************************************
	 *
	 * Methodes privees
	 * 
	 * *************************************
	 */
	
	
	//Traitement du formulaire
	protected function processForm(sfWebRequest $request, sfForm $form)
	{
		$form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
		if ($form->isValid())
		{	
			$categorie = $form->save();
			$user = $this->getUser();
			$user->setFlash('bo_categories_videos_form_ok', 'Categorie sauvegardée');
			$this->redirect('categories_videos/edit?id='.$categorie->getId());
		}
		
	}
}
