<?php

/**
 * galeries_arts actions.
 *
 * @package    anbnws
 * @subpackage galeries_arts
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 378 2010-08-25 12:19:33Z hlecorche $
 */
class galeries_artsActions extends sfActions
{
 /*
	 * *************************************
	 *
	 * Actions
	 *
	 * *************************************
	 */


	//Template qui affiche la liste des galeries
	public function executeIndex(sfWebRequest $request)
	{
		$this->prepareInfosAfficheListe($request);
	}

	//Action qui affiche le formulaire d'ajout d'une nouvelle galerie
	public function executeNew(sfWebRequest $request)
	{
		$this->form = new GalerieArtsForm();
	}

	//Action qui creer une nouvelle galerie
	public function executeCreate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$this->form = new GalerieArtsForm();
		$this->processForm($request, $this->form);
		$this->setTemplate('new');
	}


	//Action qui affiche le formulaire d'edition d'une galerie
	public function executeEdit(sfWebRequest $request)
	{
		$this->forward404Unless($galerie = Doctrine::getTable('GalerieArts')->find($request->getParameter('id')), sprintf('Object GalerieArts does not exist (%s).', $request->getParameter('id')));
		$this->form = new GalerieArtsForm($galerie);
	}

	//Action qui fait la mise à jour d'une galerie
	public function executeUpdate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
		$this->forward404Unless($galerie = Doctrine::getTable('GalerieArts')->find($request->getParameter('id')), sprintf('Object GalerieArts does not exist (%s).', $request->getParameter('id')));
		$this->form = new GalerieArtsForm($galerie);
		$this->processForm($request, $this->form);
		$this->setTemplate('edit');
	}
	
	//Action qui affiche les médias d'une galerie
	public function executeEditMedias(sfWebRequest $request)
	{
		$this->forward404Unless($galerie = Doctrine::getTable('GalerieArts')->find($request->getParameter('id')), sprintf('Object GalerieArts does not exist (%s).', $request->getParameter('id')));
		
		//On recupere la liste des medias
		$this->liste_medias = $galerie->getGaleriesArtsMedias();
		
		$this->galerie = $galerie;
		
	}
	
	
	//Action qui supprime un media d'une galerie
	public function executeDeleteMedia(sfWebRequest $request)
	{
		$request->checkCSRFProtection();

		$this->forward404Unless($media = Doctrine::getTable('GalerieArtsMedia')->find($request->getParameter('id')), sprintf('Object GalerieArtsMedia does not exist (%s).', $request->getParameter('id')));
		
		//On supprime le media de la BDD
		$galerie = $media->getGalerieArts();
		$file_name = $media->getNomFichier();
		$media->delete();
		
		//On supprime le media du serveur
		$file = sfConfig::get('app_uploads_images_galeries').'/'.$galerie->getId().'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On supprime le cache
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/arts/'.$galerie->getId();
		Util::deleteFolder($dossier_cache);
		
		//Message de confirmation + redirection
		$user = $this->getUser();
		$user->setFlash('bo_galeries_message_ok', 'Media supprimé');
		$this->redirect('galeries_arts/editMedias?id='.$galerie->getId());
	}
	
	
	
	



	/*
	 * *************************************
	 *
	 * Methodes AJAX
	 *
	 * *************************************
	 */

	//Action ajax qui affiche la pagination des galeries
	public function executeAjaxShowList(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}

	
	//Action ajax qui supprime une galerie
	public function executeAjaxDelete(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($galerie = Doctrine::getTable('GalerieArts')->find($request->getParameter('id')), sprintf('Object GalerieArts does not exist (%s).', $request->getParameter('id')));
		$user = $this->getUser();
		
		//On supprime les médias du serveur
		$dossier = sfConfig::get('app_uploads_images_galeries').'/'.$galerie->getId();
		Util::deleteFolder($dossier);
		
		//On supprime les medias de la BDD
		Doctrine::getTable('GalerieArtsMedia')->createQuery('m')
		->delete()->where('m.galerie_arts_id = ?', $galerie->getId())->execute();
		
		//On supprime le cache
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/arts/'.$galerie->getId();
		Util::deleteFolder($dossier_cache);
		
		//On supprime la galerie
		$galerie->delete();
		$user->setFlash('bo_galeries_message_ok', 'Galerie supprimée', false);
	

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}


	


	/*
	 * *************************************
	 *
	 * Methodes privees
	 *
	 * *************************************
	 */


	/**
	 * Methode qui prepare les informations (pour envoyer au template)
	 * pour l'affichage de la liste des galeries
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	protected function prepareInfosAfficheListe(sfWebRequest $request)
	{
		$page = $request->getParameter('page', 1);

		$this->liste_galeries_non_actifs = array();
		if($page == 1)
		{
			//On est à la première page, on affiche le tableau des galeries
			//non actifs
			$this->liste_galeries_non_actifs  = Doctrine::getTable('GalerieArts')->getGaleriesNonActifsBo();
		}

		//On cree le pager de résultats
		$this->pager = GalerieArtsTable::generatePagerBo();
		$this->pager->setPage($page);
		$this->pager->init();
	}


	//Traitement du formulaire
	protected function processForm(sfWebRequest $request, GalerieArtsForm $form)
	{
		$form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
		if ($form->isValid())
		{
			$reportage = $form->processForm($this);
			$this->redirect('galeries_arts/edit?id='.$reportage->getId());
		}

	}
}
