<?php

/**
 * newsletter actions.
 *
 * @package    anbnws
 * @subpackage newsletter
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 452 2010-09-30 08:47:20Z hlecorche $
 */
class newsletterActions extends sfActions
{

	const VAR_SESSION_EVENTS = 'bo_newsletter_events';
	const VAR_SESSION_TEXT = 'bo_newsletter_text';
	const VAR_SESSION_ADDRESSES = 'bo_newsletter_addresses';
	
	/*
	 * *************************************
	 *
	 * Actions
	 *
	 * *************************************
	 */
	
	//Action qui affiche les informations sur les newsletters
	public function executeIndex(sfWebRequest $request)
	{
		//On regarde si une newsletter est en cours d'envoi (presence d'une ligne dans table newsletter_contenu
		//avec "envoye" à 0 et avec "brouillon" à 0)
		$newsletter_contenu = Doctrine::getTable('NewsletterContenu')->createQuery('c')
		->where('c.envoye = 0')->addWhere('c.brouillon = 0')->count();
		
		//Si une newsletter est en cours d'envoi, on affiche les informations
		$this->envoi_cours = false;
		if($newsletter_contenu > 0)
		{
			$this->envoi_cours = true;
			
			//On recupere le nombre de mails envoyes
			$this->nombre_mails_envoyes = Doctrine::getTable('NewsletterAbonnement')->createQuery('a')
			->where('a.chariot = 1')->count();
			
			//On recupere le nombre de personne abonnées à la newsletter
			$this->nombre_abonnes = Doctrine::getTable('NewsletterAbonnement')->createQuery('a')
			->where('a.active = 1')->count();
			
			//On calcule le pourcentage de mails envoye
			$this->pourcentage_envoye = ceil($this->nombre_mails_envoyes * 100 / $this->nombre_abonnes);
		} 
	}
	
	
	
	
	
	//Action qui permet de construire la newsletter
	public function executeNew(sfWebRequest $request)
	{
		//On regarde si une newsletter est en cours d'envoi. Si oui, redirige vers l'index
		// + message d'erreur
		$this->checkIfNoActiveNewsletter();
		
		//On recupere les 50 prochains evenements, actifs
		$this->liste_evenements = Doctrine::getTable('Evenement')->getEvenementsNewsLetter();
		
		//Si le parametre 'act' vaut "edit", on pré-remplie le formulaire avec les données
		//de la newsletter stockée en session
		$this->default_events = array();
		$this->default_text = null;
		$this->default_addresses = null;
		if($request->getParameter('act') == 'edit')
		{
			$user = $this->getUser();
			$this->default_events = $user->getAttribute(self::VAR_SESSION_EVENTS, array());
			$this->default_text = $user->getAttribute(self::VAR_SESSION_TEXT, null);
			$this->default_addresses = $user->getAttribute(self::VAR_SESSION_ADDRESSES, null);
		}
	}
	
	
	
	
	
	
	//Action qui traite le formulaire envoye par executeNew, puis affiche
	//un message de validation avant l'envoi de la newsletter
	public function executeCreate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod(sfRequest::POST));
		
		$user = $this->getUser();
		
		//On regarde si une newsletter est en cours d'envoi. Si oui, redirige vers l'index
		// + message d'erreur
		$this->checkIfNoActiveNewsletter();
		
		//On supprime les anciens brouillons de newsletter de la personne
		$this->cleanBrouillons();
		
		//On recupere la liste des evenements à ajouter
		$form_liste_evenements = $request->getParameter('add_event');
		
		//On recupere le texte à ajouter
		$form_texte = $request->getParameter('add_text');
		
		//Nettoyage du texte
		if(!empty($form_texte))
		{
			ProjectConfiguration::registerPurifierHtml();
		    $config = HTMLPurifier_Config::createDefault();  
		    $config->set('Core.Encoding', 'UTF-8');
		    $config->set('HTML.Doctype', 'XHTML 1.0 Transitional'); 
		    $config->set('Cache.SerializerPath', sfConfig::get('sf_cache_dir').'/htmlpurifier');
		    
		    // Balises interdites
			$config->set('HTML.ForbiddenElements', 'iframe,img'); 
			
			$purifier = new HTMLPurifier($config);
			$form_texte = $purifier->purify($form_texte); 
		}
		
		//On recupere les adresses à envoyer
		$form_addresses = $request->getParameter('addresses');
		
		//Si pas d'evenements et de texte à ajouter, erreur
		if((!is_array($form_liste_evenements) || count($form_liste_evenements) == 0) && empty($form_texte))
		{
			$user->setFlash('bo_newsletter_error', 'Vous devez sélectionner au moins un événement ou remplir le texte.');
			$this->redirect('newsletter/new?act=edit');
		}
		
		//On stocke les données à ajouter en session
		$user->setAttribute(self::VAR_SESSION_TEXT, $form_texte);
		$user->setAttribute(self::VAR_SESSION_EVENTS, $form_liste_evenements);
		$user->setAttribute(self::VAR_SESSION_ADDRESSES, $form_addresses);
		
		//Pour chaque evenements à ajouter, on verifie s'il exite, si il est actif et
		//si non passé.
		//On ne garde que ceux qui respectent ces conditions.
		$liste_evenements = $this->testEvenements($form_liste_evenements);
		
		//Si aucun élémément est à ajouter à la newsletter, on affiche un message d'erreur 
		//en reaffichant la page de creation (sauf si on a précisé un texte)
		if(count($liste_evenements) == 0 && empty($form_texte))
		{
			$user->setFlash('bo_newsletter_error', 'Vous devez sélectionner au moins un événement ou remplir le texte.');
			$this->redirect('newsletter/new?act=edit');
		}
		
		//Si les adresses de destination définies, on vérifie que correctes
		if(!empty($form_addresses))
		{
			$list_adresses = str_replace("\r", "", $form_addresses);
			$list_adresses = explode("\n", $list_adresses);
			foreach($list_adresses as $address)
			{
				if (!preg_match(Util::getRegexMail(), $address))
				{
					$user->setFlash('bo_newsletter_error', 'Une ou plusieurs adresses sont invalides.');
					$this->redirect('newsletter/new?act=edit');
				}
			}
		}
		
		//On a des elements à ajouter. On creer donc la newsletter
		$mailBody = $this->getPartial('mailBody', array('liste_evenements' => $liste_evenements,
													    'text' => $form_texte));
		$membre_id = MembreTable::getMembreIdConnecte();
		$contenu = new NewsletterContenu();
		$contenu->setTexte($mailBody);
		$contenu->setEnvoye(0);
		$contenu->setBrouillon(1);
		$contenu->setMembreId($membre_id);
		$contenu->setAdresses($form_addresses);
		$contenu->save();
			
		$this->contenu = $contenu;
	}
	
	//Action qui valide la newsletter
	public function executeSubmit(sfWebRequest $request)
	{
				
		//On regarde si une newsletter est en cours d'envoi. Si oui, redirige vers l'index
		// + message d'erreur
		$this->checkIfNoActiveNewsletter();
		
		$user = $this->getUser();
		
		//On recupere la newsletter à envoyer
		$this->forward404Unless($contenu = Doctrine::getTable('NewsletterContenu')->find($request->getParameter('id')), sprintf('Object NewsletterContenu does not exist (%s).', $request->getParameter('id')));
		
		//Erreur 404 si newsletter pas un brouillon
		$this->forward404Unless($contenu->getBrouillon());
		
		//Erreur 404 si la personne connectee n'est pas l'auteur de la newsletter
		$membre_id = MembreTable::getMembreIdConnecte();
		$this->forward404Unless($contenu->getMembreId() == $membre_id);
		
		//Cas n°1: Envoi programmé de la newsletter (à tout le monde)
		if(empty($contenu->adresses))
		{
			//On passe la newsletter en tant que "non brouillon"
			$contenu->setBrouillon(0);
			$contenu->save();
			
			//On passe tous les chariots d'envoi de mails à 0
			$query = Doctrine::getTable('NewsletterAbonnement')->createQuery('a')
			->update()
			->set('a.chariot', 0)
			->execute();
			
			$user->setFlash('bo_newsletter_ok', 'Newsletter ajoutée avec succès. Les premiers envois partiront dans quelques minutes.');
		}
		
		//Cas n°2: Envoi direct de la newsletter
		else
		{
			try
			{
				$contenu->directSubmit();
				$user->setFlash('bo_newsletter_ok', 'Newsletter envoyée.');
			}
			catch(Exception $e)
			{
				$user->setFlash('bo_newsletter_error', 'Une erreur est survenue pendant l\'envoi de la newsletter.');
			}
		}
				
		//On vide les variables de session
		$user->setAttribute(self::VAR_SESSION_EVENTS, array());
		$user->setAttribute(self::VAR_SESSION_TEXT, null);
		$user->setAttribute(self::VAR_SESSION_ADDRESSES, null);
			
		//Retour vers la page d'accueil avec message de confirmation
		$this->redirect('newsletter/index');
			
	}
	
	
	
	
	
	
	/*
	 * *************************************
	 *
	 * Méthodes privees
	 *
	 * *************************************
	 */
	
	//Fonction qui redirige vers la page principale de newsletter (et affiche un message d'erreur)
	//si une autre newsletter est en cours d'envoi.
	protected function checkIfNoActiveNewsletter()
	{
		$user = $this->getUser();
		
		//On regarde si une newsletter est en cours d'envoi (presence d'une ligne dans table newsletter_contenu
		//avec "envoye" à 0 et avec "brouillon" à 0)
		$newsletter_contenu = Doctrine::getTable('NewsletterContenu')->createQuery('c')
		->where('c.envoye = 0')->addWhere('c.brouillon = 0')->count();
		
		//Si une newsletter est en cours d'envoi, on redirige vers la page
		//principale de newsletter et on affiche un message d'erreur
		if($newsletter_contenu > 0)
		{
			$user->setFlash('bo_newsletter_error', 'Impossible de créer une nouvelle newsletter: Une autre newsletter est déjà en cours d\'envoi.');
			$this->redirect('newsletter/index');
		}
	}
	
	/**
	 * Teste si un événement peut etre ajouté à la newsletter
	 * @param Array $ids_evenement Tableau des ID des evenements à tester
	 * @return Array Evenement
	 */
	protected function testEvenements($ids_evenement)
	{
		
		if(!is_array($ids_evenement) || count($ids_evenement) == 0)
		{
			return array();
		}
		
		$today = date('Y-m-d', time());
		
		$q = Doctrine::getTable('Evenement')->createQuery('e')
		->innerJoin('e.Lieu l')
		->orderBy('e.date_debut ASC')
		->whereIn('e.id', $ids_evenement)
		->addWhere('e.active = 1')
		->addWhere('e.date_fin >= ?', $today);
		
		return $q->execute();
	}
	
	
	/**
	 * Méthode qui supprime les anciens brouillons d'une personne
	 */
	protected function cleanBrouillons()
	{
		$membre_id = MembreTable::getMembreIdConnecte();
		
		$q = Doctrine::getTable('NewsletterContenu')->createQuery('c')
		->delete()
		->where('c.membre_id = ?', $membre_id)
		->addWhere('c.brouillon = 1')
		->execute();
	}
}
