<?php

/**
 * reportages actions.
 *
 * @package    anbnws
 * @subpackage reportages
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 443 2010-09-29 12:39:29Z hlecorche $
 */
class reportagesActions extends sfActions
{
 /*
	 * *************************************
	 *
	 * Actions
	 *
	 * *************************************
	 */


	//Template qui affiche la liste des lieux
	public function executeIndex(sfWebRequest $request)
	{
		$this->prepareInfosAfficheListe($request);
	}

	//Action qui affiche le formulaire d'ajout d'un nouveau reportage
	public function executeNew(sfWebRequest $request)
	{
		$this->form = new ReportageForm();
	}

	//Action qui creer un nouveau reportage
	public function executeCreate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$this->form = new ReportageForm();
		$this->processForm($request, $this->form);
		$this->setTemplate('new');
	}


	//Action qui affiche le formulaire d'edition d'un reportage
	public function executeEdit(sfWebRequest $request)
	{
		$this->forward404Unless($reportage = Doctrine::getTable('Reportage')->find($request->getParameter('id')), sprintf('Object Reportage does not exist (%s).', $request->getParameter('id')));
		$this->form = new ReportageForm($reportage);
	}

	//Action qui fait la mise à jour d'un reportage
	public function executeUpdate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
		$this->forward404Unless($reportage = Doctrine::getTable('Reportage')->find($request->getParameter('id')), sprintf('Object Reportage does not exist (%s).', $request->getParameter('id')));
		$this->form = new ReportageForm($reportage);
		$this->processForm($request, $this->form);
		$this->setTemplate('edit');
	}
	
	//Action qui affiche les médias d'un reportage
	public function executeEditMedias(sfWebRequest $request)
	{
		$this->forward404Unless($reportage = Doctrine::getTable('Reportage')->find($request->getParameter('id')), sprintf('Object Reportage does not exist (%s).', $request->getParameter('id')));
		
		//On recupere la liste des medias
		$this->liste_medias = $reportage->getReportageMedias();
		
		$this->reportage = $reportage;
		
	}
	
	
	//Action qui supprime un media d'un reportage
	public function executeDeleteMedia(sfWebRequest $request)
	{
		$request->checkCSRFProtection();

		$this->forward404Unless($media = Doctrine::getTable('ReportageMedia')->find($request->getParameter('id')), sprintf('Object ReportageMedia does not exist (%s).', $request->getParameter('id')));
		
		//On supprime les commentaires associes au media
		Doctrine::getTable('ReportageComment')->createQuery('c')
		->delete()->where('c.reportage_media_id = ?', $media->getId())->execute();
		
		//On supprime les ecards associes au media
		Doctrine::getTable('ReportageEcard')->createQuery('e')
		->delete()->where('e.reportage_media_id = ?', $media->getId())->execute();
		
		//On supprime les favoris associes au media
		Doctrine::getTable('ReportageFavori')->createQuery('f')
		->delete()->where('f.reportage_media_id = ?', $media->getId())->execute();
		
		//On supprime le media de la BDD
		$reportage = $media->getReportage();
		$file_name = $media->getNomFichier();
		$media->delete();
		
		//On supprime le media du serveur
		$file = sfConfig::get('app_uploads_images_reportages').'/'.$reportage->getId().'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On supprime le cache
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/reportages/'.$reportage->getId();
		Util::deleteFolder($dossier_cache);
		
		//Message de confirmation + redirection
		$user = $this->getUser();
		$user->setFlash('bo_reportages_message_ok', 'Media supprimé');
		$this->redirect('reportages/editMedias?id='.$reportage->getId());
	}
	
	
	
	



	/*
	 * *************************************
	 *
	 * Methodes AJAX
	 *
	 * *************************************
	 */

	//Action ajax qui affiche la pagination des reportages
	public function executeAjaxShowList(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}

	//Action ajax qui affiche affiche un reportage sur la page d'accueil
	public function executeAjaxActiveIndex(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($reportage = Doctrine::getTable('Reportage')->find($request->getParameter('id')), sprintf('Object Reportage does not exist (%s).', $request->getParameter('id')));
		$user = $this->getUser();

		//On ne peut pas activer sur la page principale un reportage qui n'est pas actif
		$this->forward404Unless($reportage->getActive(), 'Evenement non actif');

		$reportage->setActiveIndex(1);
		$reportage->save();
		$user->setFlash('bo_reportages_message_ok', 'Reportage activé sur la page principale du site', false);

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}

	//Action ajax qui desactive un reportage sur la page d'accueil
	public function executeAjaxInactiveIndex(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($reportage = Doctrine::getTable('Reportage')->find($request->getParameter('id')), sprintf('Object Reportage does not exist (%s).', $request->getParameter('id')));
		$user = $this->getUser();

		$reportage->setActiveIndex(0);
		$reportage->save();
		$user->setFlash('bo_reportages_message_ok', 'Reportage désactivé sur la page principale du site', false);

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}


	//Action ajax qui supprime un reportage
	public function executeAjaxDelete(sfWebRequest $request)
	{
		/*
		 * ATTENTION !!!!!!!!!!!!!!!!!!
		 * Si modification de cette methode, modifier
		 * celle de lieuxActions
		 */
		
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();

		$this->forward404Unless($reportage = Doctrine::getTable('Reportage')->find($request->getParameter('id')), sprintf('Object Reportage does not exist (%s).', $request->getParameter('id')));
		$user = $this->getUser();

		//On recupere les medias associes au reportage
		$liste_medias = $reportage->getReportageMedias();
		$liste_id_medias = array();
		foreach($liste_medias as $media)
		{
			$liste_id_medias[] = $media->getId();
		} 

		//On supprime les commentaires associes aux medias
		Doctrine::getTable('ReportageComment')->createQuery('c')
		->delete()->whereIn('c.reportage_media_id', $liste_id_medias)->execute();
		
		//On supprime les ecards associes aux medias
		Doctrine::getTable('ReportageEcard')->createQuery('e')
		->delete()->whereIn('e.reportage_media_id', $liste_id_medias)->execute();
		
		//On supprime les favoris associes aux medias
		Doctrine::getTable('ReportageFavori')->createQuery('f')
		->delete()->whereIn('f.reportage_media_id', $liste_id_medias)->execute();
		
		//On supprime les medias
		Doctrine::getTable('ReportageMedia')->createQuery('m')
		->delete()->where('m.reportage_id = ?', $reportage->getId())->execute();
		
		//On supprime les médias du serveur
		$folder = sfConfig::get('app_uploads_images_reportages').'/'.$reportage->getId();
		Util::deleteFolder($folder);
		
		//On supprime les inscriptions au reportage
		Doctrine::getTable('ReportageInscription')->createQuery('i')
		->delete()->where('i.reportage_id = ?', $reportage->getId())->execute();
		
		//On supprime les associations aux reporters du reportage
		Doctrine::getTable('ReportageReporter')->createQuery('r')
		->delete()->where('r.reportage_id = ?', $reportage->getId())->execute();
		
		//On vide le cache des médias du serveur
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/reportages/'.$reportage->getId();
		Util::deleteFolder($dossier_cache);
		
		//On supprime le reportage
		$reportage->delete();
		$user->setFlash('bo_reportages_message_ok', 'Reportage supprimé', false);
	

		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
		
		/*
		 * ATTENTION !!!!!!!!!!!!!!!!!!
		 * Si modification de cette methode, modifier
		 * celle de lieuxActions
		 */
	}


	
	
	
	//Action Ajax qui envoi un SELECT contenant la liste des lieux
	//associes à un type_id passe dans le request
	public function executeAjaxListeLieux(sfWebRequest $request)
	{
		//Vérification ajax
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On recupere le type_id et on le change dans le formulaire
		$type_id = $request->getParameter('type_id');
		
		$form = new ReportageForm();
		$form->setSelectTypeId($type_id);
		
		//On envoie le nouveau widget
		$this->setLayout(false);
		echo $form['lieu_id']->render();
		
		exit();
	}



	/*
	 * *************************************
	 *
	 * Methodes privees
	 *
	 * *************************************
	 */


	/**
	 * Methode qui prepare les informations (pour envoyer au template)
	 * pour l'affichage de la liste des lieux
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	protected function prepareInfosAfficheListe(sfWebRequest $request)
	{
		$page = $request->getParameter('page', 1);

		$this->liste_reportages_non_actifs = array();
		if($page == 1)
		{
			//On est à la première page, on affiche le tableau des lieux
			//non actifs
			$this->liste_reportages_non_actifs  = Doctrine::getTable('Reportage')->getReportagesNonActifsBo();
		}

		//On cree le pager de résultats
		$this->pager = ReportageTable::generatePagerBo();
		$this->pager->setPage($page);
		$this->pager->init();
	}


	//Traitement du formulaire
	protected function processForm(sfWebRequest $request, ReportageForm $form)
	{
		$form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
		if ($form->isValid())
		{
			$reportage = $form->processForm($this);
			$this->redirect('reportages/edit?id='.$reportage->getId());
		}

	}
}
