<?php

/**
 * videos actions.
 *
 * @package    anbnws
 * @subpackage videos
 * @author     Hubert LECORCHE
 * @version    SVN: $Id: actions.class.php 430 2010-09-27 13:41:54Z hlecorche $
 */
class videosActions extends sfActions
{
	//Affiche la liste des videos
	public function executeIndex(sfWebRequest $request)
	{
		$this->prepareInfosAfficheListe($request);
	}
	
	//Action qui affiche le formulaire d'ajout d'une nouvelle video
	public function executeNew(sfWebRequest $request)
	{
		$this->form = new VideoForm();
	}
	
	//Action qui creer une nouvelle video
	public function executeCreate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$this->form = new VideoForm();
		$this->processForm($request, $this->form);
		$this->setTemplate('new');
	}
	
	
	//Action qui affiche le formulaire d'edition d'une catégorie
	public function executeEdit(sfWebRequest $request)
	{
		$this->forward404Unless($video = Doctrine::getTable('Video')->find($request->getParameter('id')), sprintf('Object Video does not exist (%s).', $request->getParameter('id')));
		$this->form = new VideoForm($video);
	}
	
	//Action qui fait la mise à jour d'une catégorie
	public function executeUpdate(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
		$this->forward404Unless($video = Doctrine::getTable('Video')->find($request->getParameter('id')), sprintf('Object Video does not exist (%s).', $request->getParameter('id')));
		$this->form = new VideoForm($video);
		$this->processForm($request, $this->form);
		$this->setTemplate('edit');
	}
	
	
	
	/*
	 * *************************************
	 *
	 * Methodes AJAX
	 *
	 * *************************************
	 */
	
	//Action ajax qui affiche la pagination des videos
	public function executeAjaxShowList(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		
		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}
	
	//Action ajax qui supprime un lieu
	public function executeAjaxDelete(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();
		
		$this->forward404Unless($video = Doctrine::getTable('Video')->find($request->getParameter('id')), sprintf('Object Video does not exist (%s).', $request->getParameter('id')));
		
		$user = $this->getUser();
		
		//On supprime
		$video->delete();
		$user->setFlash('bo_videos_delete_ok', 'Vidéo supprimée', false);
		
		$this->prepareInfosAfficheListe($request);
		return $this->renderPartial('list');
	}
	
	
	/*
	 * *************************************
	 *
	 * Methodes privees
	 * 
	 * *************************************
	 */
	
	
	/**
	 * Methode qui prepare les informations (pour envoyer au template)
	 * pour l'affichage de la liste des videos
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	protected function prepareInfosAfficheListe(sfWebRequest $request)
	{
		$page = $request->getParameter('page', 1);
		
		$this->liste_videos_non_actives = array();
		if($page == 1)
		{
			//On est à la première page, on affiche le tableau des lieux
			//non actifs
			$this->liste_videos_non_actives  = Doctrine::getTable('Video')->getVideosNonActivesBo();
		}
		
		//On cree le pager de résultats
		$this->pager = VideoTable::generatePagerBo();
		$this->pager->setPage($page);
		$this->pager->init();
	}
	
	//Traitement du formulaire
	protected function processForm(sfWebRequest $request, sfForm $form)
	{
		$form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
		if ($form->isValid())
		{	
			$video = $form->processForm($this);
			if($video)
			{
				$this->redirect('videos/edit?id='.$video->getId());
			}
		}
		
	}
}
