<?php

/**
 * admin_annuaire actions.
 *
 * @package    anbnws
 * @subpackage admin_annuaire
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 444 2010-09-29 13:16:20Z hlecorche $
 */
class admin_annuaireActions extends sfActions
{

	/*
	 * *************************************
	 *
	 * Actions
	 *
	 * *************************************
	 */
	
	
	//Action qui affiche le formulaire d'édition des infos d'un lieu
	public function executeInfos(sfWebRequest $request)
	{
		$this->checkLieu();
		$this->form = new LieuFoForm($this->lieu);
		
		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->redirect('admin_annuaire/infos?id='.$this->lieu->getId());
			}
		}
	}
	
	//Action qui affiche le formulaire d'édition des reductions
	public function executeReductions(sfWebRequest $request)
	{
		$this->checkLieu();
		$this->form = new LieuFoReductionsForm($this->lieu);
		
		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->redirect('admin_annuaire/reductions?id='.$this->lieu->getId());
			}
		}
	}
	
	
	//Action qui affiche le formulaire d'ajout d'une image dans la galerie d'un lieu
	public function executeGaleriePhoto(sfWebRequest $request)
	{
		$this->checkLieu();
		$this->form = new LieuGalerieMediaForm(null, array('force_lieu_id' => $this->lieu->getId()));

		//Nouvelle photo
		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo sauvegardée');
				$this->redirect('admin_annuaire/galeriePhoto?id='.$this->lieu->getId());
			}
		}
	}
	
	
	//Action qui affiche le formulaire d'ajout d'une video dans la galerie d'un lieu
	public function executeGalerieVideo(sfWebRequest $request)
	{
		$this->checkLieu();
		$this->form = new LieuVideoForm(null, array('force_lieu_id' => $this->lieu->getId()));

		//Nouvelle photo
		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$video = $this->form->processForm($this);
				if($video)
				{
					$this->getUser()->setFlash('fo_lieux_form_ok', 'Vidéo sauvegardée');
				}
				else
				{
					$this->getUser()->setFlash('fo_lieux_form_ok', 'Erreur lors de la sauvegarde de la vidéo');
				}
				$this->redirect('admin_annuaire/galerieVideo?id='.$this->lieu->getId());
			}
		}
	}
	
	//Action qui affiche le formulaire d'edition d'une image dans la galerie d'un lieu
	public function executeEditGaleriePhoto(sfWebRequest $request)
	{
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($media_id = $request->getParameter('media_id'));
		$media = Doctrine::getTable('LieuGalerieMedia')->createQuery('m')
		->where('m.id = ?', $media_id)
		->addWhere('m.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($media, 'Object LieuGalerieMedia does not exists');
		
		$this->form = new LieuGalerieMediaForm($media, array('force_lieu_id' => $this->lieu->getId()));	

		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo sauvegardée');
				$this->redirect('admin_annuaire/galeriePhoto?id='.$this->lieu->getId());
			}
		}
	}
	
	//Action qui affiche le formulaire d'edition d'une video dans la galerie d'un lieu
	public function executeEditGalerieVideo(sfWebRequest $request)
	{
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($video_id = $request->getParameter('video_id'));
		$video = Doctrine::getTable('LieuVideo')->createQuery('v')
		->where('v.id = ?', $video_id)
		->addWhere('v.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($video, 'Object LieuVideo does not exists');
		
		$this->form = new LieuVideoForm($video, array('force_lieu_id' => $this->lieu->getId()));	

		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$video = $this->form->processForm($this);
				if($video)
				{
					$this->getUser()->setFlash('fo_lieux_form_ok', 'Vidéo sauvegardée');
				}
				else
				{
					$this->getUser()->setFlash('fo_lieux_form_ok', 'Erreur lors de la sauvegarde de la vidéo');
				}
				$this->redirect('admin_annuaire/galerieVideo?id='.$this->lieu->getId());
			}
		}
	}
	
	//Action  qui supprime une image de la galerie d'un lieu
	public function executeDeleteGaleriePhoto(sfWebRequest $request)
	{
		$request->checkCSRFProtection();
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($media_id = $request->getParameter('media_id'));
		$media = Doctrine::getTable('LieuGalerieMedia')->createQuery('m')
		->where('m.id = ?', $media_id)
		->addWhere('m.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($media, 'Object LieuGalerieMedia does not exists');
		
		//On supprime le media du serveur
		$dossier = sfConfig::get('app_uploads_images_galeries_lieux');
		$file_name = $media->getNomFichier();
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On supprime le media de BDD
		$media->delete();
		
		//On vide le cache de la galerie photos du lieu
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_galeries_lieux').'/'.$this->lieu->getId();
		Util::deleteFolder($dossier_cache, true);
		
		//On redirige vers la liste des medias de la galerie
		$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo supprimée');
		$this->redirect('admin_annuaire/galeriePhoto?id='.$this->lieu->getId());
	}
	
	
	//Action  qui supprime une video de la galerie d'un lieu
	public function executeDeleteGalerieVideo(sfWebRequest $request)
	{
		$request->checkCSRFProtection();
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($video_id = $request->getParameter('video_id'));
		$video = Doctrine::getTable('LieuVideo')->createQuery('v')
		->where('v.id = ?', $video_id)
		->addWhere('v.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($video, 'Object LieuVideo does not exists');
		
		//On supprime la video de BDD
		$video->delete();
		
		//On redirige vers la liste des medias de la galerie
		$this->getUser()->setFlash('fo_lieux_form_ok', 'Vidéo supprimée');
		$this->redirect('admin_annuaire/galerieVideo?id='.$this->lieu->getId());
	}
	
	//Action qui affiche le formulaire d'ajout d'une image dans le staff d'un lieu
	public function executeStaff(sfWebRequest $request)
	{
		$this->checkLieu();
		$this->form = new LieuStaffMediaForm(null, array('force_lieu_id' => $this->lieu->getId()));	

		//Nouvelle photo
		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo sauvegardée');
				$this->redirect('admin_annuaire/staff?id='.$this->lieu->getId());
			}
		}
	}
	
	//Action qui affiche le formulaire d'edition d'un staff d'un lieu
	public function executeEditStaff(sfWebRequest $request)
	{
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($media_id = $request->getParameter('media_id'));
		$media = Doctrine::getTable('LieuStaffMedia')->createQuery('m')
		->where('m.id = ?', $media_id)
		->addWhere('m.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($media, 'Object LieuStaffMedia does not exists');
		
		$this->form = new LieuStaffMediaForm($media, array('force_lieu_id' => $this->lieu->getId()));	

		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo sauvegardée');
				$this->redirect('admin_annuaire/staff?id='.$this->lieu->getId());
			}
		}
	}
	
	//Action  qui supprime une image du staff d'un lieu
	public function executeDeleteStaff(sfWebRequest $request)
	{
		$request->checkCSRFProtection();
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($media_id = $request->getParameter('media_id'));
		$media = Doctrine::getTable('LieuStaffMedia')->createQuery('m')
		->where('m.id = ?', $media_id)
		->addWhere('m.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($media, 'Object LieuStaffMedia does not exists');
		
		//On supprime le media du serveur
		$dossier = sfConfig::get('app_uploads_images_staff_lieux');
		$file_name = $media->getNomFichier();
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On supprime le media de BDD
		$media->delete();
		
		//On vide le cache de la galerie photos du lieu
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_staff_lieux').'/'.$this->lieu->getId();
		Util::deleteFolder($dossier_cache, true);
		
		//On redirige vers la liste des medias du staff
		$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo supprimée');
		$this->redirect('admin_annuaire/staff?id='.$this->lieu->getId());
	}
	
	
	
	//Action qui affiche le formulaire d'ajout d'une image dans l'onglet metier d'un lieu
	public function executeGalerieMetier(sfWebRequest $request)
	{
		$this->checkLieu();
		$this->checkOngletActif($this->lieu, array('label_metier_album_1', 'label_metier_album_2'));
		$this->form = new LieuMetierMediaForm(null, array('force_lieu_id' => $this->lieu->getId()));
		
		$this->medias_galerie_1 = array();
		$this->medias_galerie_2 = array();
		foreach($this->lieu->getLieuMetierMedias() as $media)
		{
			if($media->getAlbumId() == 1)
			{
				$this->medias_galerie_1[] = $media;
			}
			else
			{
				$this->medias_galerie_2[] = $media;
			}
		}

		//Nouvelle photo
		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo sauvegardée');
				$this->redirect('admin_annuaire/galerieMetier?id='.$this->lieu->getId());
			}
		}
	}
	
	
	//Action qui affiche le formulaire d'edition d'une image dans l'onglet metier d'un lieu
	public function executeEditGalerieMetier(sfWebRequest $request)
	{
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($media_id = $request->getParameter('media_id'));
		$media = Doctrine::getTable('LieuMetierMedia')->createQuery('m')
		->where('m.id = ?', $media_id)
		->addWhere('m.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($media, 'Object LieuMetierMedia does not exists');
		$this->checkOngletActif($this->lieu, array('label_metier_album_'.$media->getAlbumId()));
		
		$this->form = new LieuMetierMediaForm($media, array('force_lieu_id' => $this->lieu->getId()));

		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo sauvegardée');
				$this->redirect('admin_annuaire/galerieMetier?id='.$this->lieu->getId());
			}
		}
	}
	
	
	//Action  qui supprime une image de l'onglet metier d'un lieu
	public function executeDeleteGalerieMetier(sfWebRequest $request)
	{
		$request->checkCSRFProtection();
		$this->checkLieu();
		
		//On verifie que le media existe et qu'il appartient bien au bon lieu
		$this->forward404Unless($media_id = $request->getParameter('media_id'));
		$media = Doctrine::getTable('LieuMetierMedia')->createQuery('m')
		->where('m.id = ?', $media_id)
		->addWhere('m.lieu_id = ?', $this->lieu->getId())
		->fetchOne();
		$this->forward404Unless($media, 'Object LieuMetierMedia does not exists');
		$this->checkOngletActif($this->lieu, array('label_metier_album_'.$media->getAlbumId()));
		
		//On supprime le media du serveur
		$dossier = sfConfig::get('app_uploads_images_metier_lieux');
		$file_name = $media->getNomFichier();
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);
		}
		
		//On supprime le media de BDD
		$media->delete();
		
		//On vide le cache de la galerie photos du lieu
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_metier_lieux').'/'.$this->lieu->getId();
		Util::deleteFolder($dossier_cache, true);
		
		//On redirige vers la liste des medias du staff
		$this->getUser()->setFlash('fo_lieux_form_ok', 'Photo supprimée');
		$this->redirect('admin_annuaire/galerieMetier?id='.$this->lieu->getId());
	}
	
	//Action qui affiche le formulaire d'édition du texte metier d'un lieu
	public function executeTexteMetier(sfWebRequest $request)
	{
		$this->checkLieu();
		$this->checkOngletActif($this->lieu, array('label_metier_texte_1', 'label_metier_texte_2'));
		$this->form = new LieuFoTexteMetierForm($this->lieu);
		
		if($request->isMethod(sfRequest::POST))
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{	
				$this->form->processForm($this);
				$this->redirect('admin_annuaire/texteMetier?id='.$this->lieu->getId());
			}
		}
	}
	
	
	/*
	 * *************************************
	 *
	 * Actions Ajax
	 *
	 * *************************************
	 */

	
	//Action Ajax qui supprime une image d'un lieu
	public function executeAjaxDeleteImage(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		$request->checkCSRFProtection();
		
		$this->checkLieu();
		$this->forward404Unless($image_id = $request->getParameter('image'), sprintf('Image non precisee'));
		
		//On ne peut supprimer que les images qui sont declarees
		$images_autorisees = Lieu::getNumImages();
		$this->forward404Unless(in_array($image_id, $images_autorisees) && $image_id > 1); //Impossible de supprimer la 1ere image
		
		//Si le fichier est présent sur le serveur, on le supprime
		$dossier = sfConfig::get('app_uploads_images_lieux');
		$file_name = $this->lieu->get('image_'.$image_id);
		$file = $dossier.'/'.$file_name;
		if(!empty($file_name) && file_exists($file))
		{
			unlink($file);	
		}
		
		//On vide le cache des images du lieu
		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_lieux').'/'.$this->lieu->getId();
		Util::deleteFolder($folder_cache);
		
		//On supprime l'image de la base de données
		$this->lieu->set('image_'.$image_id, null);
		$this->lieu->save();
				
		//On envoie un message de confirmation
		return $this->renderText('<span style="color: red;">Image supprimée</span>');
	}
	
	

	

	
	
	
	
	
	
	/*
	 * *************************************
	 *
	 * Méthodes privées
	 *
	 * *************************************
	 */
	
	/**
	 * Fonction qui verifie si le lieu est actif et que la personne connectee peut modifier
	 * ce lieu
	 * @return unknown_type
	 */
	protected function checkLieu()
	{
		$request = $this->getRequest();
				
		$this->lieu = Doctrine::getTable('Lieu')->find(array($request->getParameter('id')));
		$this->forward404Unless($this->lieu, 'Object Lieu does not exists');
				
		//Si lieu non actif, erreur 404
		$this->forward404Unless($this->lieu->getActive(), 'Lieu non actif');
		
		//On regarde si la personne a les droits d'admin sur ce lieu
		$membre_id = MembreTable::getMembreIdConnecte();
		$admin = Doctrine::getTable('LieuAdmin')->createQuery('a')
		->where('a.membre_id = ?', $membre_id)
		->addWhere('a.lieu_id = ?', $this->lieu->getId());
			
		if($admin->count() == 0)
		{
			$this->forward404('Pas les droits');
		}
		
		//Ajoute le CSS
		if(!empty($this->lieu->css))
		{
			sfContext::getInstance()->getConfiguration()->loadHelpers(array('Url'));
			$css = url_for('@annuaire_css?id='.$this->lieu->getId(), true);
			$this->getResponse()->addStylesheet($css, 'last');   
		}
	}
	
	
	/**
	 * Verifie si au moins un onglet donné en parametre est actif pour le lieu donne
	 * @param Lieu $lieu	Lieu a verifier
	 * @param Array $onglets	Liste des onglets a verifier (au moins un onglet doit etre actif)
	 */
	protected function checkOngletActif($lieu, $onglets)
	{
		foreach($onglets as $onglet)
		{
			$nom_onglet = $lieu->get($onglet);
			if(!empty($nom_onglet))
			{
				return true;
			}
		}
		$this->forward404('Onglet inactif');
	}
}
