<?php

/**

 * This file is part of "AnnecyByNight"

 * Copyright (c) 2009 Hubert LECORCHE

 * 

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Classe de formulaire qui permet d' editer un lieu sur le front-office

 *

 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: LieuFoForm.class.php 451 2010-09-30 08:46:27Z hlecorche $ 

 */



class LieuFoForm extends BaseLieuForm

{

	public function configure()

	{

		//Classe

		$class = "fields";

																	 

		$this->useFields(array('description', 'presentation', 'telephone', 'horaires', 'lien',

		'texte_2', 'texte_3', 'texte_4', 'texte_5'));

  														  

  														  

  		//Champ "telephone"

		$this->setWidget('telephone', new sfWidgetFormInput(array(), array('class' => $class,

																	 'size' => 50)));

		

		$this->setValidator('telephone', new sfValidatorString(array('required' => false,

  																'trim' => true,

  																'min_length' => 10,

  																'max_length' => 55),

  														  array('min_length'=> '%min_length% caractères mini',

  														  		'max_length'=> '%max_length% caractères maxi')));



  		//Champ "horraires"

		$this->setWidget('horaires', new sfWidgetFormTextarea(array(), array('class' => $class,

																		 	'rows' => 5,

																		 	'cols' => 90)));

		

		$this->setValidator('horaires', new sfValidatorString(array('required' => false,

  																'trim' => true,

  																'max_length' => 255),

  														  array('max_length'=> '%max_length% caractères maxi')));												  

  														  							 

  														  

  		//Champ "description"

		$this->setWidget('description',  new ecWidgetFormTextareaTinyMCE(array('width' => '700',

																			   'height' => '400'),

				  														 array('cols' => '60', 

				  														 	   'rows' => '10')));

		

		$this->setValidator('description', new ecValidatorHtml(array('required' => true,

  																'trim' => true,

  																'max_length' => 3000),

  														  array('required' => 'Champ obligatoire',

  														  		'max_length'=> '%max_length% caractères maxi')));



  		//Champ "presentation"

		$this->setWidget('presentation',  new ecWidgetFormTextareaTinyMCE(array('width' => '700',

																			   'height' => '400'),

				  														 array('cols' => '60', 

				  														 	   'rows' => '10')));

		

		$this->setValidator('presentation', new ecValidatorHtml(array('required' => false,

  																'trim' => true,

  																'max_length' => 5000),

  														  array('max_length'=> '%max_length% caractères maxi')));



  														  

  														  

  		//images

  		$num_images = Lieu::getNumImages();

  		foreach($num_images as $i)

  		{

  			if($i < 100 && $i > 1) //Impossible de modifier la 1ere image

  			{

		  		$this->setWidget('file_image_'.$i, new sfWidgetFormInputFile(array(), array('class' => $class)));

		  																  

		  		$this->setValidator('file_image_'.$i, new sfValidatorFile(array('max_size' => 2000000,

		  															   'mime_types' => array('image/jpeg'),

		  															   'required' => false),

		  														 array('max_size' => 'La photo doit faire 2Mo maximum',

		  														 	   'mime_types' => 'Format du fichier incorrect')));

  			}

  		}	

  		

  		

  		//Textes

  		$num_textes = Lieu::getNumTextes();

  		foreach($num_textes as $i)

  		{

	  		$this->setWidget('texte_'.$i, new sfWidgetFormInput(array(), array('class' => $class,

																		 	   'size' => 50)));

			

			$this->setValidator('texte_'.$i, new sfValidatorString(array('required' => false,

	  																'trim' => true,

	  																'max_length' => 45),

	  														  array('max_length'=> '%max_length% caractères maxi')));

  		}



  		

  		//Champ "lien"

		$this->setWidget('lien', new sfWidgetFormInput(array(), array('class' => $class,

																	 'size' => 30)));

		

		$this->setValidator('lien', new sfValidatorUrl(array('required' => false,

  																'trim' => true,

  																'max_length' => 255),

  														  array('max_length'=> '%max_length% caractères maxi',

  														  		'invalid' => 'Adresse invalide')));		



  														  

	}

	

	

	

	

	/**

	 * Fonction apelee quand formulaire valide

	 * @param sfActions $action

	 * @return Lieu

	 */

	public function processForm(sfActions $action)

	{

		//On recupere l'objet Lieu

		$lieu = $this->getObject();

			

		

		//Si les images ne sont pas présentes, on desactive les widgets associes

		//pour eviter une erreur SF

		$num_images = Lieu::getNumImages();

  		foreach($num_images as $i)

		{

			if($i < 100 && $i > 1) //Impossible de modifier la 1ere image

			{

				$image = $this->getValue('file_image_'.$i);

				if(empty($image))

				{

					unset($this['file_image_'.$i]);

				}

			}

		}

		

		//On sauvegarde les données

		$lieu = $this->save();

		

		//On traite les nouvelles images

		$dossier_images = sfConfig::get('app_uploads_images_lieux');

		

		foreach($num_images as $i)

		{

			if($i < 100 && $i > 1)

			{

				$image = $this->getValue('file_image_'.$i);

				if(!empty($image))

				{

					//On regarde si une ancienne photo est presente, et si oui on la supprime

					$ancienne_image = $lieu->get('image_'.$i);

					if(!empty($ancienne_image) && file_exists($dossier_images.'/'.$ancienne_image))

					{

						unlink($dossier_images.'/'.$ancienne_image);

					}

					

					//On ajoute la nouvelle photo

					$extension = $image->getExtension($image->getOriginalExtension());

					$name = 'lieu_'.$lieu->getId().'_image_'.$i.$extension;

					$image->save($dossier_images.'/'.$name);

					

					//On mets à jour la BDD avec cette nouvelle valeur

					$lieu->set('image_'.$i, $name);

				}

			}

		}

		

		//On sauvegarde le tout

		$lieu->save();

		

		//On vide le cache des images du lieu

		//On supprime le cache des images de profil de la personne

		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_lieux').'/'.$lieu->getId();

		Util::deleteFolder($folder_cache);

		

		//On affiche le message de confirmation

		$user = $action->getUser();

		$user->setFlash('fo_lieux_form_ok', 'Modifications sauvegardées');

		

		return $lieu;

	}

}

?>