<?php

/**
 * agenda actions.
 *
 * @package    anbnws
 * @subpackage agenda
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 413 2010-09-06 11:37:02Z hlecorche $
 */
class agendaActions extends sfActions
{

	/**
	 * Action qui affiche les détails d'un evenement
	 *
	 * @param sfRequest $request A request object
	 */
	public function executeZoom(sfWebRequest $request)
	{

		$evenement = Doctrine::getTable('Evenement')->findJoinZoom(array($request->getParameter('id')));
		$this->forward404Unless($evenement, 'Object Evenement does not exists');

		$this->AfficheInfosSoiree($evenement);

		$this->form = new EvenementInscriptionForm();

	}


	//Action appelee pour ajouter une inscription a une soiree
	public function executeAddInscription(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$user = $this->getUser();

		//Recupere les infos sur l'evenement
		$evenement = Doctrine::getTable('Evenement')->findJoinZoom(array($request->getParameter('id')));
		$this->forward404Unless($evenement, 'Object Evenement does not exists');

		//Recupere les infos sur le formulaire
		$this->form = new EvenementInscriptionForm();
		$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));

		//On regarde si la personne est bien authentifiee
		if(!$user->IsAuthenticated())
		{
			//La personne n'est pas connectee
			$this->redirect('agenda/zoom?id='.$evenement->getId());
		}

		//On regarde si l'evenement n'est deja pas passe
		if($evenement->estPasse())
		{
			//La soiree est deja passee, donc impossible de s'inscrire
			$user->setFlash('add_inscription_error', 'Les inscriptions pour cette soirée sont fermées');
			$this->AfficheInfosSoiree($evenement);
			$this->setTemplate('zoom');
			return 'Success';
		}


		//On regarde si la personne n'a deja pas poste sur cet evenement
		$membre_id = MembreTable::getMembreIdConnecte();
		$query = Doctrine::getTable('EvenementInscription')->createQuery('ei')
		->where('membre_id = ?', $membre_id)
		->addwhere('evenement_id = ?', $evenement->getId())
		->select('ei.id');
		$nombre_messages = count($query->fetchArray());
		if($nombre_messages > 0)
		{
			//La personne a deja poste un message sur cet evenement, on affiche
			//alors un message d'erreur
			$user->setFlash('add_inscription_error', 'Vous avez déjà posté sur cet événement.');
			$this->AfficheInfosSoiree($evenement);
			$this->setTemplate('zoom');
			return 'Success';
		}


		//Traitement du formulaire
		if ($this->form->isValid())
		{
			//Formulaire valide

			//On recupere l'objet du formulaire
			$object = $this->form->getObject();
			$object->setEvenement($evenement);
			$object->setMembreId(MembreTable::getMembreIdConnecte());

			//On sauvegarde
			$this->form->save();
			$user->setFlash('add_inscription_ok', 'Message sauvegardé');

			//Redirection
			$this->redirect('agenda/zoom?id='.$evenement->getId());

		}
		else
		{
			//Formulaire invalide
			$this->AfficheInfosSoiree($evenement);
			$this->setTemplate('zoom');
		}


	}




	/**
	 * Affiche les infos d'une soiree
	 * Apelee par l'action Zoom ou AddInscription (si erreur dans formulaire)
	 * @param Evenement $evenement
	 * @return unknown_type
	 */
	private function AfficheInfosSoiree(Evenement $evenement)
	{
		//Les informations sur les inscriptions à l'evenement
		$this->inscriptions = $evenement->getEvenementsInscriptionsJoinMembre();
		
		$this->lieu = $evenement->getLieu();
		
		//On recupere la liste des prochains evenements dans ce lieu
		$max_result = sfConfig::get('app_nbre_prochains_evenements', 20);
		$q = Doctrine::getTable('Evenement')->createQuery('e')
		->orderBy('e.date_debut ASC')->limit($max_result);
		$this->liste_prochains_evenements = $this->lieu->getEvenementsActifsNonPasses($q);
		
		//On recupere la liste des derniers evenements dans ce lieu
		$max_result = sfConfig::get('nbre_derniers_evenements', 20);
		$q = Doctrine::getTable('Evenement')->createQuery('e')
		->orderBy('e.date_debut DESC')->limit($max_result);
		$this->liste_derniers_evenements = $this->lieu->getEvenementsActifsPasses($q);
		
		//On recupere la liste des derniers reportages dans ce lieu
		$max_result = sfConfig::get('nbre_derniers_reportages', 20);
		$q = Doctrine::getTable('Reportage')->createQuery('r')
		->orderBy('r.date DESC')->limit($max_result);
		$this->liste_reportages = $this->lieu->getReportagesActifs($q);
		
		//Chemin vers les photos
		$this->dossier_images_events = sfConfig::get('app_dossiers_images_agenda').'/';
		$this->dossier_images_lieux = sfConfig::get('app_dossiers_images_lieux').'/';

		//On regarde si l'evenement est deja passe ou pas (car si deja passe, on n'affiche
		//pas le formulaire d'inscription)
		$this->inscriptions_ouvertes = !$evenement->estPasse();

		$this->user = $this->getUser();
		$this->evenement = $evenement;
	}


	//Methode qui change le mois ou l'annee en cours sur le calendrier
	public function executeChangeCalendar(sfWebRequest $request)
	{
		$month = $request->getParameter('month', null);
		$year = $request->getParameter('year', null);

		//On enregistre les nouvelles valeurs en session
		$session_calendar['month']  = $month;
		$session_calendar['year']  = $year;
		$user = $this->getUser();
		$user->setAttribute(sfConfig::get('app_calendar_name_session'), $session_calendar);

		//On redirige vers la page ou on se trouvait
		$referer = $request->getReferer();
		$this->redirect($referer);
	}




	//Action qui affiche la liste des evenements
	public function executeList(sfWebRequest $request)
	{
		//Cette page peut afficher la liste des évenements de deux manieres differentes :
		// * Soit afficher les soirées d'une date donnée ("jour", "mois" et "annee" donnes dans le GET)
		// * Soit afficher les évenements des 30 prochains jours, si aucune date precisee dans le GET
		
		//On regarde si deux parametres sont passes en GET
		$this->display_one_day = false;
		$this->date = null;
		$jour = intval($request->getParameter('jour'));
		$mois = intval($request->getParameter('mois'));
		$annee = intval($request->getParameter('annee'));
		
		//on construit l'url de la page pour le formulaire de tri
		$this->url_page = $this->getModuleName().'/'.$this->getActionName();
		
		if(is_integer($jour) && $jour > 0 && $jour < 32 &&
		is_integer($mois) && $mois > 0 && $mois < 13 && 
		is_integer($annee) && $annee > 1980 && $annee < 2030 )
		{
			//Les parametres donnes en GET, sont corrects, ont va les utiliser
			$this->display_one_day = true;
			$this->date = $annee.'-'.$mois.'-'.$jour;
			//on re-construit l'url de la page pour le formulaire de tri
			$this->url_page = $this->getModuleName().'/'.$this->getActionName().'?jour='.$jour.'&mois='.$mois.'&annee='.$annee;
		}
		
		
		//Configuration
		$this->nom_session = 'agenda_'.$this->date;
		
		$user = $this->getUser();

		if($request->isMethod(sfRequest::POST))
		{
			//On vient du formulaire du changement des propriétés d'affichage,
			//on modifie les paramètres
			$this->changeDisplay($this->nom_session, $request);
		}


		//On cree le pager de résultats
		$this->pager = EvenementTable::generatePager($this->nom_session, $this->display_one_day, $this->date);
		$this->pager->setPage($this->getRequestParameter('page',1));
		$this->pager->init();

		//Chemin des dossiers
		$this->dossier_images = sfConfig::get('app_dossiers_images_agenda').'/';


		//Données fournis au formulaire de recherche
		//Liste des catégories
		$this->liste_categories = Doctrine::getTable('Type')->getTypesSoireesForm();
		$this->liste_tri = array(0 => 'Trier par...', 1 => 'Trier par lieu', 2=>'Trier par auteur', 3 => 'Trier par titre', 4 => 'Trier par date');
		$this->liste_ordre = array(0 => 'Croissant', 1 => 'Décroissant');
		$this->liste_nombre_pages = array(12 => '12', 24 => '24', 64 => '64');
		//Valeurs par défaults du formulaire
		$this->selected_categorie = $user->getAttribute($this->nom_session.'_categorie', 0);
		$this->selected_tri = $user->getAttribute($this->nom_session.'_tri', 0);
		$this->selected_nombre_pages = $user->getAttribute($this->nom_session.'_nombre_pages', 64);
		$this->selected_ordre = $user->getAttribute($this->nom_session.'_ordre', 0);

		$this->setTemplate('list');
	}


	//Fonction qui affiche et traite le formulaire d'ajout d'un évenement
	public function executeAjoutEvenement(sfWebRequest $request)
	{
		$this->form = new SuggestEventForm();
		
		if($request->getMethod() == sfRequest::POST)
		{
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{
				$this->form->processForm($this);
				$this->redirect('agenda/ajoutEvenementOk');
			}
		}
	}
	
	//Fonction qui affiche la confirmation d'ajout de soirée
	public function executeAjoutEvenementOk(sfWebRequest $request)
	{
		
	}
	
	
	
	//Action Ajax qui envoi un SELECT contenant la liste des lieux
	//associes à un type_id passe dans le request
	public function executeAjaxListeLieux(sfWebRequest $request)
	{
		//Vérification ajax
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On recupere le type_id et on le change dans le formulaire
		$type_id = $request->getParameter('type_id');
		
		$form = new SuggestEventForm();
		$form->setSelectTypeId($type_id);
		
		//On envoie le nouveau widget
		$this->setLayout(false);
		echo $form['lieu_id']->render();
		
		exit();
	}
	

	/**
	 * Fonction qui change les priorités d'affichage sur la liste, et
	 * qui sauvegarde en session
	 * @param String $nom_session Nom de la session
	 * @param sfRequest $request
	 * @return unknown_type
	 */
	private function changeDisplay($nom_session, $request)
	{
		$user = $this->getUser();

		//Traitement du champ "categorie"
		$categorie = $request->getParameter('categorie');
		if(!is_null($categorie))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_categorie', $categorie);
		}



		//Traitement du champ 'tri'
		$tri = $request->getParameter('tri');
		if(!is_null($tri))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_tri', $tri);
		}

		//Traitement du champ 'nombre_pages'
		$nombre_pages = $request->getParameter('nombre_pages');
		if(!is_null($nombre_pages))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_nombre_pages', $nombre_pages);
		}

		//Traitement du champ 'ordre'
		$ordre = $request->getParameter('ordre');
		if(!is_null($ordre))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_ordre', $ordre);
		}
	}
}