<?php

/**
 * galeries_arts actions.
 *
 * @package    anbnws
 * @subpackage galeries_arts
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 413 2010-09-06 11:37:02Z hlecorche $
 */
class galeries_artsActions extends sfActions
{
 	/**
	 * ******************************************************
	 * 
	 * Actions générales
	 * 
	 * ******************************************************
	 */
	
	//Action qui affiche la liste des categories de galeries d'arts
	public function executeIndex(sfWebRequest $request)
	{
		$this->liste_categories = GalerieArtsCategorieTable::createQueryWithPersonalizedColumns()
		->orderBy('c.nom ASC')
		->where('c.active = 1')
		->execute();
	}
	
	
	
	/**
	 * Action qui affiche la liste des médias d'une galerie, puis affiche 
	 * le partial _zoom_galerie par défaut et après on change en AJAX
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	public function executeZoom(sfWebRequest $request)
	{
		//On recupere l'objet Galerie que l'on veut recuperer
		//avec les jointures sur le lieu, le membre reporter,
		//et l'évenement (si PRESENT)
		$galerie = Doctrine::getTable('GalerieArts')->findGalerieJoinCategorie(array($request->getParameter('id')));
		$this->forward404Unless($galerie, 'Object GalerieArts does not exists');
		
		//On prepare les infos de la galerie à envoyer au template
		$this->getInformationsForShowGalerie($galerie, 1);
				
		$this->galerie = $galerie;
	}
	
	
	//Action qui affiche la liste des galeries
	public function executeListeGaleries(sfWebRequest $request)
	{	
		$categorie = Doctrine::getTable('GalerieArtsCategorie')->find(array($request->getParameter('id')));
		$this->forward404Unless($categorie, 'Object GalerieArtsCategorie does not exists');
		$this->categorie = $categorie;
		
		//Configuration
		$this->nom_session = 'galeries_arts';
		$this->url_page = $this->getModuleName().'/'.$this->getActionName().'?id='.$categorie->getId();
		$user = $this->getUser();
		
		if($request->isMethod(sfRequest::POST) || $request->hasParameter('categorie'))
		{
			//On vient du formulaire du changement des propriétés d'affichage
			//on modifie les paramètres
			$this->changeDisplay($this->nom_session, $request);
		}
		

		//On cree le pager de résultats

		$this->pager = Doctrine::getTable('GalerieArts')->generatePager($this->nom_session, $categorie);
		$this->pager->setPage($this->getRequestParameter('page',1));
		$this->pager->init();
		
		
		//Données fournis au formulaire de recherche
		$this->liste_tri = array(0 => 'Trier par...', 1 => 'Trier par nom', 2=>'Trier par date d\'ajout');
		$this->liste_ordre = array(0 => 'Croissant', 1 => 'Décroissant');
		$this->liste_nombre_pages = array(12 => '12', 24 => '24', 64 => '64');
		//Valeurs par défaults du formulaire
		$this->selected_tri = $user->getAttribute($this->nom_session.'_tri', 0);
		$this->selected_nombre_pages = $user->getAttribute($this->nom_session.'_nombre_pages', 64);
		$this->selected_ordre = $user->getAttribute($this->nom_session.'_ordre', 1);
		
		$this->setTemplate('list');
	}
	
	
	
	
	
	
	/**
	 * ******************************************************
	 * 
	 * Actions Ajax
	 * 
	 * ******************************************************
	 */
	
	
	
	public function executeAjaxZoomGalerie(sfWebRequest $request)
	{
		//On verifie que l'on vient bien d'une requete ajax
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On recupere l'objet GalerieArts que l'on veut recuperer
		$galerie = Doctrine::getTable('GalerieArts')->find(array($request->getParameter('id')));
		$this->forward404Unless($galerie, 'Object GalerieArts does not exists');
		
		//On recupere le numero de page à afficher
		$page = $request->getParameter('page', 1);
		
		//On prepare les infos de la galerie à envoyer au template
		$this->getInformationsForShowGalerie($galerie, $page);
						
		$this->galerie = $galerie;
		
		return $this->renderPartial('galeries_arts/zoom_galerie');
		
	}
	
	
	
	/**
	 * Action Ajax qui permet d'afficher un media (photo ou video) . Utilise la partial
	 * "_ajax/zoomPhoto" si photo (ou "_ajax/zoomVideo si video)
	 * qui remplace le contenu du div "contenu_reportage"
	 * du template "zoomSuccess".
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	public function executeAjaxZoomMedia(sfWebRequest $request)
	{
		//On verifie que l'on vient bien d'une requete ajax
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On regarde si la personne est connectee. Dans le cas contraire, renvoie d'une image
		//l'invitant à se connecter.
		$user = $this->getUser();
		if(!$user->isAuthenticated())
		{
			return $this->renderPartial('galeries_arts/ajax/erreurConnexion');
		}
		
		//On recupere l'id du media à afficher, erreur 404 si non existante dans la table
		//On fait aussi une jointure avec la table galerie_arts pour recuperer les infos de la galerie associee
		$media = Doctrine::getTable('GalerieArtsMedia')->findJoinGalerie(array($request->getParameter('id')));
		$this->forward404Unless($media, 'Object GalerieArtsMedia does not exists');

		$this->media = $media;
		
		if($media->getIsVideo())
		{
			//On prepare les informations necessaires à l'affichage de la photo
			$this->getInformationsForShowVideo($media, $request);
			
			//On affiche le template d'affichage des photos
			return $this->renderPartial('galeries_arts/ajax/zoomVideo');
		}
		else
		{
			//On prepare les informations necessaires à l'affichage de la photo
			$this->getInformationsForShowPhoto($media, $request);
			
			//On affiche le template d'affichage des photos
			return $this->renderPartial('galeries_arts/ajax/zoomPhoto');
		}		
	}
	
	
	
	
	
	
	
	
	
	/**
	 * ******************************************************
	 * 
	 * Methodes privees
	 * 
	 * ******************************************************
	 */
	
	/**
	 * Prepare toutes les informations nécessaires (pour envoyer au template)
	 * necessaire pour l'affiche d'une galerie (liste des médias)
	 * @param GalerieArts $galerie
	 * @param Int $page page à afficher
	 * @return unknown_type
	 */
	private function getInformationsForShowGalerie(GalerieArts $galerie, $page = 1)
	{
		//Si la galerie n'est pas actif, erreur 404
		$this->forward404Unless($galerie->getActive());
				
		//On recupere les medias
		$max_results  = sfConfig::get('app_galerie_arts_nbre_elements_liste_medias', 40);
		$pager = new sfDoctrinePager('GalerieArtsMedia', $max_results);
		//On definit le tri ascendant par ID
		$query = $pager->getQuery();
		$query->orderBy('id ASC');
		$query->addWhere('galerie_arts_id = ?', $galerie->getId());
		$pager->setPage($page);
		$pager->init();
		$this->pager = $pager;
	}
	
	
	
	/**
	 * Prepare toutes les informations nécessaires (pour envoyer au template)
	 * necessaire pour l'affiche d'une photo
	 * @param GalerieArtsMedia $media
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	private function getInformationsForShowPhoto(GalerieArtsMedia $media, sfWebRequest $request)
	{
		//On regarde si la photo est bien un media de type "photo", sinon erreur 404
		$this->forward404Unless(!$media->getIsVideo());
		
		//On recupere le numero de page d'ou l'on vient (pour pouvoir creer
		//le bouton "Retour à la liste des medias"
		$this->page_liste = $request->getParameter('page', 1);
	}
	
	
	/**
	 * Prepare toutes les informations nécessaires (pour envoyer au template)
	 * necessaire pour l'affiche d'une video
	 * @param GalerieArtsMedia $media
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	private function getInformationsForShowVideo(GalerieArtsMedia $media, sfWebRequest $request)
	{
		//On regarde si le media est bien un media de type "video", sinon erreur 404
		$this->forward404Unless($media->getIsVideo());
		
		//On recupere le numero de page d'ou l'on vient (pour pouvoir creer
		//le bouton "Retour à la liste des medias"
		$this->page_liste = $request->getParameter('page', 1);
	}
	
	
	
	/**
	 * Fonction qui change les priorités d'affichage sur la liste, et
	 * qui sauvegarde en session
	 * @param String $nom_session Nom de la session
	 * @param sfRequest $request
	 * @return unknown_type
	 */
	private function changeDisplay($nom_session, $request)
	{
		$user = $this->getUser();

		
		//Traitement du champ 'tri'
		$tri = $request->getParameter('tri');
		if(!is_null($tri))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_tri', $tri);
		}

		//Traitement du champ 'nombre_pages'
		$nombre_pages = $request->getParameter('nombre_pages');
		if(!is_null($nombre_pages))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_nombre_pages', $nombre_pages);
		}

		//Traitement du champ 'ordre'
		$ordre = $request->getParameter('ordre');
		if(!is_null($ordre))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_ordre', $ordre);
		}
	}
}
