<?php
/**
 * This file is part of "Annecy By Night"
 * Copyright (c) 2009 Hubert LECORCHE
 * 
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */


/**
 * Classe de formulaire d'inscription
 *
 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>
 * @version    SVN: $Id: EditProfilInfosForm.class.php 381 2010-08-26 09:18:49Z hlecorche $ 
 */
class EditProfilInfosForm extends BaseMembreForm
{
  public function configure()
  {
  		//Classe des champs du formulaire
  		$class = 'fields';
  		
  		//Définition des listes
  		$liste_sexes = array(0 => '', 1 => 'Masculin', 2 => 'Féminin');
  		$liste_fumeur = array(null => '', 0 => 'Non fumeur', 1 => 'Fumeur');
  		$liste_enfants = array(null => '', 0 => 'N\'a pas d\'enfant', 1 => 'A des enfants');
  		$liste_annees = array();
  		for($i=intval(date('Y', time())); $i>= intval(date('Y', time() - 31536000 * 100)); $i--) { $liste_annees[$i] = $i; }	
  		
  			  
  		
  		//Champ "prenom" (facultatif)
  		$this->setWidget('prenom', new sfWidgetFormInput(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('prenom', new sfValidatorString(array('required' => true,
  																  'trim' => true,
  																  'min_length' => 3,
  																  'max_length' => 25),
  														  	array('min_length'=> '%min_length% caractères mini',
  														  		  'max_length'=> '%max_length% caractères maxi',
  														  		  'required' => 'Champ obligatoire')));
  		
  		//Champ mot de passe (obligatoire si l'autre est rempli)
  		$this->setWidget('mot_passe', new sfWidgetFormInput(array('type' => 'password'), array('class' => $class,
  																							   'size' => 30)));
  		$this->setValidator('mot_passe', new sfValidatorString(array('required' => true,
  																	'min_length' => 6,
  																	'max_length' => 255),
  														  	   array('required' => 'Champ obligatoire',
  														  			 'min_length'=> '%min_length% caractères mini',
  														  			 'max_length'=> '%max_length% caractères maxi')));

  		
  		//Champ mot de passe confirmation (obligatoire si l'autre est rempli)
  		$this->setWidget('mot_passe_confirmation', new sfWidgetFormInput(array('type' => 'password'), array('class' => $class,
  																							   'size' => 30)));
  		$this->setValidator('mot_passe_confirmation', new sfValidatorPass());
  											  	   
  		
  														  	
  		//Champ "portable" (facultatif)
  		$this->setWidget('portable', new sfWidgetFormInput(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('portable', new sfValidatorString(array('required' => false,
  																  'trim' => true,
  																  'min_length' => 10,
  																  'max_length' => 20),
  														  	array('min_length'=> '%min_length% caractères mini',
  														  		  'max_length'=> '%max_length% caractères maxi')));
  														  	
  		//Champ "sexe" (obligatoire)
  		$this->setWidget('sexe', new sfWidgetFormSelect(array('choices' => $liste_sexes), 
  														array('class' => $class)));
  		$this->setValidator('sexe', new sfValidatorChoice(array('choices' => array(1, 2),
  																'required' => true),
  														  array('required' => 'Champ obligatoire',
  														  		'invalid' => 'Champ obligatoire')));
  		
  		//Champ "civilite_id" (facultatif)
  		$this->setWidget('civilite_id', new sfWidgetFormDoctrineChoice(array('model' => 'Civilite',
  																		  'add_empty' => true,
  																		  'order_by' => array('nom', 'ASC')), 
  														array('class' => $class)));
  		$this->setValidator('civilite_id', new sfValidatorDoctrineChoice(array('model' => 'Civilite',
  																'required' => false,
  																'column' => 'id'),
  														  array('required' => 'Champ obligatoire',
  														  		'invalid' => 'Champ invalide'
  														  		)));
  														  
  		//Champ "fume" (facultatif)
  		$this->setWidget('fume', new sfWidgetFormSelect(array('choices' => $liste_fumeur), 
  														array('class' => $class)));
  		$this->setValidator('fume', new sfValidatorChoice(array('choices' => array_keys($liste_fumeur),
  																'required' => false),
  														  array('invalid' => 'Champ obligatoire')));
  														  
  		//Champ "enfants" (facultatif)
  		$this->setWidget('enfants', new sfWidgetFormSelect(array('choices' => $liste_enfants), 
  														array('class' => $class)));
  		$this->setValidator('enfants', new sfValidatorChoice(array('choices' => array_keys($liste_enfants),
  																'required' => false),
  														  array('invalid' => 'Champ obligatoire')));
  														  
  		//Champ "date_naissance" (obligatoire")
  		$this->setWidget('date_naissance', new sfWidgetFormDate(array('format' => '%day%/%month%/%year%',
  																	  'empty_values' => array('year' => 'Année',
  																							  'month' => 'Mois',
  																							  'day' => 'Jour'),
  																		'years' => $liste_annees),
  																array('class' => $class)));
  																
  		$this->setValidator('date_naissance', new sfValidatorDate(array('required' => true,
  																	 'max' => time(),
  																	 'min' => time() - 31536000 * 100),
  															   array('required' => 'Champ obligatoire',
  																	 'max' => 'Date invalide',
  															   		 'min' => 'Date invalide',
  															   		 'invalid' => 'Date invalide')));
  															   
  		
		//Champ "ville" (obligatoire)
  		$this->setWidget('ville', new sfWidgetFormInput(array(), array('class' => $class,
  																		'size' => 25)));	
  		$this->setValidator('ville', new sfValidatorString(array('required' => true,
  																	'min_length' => 3,
  																	'max_length' => 40,
  																	'trim' => true),
  														  	   array('required' => 'Champ obligatoire',
  														  			 'min_length'=> '%min_length% caractères mini',
  														  			 'max_length'=> '%max_length% caractères maxi')));								   

  														  	   
  		//Champ "code_postal" (obligatoire)
  		$this->setWidget('code_postal', new sfWidgetFormInput(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('code_postal', new sfValidatorInteger(array('required' => true,
  																  'min' => 100,
  																  'max' => 999999),
  																  array('required' => 'Champ obligatoire',
  																  		'min' => 'Code postal invalide',
  																  		'max' => 'Code postal invalide',
  																  		'invalid' =>'Code postal invalide')));
  																  
  		$this->setWidget('site_web', new sfWidgetFormInput(array(), array('class' => $class,
  																		'size' => 30)));	
  		$this->setValidator('site_web', new sfValidatorUrl(array('required' => false,
  																	'min_length' => 10,
  																	'max_length' => 255,
  																	'trim' => true),
  														  	   array('invalid' => 'Adresse invalide',
  														  			 'min_length'=> '%min_length% caractères mini',
  														  			 'max_length'=> '%max_length% caractères maxi')));	
  		
  												  	   
  		$this->setWidget('annonce', new sfWidgetFormTextarea(array(), array('class' => $class)));	
  		$this->setValidator('annonce', new sfValidatorString(array('required' => false,
  																	'max_length' => 500,
  																	'trim' => true),
  														  	   array('max_length'=> '%max_length% caractères maxi')));													  	   
  														  	   
  		//Champs captcha
  		$this->setWidget('captcha', new sfWidgetFormInput(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('captcha', new sfValidatorSfCryptoCaptcha(array('required' => true, 
  																			'trim' => true),
                                                   					  array('wrong_captcha' => 'Code invalide',
                                                         					'required' => 'Champ obligatoire')));											 
  		
 		//Champs désactivés car non modifiables dans ce formulaire
 		unset($this['id']);
		unset($this['pseudo']);
		unset($this['email']);
        unset($this['confirmation']);
		unset($this['confirmation_code']);
		unset($this['derniere_requete']);
		unset($this['level_id']);
		unset($this['img_1']);
		unset($this['img_2']);
		unset($this['img_3']);
		unset($this['mot_passe_crypte']);
		unset($this['image_profil']);
		unset($this['notification_newsletter']);
		unset($this['fonction_id']);
		unset($this['reportages_list']); //Champ virtuel
		unset($this['reportages_presents_list']); //Champ virtuel
		unset($this['lieux_list']); //Champ virtuel
		
		//Champs desactives car traites par SF
		unset($this['created_at']);
		
		
		
		
		//Validateur pour comparer les deux mots de passe
		$this->validatorSchema->setPostValidator(new sfValidatorSchemaCompare('mot_passe_confirmation', sfValidatorSchemaCompare::EQUAL, 'mot_passe',
  																array(),
  																array('invalid' => 'Les mots de passe ne correpondent pas')));
  }
  
  
  
  
  /**
   * Action qui remplie le formulaire en fonction du request
   * @see lib/symfony/form/sfForm#bind()
   */
  public function bind(array $taintedValues = null, array $taintedFiles = null)
  {
  		if(empty($taintedValues['mot_passe']) && empty($taintedValues['mot_passe_confirmation']))
  		{
  			//Les deux mots de passe n'ont pas été définis, l'utilisateur ne veut
  			//donc pas les changer. On ne traite pas ces champs.
  			
  			//On mets les validateurs de ses champs tous passifs
  			$this->setValidator('mot_passe', new sfValidatorPass());
  			$this->setValidator('mot_passe_confirmation', new sfValidatorPass());
  			$this->validatorSchema->setPostValidator(new sfValidatorPass());
  			
  			//Note: Lors de la sauvegarde du formulaire, le mot de passe
  			//ne sera pas change car dans le setter du mot de passe,
  			//il ne se change pas si la valeur donnee est nulle ou vide.
  		}
  		
  		//Appel méthode parent
  		parent::bind($taintedValues, $taintedFiles);
  }
}