<?php

/**
 * messagerie actions.
 *
 * @package    anbnws
 * @subpackage messagerie
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 154 2009-08-07 09:36:18Z sjeandroz $
 */
class messagerieActions extends sfActions
{

	//Affiche la liste des messages de la boite de reception
	public function executeIndex(sfWebRequest $request)
	{
		//On recupere l'objet membre de la personne connectee
		$membre = MembreTable::getMembreConnecte();
		
		$this->liste_messages = $membre->getBoiteReception();
		
		//on appel la fonction qui compte le nombre de messages non lus et qui stocke ce nombre en session
		$user = $this->getUser()->CheckMessagerie();
	}
	
	//Action qui supprime une liste de messages
	public function executeDeleteMessages(sfWebRequest $request)
	{
		$this->forward404Unless($request->getMethod() == sfRequest::POST);
		$user = $this->getUser();
		
		//On recupere la liste des messages à supprimer
		$liste_messages_a_supprimer = $request->getParameter('delete_msg');
		
		//Si pas de messages à supprimer, erreur
		if(!is_array($liste_messages_a_supprimer) || count($liste_messages_a_supprimer) == 0)
		{
			$user->setFlash('messages_error', 'Vous devez sélectionner au moins un message');
			$this->redirect('messagerie/index');
		}
		
		//Si plus de 50 messages à supprimer, message d'erreur
		if(count($liste_messages_a_supprimer) > 50)
		{
			$user->setFlash('messages_error', 'Impossible de supprimer plus de 50 messages');
			$this->redirect('messagerie/index');
		}
		
		//On recupere l'ID de la personne connecte
		$membre_id = MembreTable::getMembreIdConnecte();
		
		//Pour chaque message à supprimer, on verifie que la personne soit la bonne
		//et on supprime
		foreach($liste_messages_a_supprimer as $message_id)
		{
			$message = Doctrine::getTable('Message')->find($message_id);
			
			if(empty($message))
			{
				//Message pas trouve
				$user->setFlash('messages_error', 'Tous les messages n\'ont pas pu être supprimés.');
			}
			else
			{
				//Message trouve en BDD
				if($message->getDestinataireMembreId() == $membre_id)
				{
					//L'utilisateur est bien le bon, on peu supprime
					$message->delete();
					$user->setFlash('messages_ok', 'Message(s) supprimé(s)');
				}
				else
				{
					//L'utilisateur n'a pas le droit de supprimer le message
					$user->setFlash('messages_error', 'Tous les messages n\'ont pas pu être supprimés.');
				}
			}
		}
		
		$this->redirect('messagerie/index');
	}
	
	
	
	//Action qui supprime un message
	public function executeDeleteMessage(sfWebRequest $request)
	{
		
		$message = Doctrine::getTable('Message')->find(array($request->getParameter('id')));
		$this->forward404Unless($message, 'Object Message does not exists');
		
		//On recupere l'id de la personne qui est connectee
		$membre_id = MembreTable::getMembreIdConnecte();
		$user = $this->getUser();
		
		if($message->getDestinataireMembreId() == $membre_id)
		{
			//L'utilisateur est bien le bon, on peu supprime
			$message->delete();
			$user->setFlash('messages_ok', 'Messages supprimé');
		}
		else
		{
			//L'utilisateur n'a pas le droit de supprimer le message
			$user->setFlash('messages_error', 'Impossible de supprimer ce message');
		}
		
		//On redirige vers la boite de reception
		$this->redirect('messagerie/index');
	}
	
	
	
	//Action qui lit un message
	public function executeLire(sfWebRequest $request)
	{
		$this->message = $this->afficheMessage($request);
		
		//on appel la fonction qui compte le nombre de messages non lus et qui stocke ce nombre en session
		$user = $this->getUser()->CheckMessagerie();
	}
	
	
	//Action qui affiche le formulaire pour répondre à un message
	public function executeRepondre(sfWebRequest $request)
	{
		//On recupere le message d'origine
		$this->message = $this->afficheMessage($request);
		
		//On cree le formulaire
		$this->form = new MessageForm();
		
		//On configure le champ caché du formulaire, qui définit le destinataire
		$destinataire_id = $this->message->getExpediteurMembreId();
		$this->form->setDefault('destinataire_membre_id', $destinataire_id);
		$this->destinataire = $this->message->getExpediteurMembre();
		
		//On configure l'objet par défault
		$objet = 'Re: '.$this->message->getTitre();
		$this->form->setDefault('titre', $objet);
	}
	
	
	
	//Action qui affiche le formulaire pour ecrire un message
	public function executeEcrire(sfWebRequest $request)
	{
		//On recuperer l'ID du destinataire
		$destinataire = Doctrine::getTable('Membre')->find(array($request->getParameter('id')));
		$this->forward404Unless($destinataire, 'Object Membre does not exists');
		
		//Si le destinataire n'est pas actif, erreur 404
		$this->forward404Unless($destinataire->getConfirmation(), 'Membre non actif');
		
		//On cree le formulaire
		$this->form = new MessageForm();
		
		//On configure le champ caché du formulaire, qui définit le destinataire
		$this->form->setDefault('destinataire_membre_id', $destinataire->getId());
	}
	
	
	
	//Action qui traite le formulaire d'envoi d'une réponse à un message
	public function executeEnvoyerReponse(sfWebRequest $request)
	{
		$this->forward404Unless($request->getMethod() == sfRequest::POST);
		
		$this->form = new MessageForm();
		$this->processFormSubmit($request, $this->form);
		
		//On recupere le message d'origine
		$this->message = $this->afficheMessage($request);
		$this->destinataire = $this->message->getExpediteurMembre();
		
		$this->setTemplate('repondre');
	}
	
	
	
	//Action qui traite le formulaire d'envoi d'un nouveau message
	public function executeEnvoyerMessage(sfWebRequest $request)
	{
		$this->forward404Unless($request->getMethod() == sfRequest::POST);
		
		$this->form = new MessageForm();
		$this->processFormSubmit($request, $this->form);
		
		$this->setTemplate('ecrire');
	}
	
	
	
	
	
	//Fonction privee, qui fait le necessaire pour afficher un message
	private function afficheMessage($request)
	{
		//On recupere l'ID du message à afficher
		//Erreur 404 si message non existant
		$message = Doctrine::getTable('Message')->find(array($request->getParameter('id')));
		$this->forward404Unless($message, 'Object Message does not exists');
		
		//On recupere l'id de la personne connectee
		$membre_id = MembreTable::getMembreIdConnecte();
		
		//On verifie que la personne a le droit de consulter le message
		//Sinon erreur 404
		if($message->getDestinataireMembreId() != $membre_id)
		{
			$this->forward404('Pas les droits');
		}
		
		//On passe le message en tant que "lu"
		if($message->getLu() == 0)
		{
			$message->setLu(1);
			$message->save();
		}
		return $message;
	}
	
	
	//Fonction privee qui traite le formulaire d'envoi
	private function processFormSubmit(sfWebRequest $request, sfForm $form)
	{
		$form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
		$user = $this->getUser();
		
		if ($form->isValid())
		{
			//On récupère l'objet "Message"
			$message = $form->getObject();
			
			//On regarde si la personne ne s'envoie pas le message à lui meme
			$membre_id_connecte = MembreTable::getMembreIdConnecte();
			$destinataire_id = $form->getValue('destinataire_membre_id');
			
			if($destinataire_id == $membre_id_connecte)
			{
				//La personne essaie de s'envoyer le mail à lui meme, message d'erreur
				$user->setFlash('messages_error', 'Impossible de s\'envoyer le mail à soit meme');
			}
			else
			{
				//On ajoute l'expediteur
				$message->setExpediteurMembreId($membre_id_connecte);
				
				//On sauvegarde le message
				$message = $form->save();
				
				//On redirige vers la boite de reception avec un message de confirmation
				$user->setFlash('messages_ok', 'Message envoyé');
				$this->redirect('messagerie/index');
			}
		}
	}
}
