<?php

/**
 * reportages actions.
 *
 * @package    anbnws
 * @subpackage reportages
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 440 2010-09-29 11:49:55Z hlecorche $
 */
class reportagesActions extends sfActions
{
	
	/**
	 * ******************************************************
	 * 
	 * Actions générales
	 * 
	 * ******************************************************
	 */
	
	//Action principale, redirige vers les reportages photos
	public function executeIndex(sfWebRequest $request)
	{
		$this->forward('reportages', 'listeReportagePhotos');
	}
	
	
	
	/**
	 * Action qui affiche la liste des médias d'un reportage, puis affiche 
	 * le partial _zoom_reportage par défaut et après on change en AJAX
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	public function executeZoom(sfWebRequest $request)
	{
		//On recupere l'objet Reportage que l'on veut recuperer
		//avec les jointures sur le lieu, le membre reporter,
		//et l'évenement (si PRESENT)
		$reportage = Doctrine::getTable('Reportage')->findReportageJoinAll(array($request->getParameter('id')));
		$this->forward404Unless($reportage, 'Object Reportage does not exists');
		
		//On prepare les infos du reportage à envoyer au template
		$this->getInformationsForShowReportage($reportage, 1, false);
				
		$this->reportage = $reportage;
	}
	
	
	//Action qui affiche la liste des reportages
	public function executeListeReportages(sfWebRequest $request)
	{
		//On récupère le type de reportage à afficher (media = photos ou media = videos)
		$type_media = $request->getParameter('media');
		$this->forward404Unless(in_array($type_media, array('photos', 'videos')));
		if($type_media == 'photos')
		{
			$is_video = false;
		}
		else
		{
			/*
			 * TODO
			 * Rubrique desactivee
			 */
			$this->forward404('Rubrique desactivee');
			$is_video = true;
		}
		
		//Configuration
		$this->nom_session = 'reportages_'.$type_media;
		$this->url_page = $this->getModuleName().'/'.$this->getActionName().'?media='.$type_media;
		$user = $this->getUser();
		
		if($request->isMethod(sfRequest::POST) || $request->hasParameter('categorie'))
		{
			//On vient du formulaire du changement des propriétés d'affichage
			//Ou alors on vient d'un reportage (fil arianne) et on filtre avec une categorie
			//on modifie les paramètres
			$this->changeDisplay($this->nom_session, $request);
		}
		

		//On cree le pager de résultats

		$this->pager = Doctrine::getTable('Reportage')->generatePager($this->nom_session, $is_video);
		$this->pager->setPage($this->getRequestParameter('page',1));
		$this->pager->init();
		
		
		//Données fournis au formulaire de recherche
		//Liste des catégories
		$this->liste_categories = Doctrine::getTable('Type')->getTypesSoireesForm();
		$this->liste_tri = array(0 => 'Trier par...', 1 => 'Trier par nom', 2 => 'Trier par date');
		$this->liste_ordre = array(0 => 'Croissant', 1 => 'Décroissant');
		$this->liste_nombre_pages = array(18 => '18', 24 => '24', 64 => '64');
		//Valeurs par défaults du formulaire
		$this->selected_categorie = $user->getAttribute($this->nom_session.'_categorie', 0);
		$this->selected_tri = $user->getAttribute($this->nom_session.'_tri', 0);
		$this->selected_nombre_pages = $user->getAttribute($this->nom_session.'_nombre_pages', 64);
		$this->selected_ordre = $user->getAttribute($this->nom_session.'_ordre', 1);

		$this->setTemplate('list');
	}
	
	
	//Action qui affiche directement un média (si on vient du profil d'un utilisateur
	//par exemple). Utilise le template zoom mais affiche directement le media dans le partial
	public function executeZoomMedia(sfWebRequest $request)
	{
		//On recupere l'id du media à afficher, erreur 404 si non existante dans la table
		$media = Doctrine::getTable('ReportageMedia')->find(array($request->getParameter('id')));
		$this->forward404Unless($media, 'Object Media does not exists');
		
		//Explications: On affiche le reportage associe au media. Une fois le template du reportage
		//chargé, une requete ajax sera executee pour afficher le media souhaite.
		
		//On recupere l'objet Reportage que l'on veut recuperer
		//avec les jointures sur le lieu, le membre reporter,
		//et l'évenement (si PRESENT)
		$reportage = Doctrine::getTable('Reportage')->findReportageJoinAll($media->getReportageId());
		$this->forward404Unless($reportage, 'Object Reportage does not exists');
		
		//On prepare les infos du reportage à envoyer au template
		$this->getInformationsForShowReportage($reportage, 1, false);
				
		$this->reportage = $reportage;
		$this->media_id = $media->getId();
		$this->direct_media = true;
		
		$this->setTemplate('zoom');
	}
	
	
	
	
	//Action qui affiche et qui traite le formulaire d'envoi d'ecard
	public function executeCreateEcard(sfWebRequest $request)
	{
		//On verifie que le media existe, sinon erreur 404
		$media = Doctrine::getTable('ReportageMedia')->find(array($request->getParameter('id')));
		$this->forward404Unless($media, 'Object Media does not exists');
		
		//On verifie que le media n'est pas une video, sinon erreur 404
		$this->forward404Unless(!$media->getisVideo());
		
		//On verifie que le reportage soit actif, sinon erreur 404
		$reportage = $media->getReportage();
		$this->forward404Unless($reportage->getActive());
		
		$this->form = new ReportageEcardForm();
		if($request->getMethod() == sfRequest::POST)
		{
			//On traite le formulaire
			$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
			if ($this->form->isValid())
			{
				$this->form->processForm($this);
				$this->redirect('reportages/confirmEcard');
			}
		}
		
		$this->media = $media;
		$this->reportage = $reportage;
		$this->setTemplate('ecard/createEcard');
	}
	
	//Action qui affiche le message de confirmation d'ajout d'une ecard
	public function executeConfirmEcard(sfWebRequest $request)
	{
		$this->setTemplate('ecard/confirmEcard');
	}
	
	//Action qui affiche une ecard
	public function executeZoomEcard(sfWebRequest $request)
	{
		//On verifie que l'ecard existe, sinon erreur 404
		$ecard = Doctrine::getTable('ReportageEcard')->findJoinAll(array($request->getParameter('id')));
		$this->forward404Unless($ecard, 'Object ReportageEcard does not exists');
		
		//On verifie que la personne dispose du bon code, sinon erreur 404
		$this->forward404Unless($cle = $request->getParameter('cle'), sprintf('The key is missed (%s).', $request->getParameter('cle')));
		if($cle != $ecard->getCodeVisualisation())
		{
			$this->forward404('Mauvaise cle');
		}
		
		//Si ecard, non lu, on la passe en lu
		if($ecard->getLu() == 0)
		{
			$ecard->setLu(1);
			$ecard->save();
		}
		
		$this->ecard = $ecard;
		$this->media = $ecard->getReportageMedia();
		$this->reportage = $this->media->getReportage();
		$this->setTemplate('ecard/zoomEcard');
	}
	
	
	/**
	 * ******************************************************
	 * 
	 * Actions Ajax
	 * 
	 * ******************************************************
	 */
	
	
	
	public function executeAjaxZoomReportage(sfWebRequest $request)
	{
		//On verifie que l'on vient bien d'une requete ajax
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On recupere l'objet Reportage que l'on veut recuperer
		$reportage = Doctrine::getTable('Reportage')->find(array($request->getParameter('id')));
		$this->forward404Unless($reportage, 'Object Reportage does not exists');
		
		//On recupere le numero de page à afficher
		$page = $request->getParameter('page', 1);
		
		//On prepare les infos du reportage à envoyer au template
		$this->getInformationsForShowReportage($reportage, $page, 1);
						
		$this->reportage = $reportage;
		
		return $this->renderPartial('reportages/zoom_reportage');
		
	}
	
	
	
	/**
	 * Action Ajax qui permet d'afficher un media (photo ou video) . Utilise la partial
	 * "_ajax/zoomPhoto" si photo (ou "_ajax/zoomVideo si video)
	 * qui remplace le contenu du div "contenu_reportage"
	 * du template "zoomSuccess".
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	public function executeAjaxZoomMedia(sfWebRequest $request)
	{
		//On verifie que l'on vient bien d'une requete ajax
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On regarde si la personne est connectee. Dans le cas contraire, renvoie d'une image
		//l'invitant à se connecter.
		$user = $this->getUser();
		if(!$user->isAuthenticated())
		{
			return $this->renderPartial('reportages/ajax/erreurConnexion');
		}
		
		//On recupere l'id du media à afficher, erreur 404 si non existante dans la table
		//On fait aussi une jointure avec la table reportage pour recuperer les infos du reportage
		//associe
		$media = Doctrine::getTable('ReportageMedia')->findJoinReportage(array($request->getParameter('id')));
		$this->forward404Unless($media, 'Object Media does not exists');

		$this->media = $media;
		
		if($media->getIsVideo())
		{
			//On prepare les informations necessaires à l'affichage de la photo
			$this->getInformationsForShowVideo($media, $request);
			
			//On affiche le template d'affichage des photos
			return $this->renderPartial('reportages/ajax/zoomVideo');
		}
		else
		{
			//On prepare les informations necessaires à l'affichage de la photo
			$this->getInformationsForShowPhoto($media, $request);
			
			//On affiche le template d'affichage des photos
			return $this->renderPartial('reportages/ajax/zoomPhoto');
		}		
	}
	
	
	/**
	 * Action qui ajoute une photo dans la galerie photos de la personne connectee
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	public function executeAjaxAjouterFavoris(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On verifie que le media donne existe en base de donnees
		$media = Doctrine::getTable('ReportageMedia')->find(array($request->getParameter('id')));
		$this->forward404Unless($media, 'Object Media does not exists');
		
		//On verifie que le media donne est une photo (et pas une video)
		if($media->getIsVideo())
		{
			$this->forward404();
		}
		
		//On verifie que la personne est connectee
		$user = $this->getUser();
		if(!$user->isAuthenticated())
		{
			return $this->renderPartial('reportages/ajax/erreurConnexion');
		} 
		
		//On recupere l'objet de la personne connecte
		$membre = MembreTable::getMembreConnecte();
		
		//On recupere la liste des images favorites de la personne
		$liste_images_favorites = $membre->getTableImagesFavorites();
		
		//On verifie que la personne a pas + du nombre maxi autorise d'images dans sa galerie
		$error = false;
		$maxi_autorise = sfConfig::get('app_reportages_nbre_maxi_favoris', 50);
		if(count($liste_images_favorites) > $maxi_autorise)
		{
			$error = true;
			$user->setFlash('reportages_add_favori_error', 'Vous pouvez avoir que '.$maxi_autorise.' images maxi dans vos favoris.', false);
		}
		
		//On verifie que la personne n'a deja pas l'image dans ses favoris
		if(in_array($media->getId(), $liste_images_favorites))
		{
			$error = true;
			$user->setFlash('reportages_add_favori_error', 'Vous avez déjà cette image dans vos favoris', false);
		}
		
		//On ajoute l'image dans ses favoris et on affiche un message de confirmation
		if(!$error)
		{
			$favori = new ReportageFavori();
			$favori->setMembreId($membre->getId());
			$favori->setReportageMediaId($media->getId());
			$favori->save();
			$user->setFlash('reportages_add_favori_ok', 'Photo ajoutée à votre galerie', false);
		}

		//On prepare les informations necessaires à l'affichage de la photo
		$this->getInformationsForShowPhoto($media, $request);
		$this->media = $media;
		
		return $this->renderPartial('reportages/ajax/actionsPhoto');
	}
	
	//Ajoute la photo en image de profil
	public function executeAjaxAjouterImageProfil(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On verifie que le media donne existe en base de donnees
		$media = Doctrine::getTable('ReportageMedia')->find(array($request->getParameter('id')));
		$this->forward404Unless($media, 'Object Media does not exists');
		
		//On verifie que le media donne est une photo (et pas une video)
		if($media->getIsVideo())
		{
			$this->forward404();
		}
		
		//On verifie que la personne est connectee
		$user = $this->getUser();
		if(!$user->isAuthenticated())
		{
			return $this->renderPartial('reportages/ajax/erreurConnexion');
		} 
		
		//On recupere l'objet de la personne connecte
		$membre = MembreTable::getMembreConnecte();
		
		//On regarde si le membre a déjà une image de profil. Si oui, on la supprime
		$dossier_membre = sfConfig::get('app_uploads_images_membres');
		$ancien_fichier = $membre->getImageProfil();
		if(!empty($ancien_fichier) && file_exists($dossier_membre.'/'.$ancien_fichier))
		{
			//Fichier présent, on le supprime
			unlink($dossier_membre.'/'.$ancien_fichier);
		}
		
		//On copie le nouveau fichier
		$dossier_reportage = sfConfig::get('app_uploads_images_reportages').'/'.$media->getReportage()->getId();
		$media_file = $dossier_reportage.'/'.$media->getNomFichier();
		$extension = stristr($media->getNomFichier(), '.');
		$nouveau_fichier = $membre->getId().'mbr'.$extension;
		$nouveau_fichier_file = $dossier_membre.'/'.$nouveau_fichier;
		copy($media_file, $nouveau_fichier_file);
		
		//Mise à jour de la BDD
		$membre->setImageProfil($nouveau_fichier);
		$membre->save();
		
		//On supprime le cache des images de profil de la personne
		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_membres').'/'.$membre->getId();
		Util::deleteFolder($folder_cache);
		
		$user->setFlash('reportages_add_favori_ok', 'Photo ajoutée à votre profil', false);

		//On prepare les informations necessaires à l'affichage de la photo
		$this->getInformationsForShowPhoto($media, $request);
		$this->media = $media;
		
		return $this->renderPartial('reportages/ajax/actionsPhoto');
	}
	
	
	/**
	 * Action qui ajoute un commentaire à un media
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	public function executeAjaxAjouterCommentaire(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On verifie que l'id du media est bien precise, et qu'il existe
		$media = Doctrine::getTable('ReportageMedia')->find(array($request->getParameter('id')));
		$this->forward404Unless($media, 'Object Media does not exists');
		
		//On recupere le formulaire, on le bind
		$this->form_comment = new ReportageCommentForm();
		$this->form_comment->bind($request->getParameter($this->form_comment->getName()), $request->getFiles($this->form_comment->getName()));
		
		//On regarde si la personne est connectee, sinon message d'erreur
		$can_add = true;
		$user = $this->getUser();
		if(!$user->isAuthenticated())
		{
			$user->setFlash('reportages_add_comment_error', 'Vous devez être connecté pour pouvoir ajouter un commentaire', false);
			$can_add = false;
		}
		
		if($this->form_comment->isValid() && $can_add)
		{
			//Le formulaire est valide
			//On traite le formulaire
			$this->form_comment->processForm($media);
			
			$user->setFlash('reportages_add_comment_ok', 'Commentaire ajouté', false);
			
			//On cree un nouveau formulaire (pour vider l'ancien)
			$this->form_comment = new ReportageCommentForm(); 
		}
			
		//On passe le media et les commentaires au template
		$this->media = $media;
		$this->liste_commentaires = $media->getReportagesCommentsJoinMembre();
			
		//On affiche le template des actions du media (template different si photo ou video)
		if($media->getIsVideo())
		{
			//Template d'actions pour une video
			return $this->renderPartial('reportages/ajax/actionsVideo');
		}
		else
		{
			//Template d'actions pour une photo
			return $this->renderPartial('reportages/ajax/actionsPhoto');
		}
		
	}
	
	
/**
	 * Action qui ajoute un reportage dans les reportages presents de la personne connectee
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	public function executeAjaxEtaitPresent(sfWebRequest $request)
	{
		$this->forward404Unless($request->isXmlHttpRequest());
		
		//On verifie que le reportage donne existe en base de donnees
		$reportage = Doctrine::getTable('Reportage')->find(array($request->getParameter('id')));
		$this->forward404Unless($reportage, 'Object Reportage does not exists');
		
		//On verifie que le reportage donne est actif
		if(!$reportage->getActive())
		{
			$this->forward404();
		}
		
		//On verifie que la personne est connectee
		$user = $this->getUser();
		if(!$user->isAuthenticated())
		{
			return $this->renderPartial('reportages/ajax/erreurConnexion');
		} 
		
		//On recupere l'objet de la personne connecte
		$membre = MembreTable::getMembreConnecte();
		
		//On recupere la liste des inscriptions aux reportages de la personne connectee
		//Si reportage deja present, message d'erreur
		$nombre_results = Doctrine::getTable('ReportageInscription')->createQuery('i')
		->where('i.reportage_id = ?', $reportage->getId())
		->addWhere('i.membre_id = ?', $membre->getId())
		->count();
		if($nombre_results > 0)
		{
			//Reportage deja present
			$message = '<span style="color: red;">Vous êtes déjà inscit à ce reportage.</span>';
			return $this->renderText($message);
		}
		
		//On ajoute le reportage dans les inscriptions du membre et on affiche un message de confirmation
		$membre->ReportagesPresents[] = $reportage;
		$membre->save();
		$message = '<span style="color: green;">Inscription au reportage validée.</span>';
		return $this->renderText($message);
	}
	
	
	
	
	/**
	 * ******************************************************
	 * 
	 * Methodes privees
	 * 
	 * ******************************************************
	 */
	
	/**
	 * Prepare toutes les informations nécessaires (pour envoyer au template)
	 * necessaire pour l'affiche d'un reportage (liste des médias)
	 * @param Reportage $reportage
	 * @param Int $page page à afficher
	 * @param Bool $is_ajax Si vrai, on affiche le reportage depuis un appel ajax
	 * @return unknown_type
	 */
	private function getInformationsForShowReportage(Reportage $reportage, $page = 1, $is_ajax = false)
	{
		//Si le reportage n'est pas actif, erreur 404
		$this->forward404Unless($reportage->getActive());
				
		//On recupere les medias
		$max_results  = sfConfig::get('app_reportages_nbre_elements_liste_medias', 40);
		$pager = new sfDoctrinePager('ReportageMedia', $max_results);
		//On definit le tri ascendant par ID
		$query = $pager->getQuery();
		$query->orderBy('id ASC');
		$query->addWhere('reportage_id = ?', $reportage->getId());
		$pager->setPage($page);
		$pager->init();
		$this->pager = $pager;
		
		if(!$is_ajax)
		{
			//On veut afficher un reportage mais depuis une requette HTTP et non pas depuis une
			//requete AJAX.
			//On definie alors les objets necessaires pour afficher les détails du reportage
			//Si on a une requete AJAX, ces informations sont déjà affichees sur le template
			//du client, donc ne refait pas les requetes en BDD.
		
			//On recupere le nombre de commentaires
			$this->nombre_commentaires = $reportage->countComments();
			
			//On recupere la liste des derniers evenements associee au lieu du reportage
			$q = Doctrine::getTable('Evenement')->createQuery('e')
			->orderBy('e.date_debut DESC')->limit(10);
			$this->liste_derniers_evenements = $reportage->getLieu()->getEvenementsActifsPasses($q);
			
			//On recupere la liste des derniers autres reportages associes a ce lieu
			$q = Doctrine::getTable('Reportage')->createQuery('r')
			->orderBy('r.date DESC')->limit(10)
			->addWhere('r.id != ?', $reportage->getId());
			$this->liste_autres_reportages = $reportage->getLieu()->getReportagesActifs($q);
			
			//On recupere la liste des prochains evenements associee au lieu du reportage
			$q = Doctrine::getTable('Evenement')->createQuery('e')
			->orderBy('e.date_debut DESC')->limit(10);
			$this->liste_prochains_evenements = $reportage->getLieu()->getEvenementsActifsNonPasses($q);
	
		}
	}
	
	
	
	/**
	 * Prepare toutes les informations nécessaires (pour envoyer au template)
	 * necessaire pour l'affiche d'une photo
	 * @param ReportageMedia $media
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	private function getInformationsForShowPhoto(ReportageMedia $media, sfWebRequest $request)
	{
		//On regarde si la photo est bien un media de type "photo", sinon erreur 404
		$this->forward404Unless(!$media->getIsVideo());
		
		//On recupere les commentaires de ce media
		$this->liste_commentaires = $media->getReportagesCommentsJoinMembre();
		
		//On cree un formulaire de creation de commentaire
		$this->form_comment = new ReportageCommentForm();
		
		//On recupere le numero de page d'ou l'on vient (pour pouvoir creer
		//le bouton "Retour à la liste des medias"
		$this->page_liste = $request->getParameter('page', 1);
	}
	
	
	/**
	 * Prepare toutes les informations nécessaires (pour envoyer au template)
	 * necessaire pour l'affiche d'une video
	 * @param ReportageMedia $media
	 * @param sfWebRequest $request
	 * @return unknown_type
	 */
	private function getInformationsForShowVideo(ReportageMedia $media, sfWebRequest $request)
	{
		//On regarde si le media est bien un media de type "video", sinon erreur 404
		$this->forward404Unless($media->getIsVideo());
		
		//On recupere les commentaires de ce media
		$this->liste_commentaires = $media->getReportagesCommentsJoinMembre();
		
		//On cree un formulaire de creation de commentaire
		$this->form_comment = new ReportageCommentForm();
		
		//On recupere le numero de page d'ou l'on vient (pour pouvoir creer
		//le bouton "Retour à la liste des medias"
		$this->page_liste = $request->getParameter('page', 1);
	}
	
	
	
	/**
	 * Fonction qui change les priorités d'affichage sur la liste, et
	 * qui sauvegarde en session
	 * @param String $nom_session Nom de la session
	 * @param sfRequest $request
	 * @return unknown_type
	 */
	private function changeDisplay($nom_session, $request)
	{
		$user = $this->getUser();

		//Traitement du champ "categorie"
		$categorie = $request->getParameter('categorie');
		if(!is_null($categorie))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_categorie', $categorie);
		}



		//Traitement du champ 'tri'
		$tri = $request->getParameter('tri');
		if(!is_null($tri))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_tri', $tri);
		}

		//Traitement du champ 'nombre_pages'
		$nombre_pages = $request->getParameter('nombre_pages');
		if(!is_null($nombre_pages))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_nombre_pages', $nombre_pages);
		}

		//Traitement du champ 'ordre'
		$ordre = $request->getParameter('ordre');
		if(!is_null($ordre))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_ordre', $ordre);
		}
	}
}
