<?php
/**
 * This file is part of "AnnecyByNight"
 * Copyright (c) 2009 Hubert LECORCHE
 * 
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */


/**
 * Template qui affiche la liste des médias d'un reportage.
 * Contient par défaut le partial "zoom_reportage" et apres change
 * en AJAX
 *
 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>
 * @version    SVN: $Id: zoomSuccess.php 360 2010-08-19 13:10:25Z hlecorche $ 
 */

use_helper('Date');
use_helper('Text');
jq_add_plugin_ui();

?>

<!-- Fil d'arianne -->
<span class="texte_moyen texte_gras">
	<?php if($reportage->getIsReportageVideo()): ?>
		<?php echo link_to('Les reportages &gt;', 'reportages/listeReportages?media=videos', array('class' => 'texte_vert')) ?>
		&nbsp;&nbsp;
		<?php echo link_to($reportage->getLieu()->getType()->getNom().' &gt;', 'reportages/listeReportages?media=videos&categorie='.$reportage->getLieu()->getTypeId(), array('class' => 'texte_orange', 'style' => 'font-weight: bold;')) ?>
	<?php else: ?>
		<?php echo link_to('Les reportages &gt;', 'reportages/listeReportages?media=photos', array('class' => 'texte_vert')) ?>
		&nbsp;&nbsp;
		<?php echo link_to($reportage->getLieu()->getType()->getNom().' &gt;', 'reportages/listeReportages?media=photos&categorie='.$reportage->getLieu()->getTypeId(), array('class' => 'texte_orange', 'style' => 'font-weight: bold;')) ?>
	<?php endif; ?>
	
	&nbsp;&nbsp;
	<?php echo format_date($reportage->getDate(), 'dd/MM/yyyy') ?> 
	&nbsp;
	<?php echo truncate_text($reportage->getLieu()->getNom(),11 )?>
	&nbsp;
	<?php echo (count($reportage->getReporters()) > 1)? 'Reporters:' : 'Reporter:'; ?>
	<?php foreach($reportage->getReporters() as  $reporter) echo '&nbsp; '.link_to($reporter->getPseudo(), 'membres/profil?id='.$reporter->getId()).'&nbsp; '; ?>
</span>
<?php echo $nombre_commentaires; ?> commentaire(s)

<br />


<!-- Contenu central du reportage -->
<div id="contenu_reportage">
<?php if(!isset($direct_media)): 
	//On affiche par defaut la liste des medias
	include_partial('zoom_reportage', array('pager' => $pager,
											  'reportage' => $reportage));

else: 
//On affiche directement un media une fois la page chargee (dans le cas ou on vient du profil d'un membre) ?>

<script type="text/javascript">/* <![CDATA[ */
$(document).ready(function () {
	<?php echo jq_remote_function(array('url' => 'reportages/ajaxZoomMedia?id='.$media_id.'&page='.$pager->getPage(),
									   'update' => 'contenu_reportage',
									   'loading' => 'begin_ajax_reportage();',
									   'complete' => 'end_ajax_reportage();'
									   )) 
	?>
});
/* ]]> */</script>

<?php endif;?>
</div>






<!-- Détails sur reportage -->
<div id="details_reportage"> 
<br />
<div class="hr"></div>

<span class="texte_moyen texte_gras"><?php echo format_date($reportage->getDate(), 'dd/MM/yyyy') ?>   
	<?php echo $reportage->getLieu()->getNom() ?>  
	<?php echo $reportage->getTitre() ?>
</span>

<div id="inscription_reportage">
<?php echo image_tag('icones/16/user_green.png', array('alt' => 'user')) ?>
<?php echo jq_link_to_remote('J\'étais à cette soirée', 
 						 array('url' => 'reportages/ajaxEtaitPresent?id='.$reportage->getId(),
 						 	   'update' => 'inscription_reportage'),
 						 array('style' => 'color: green; font-weight: bold;')) ?>
</div> 

<table>
<tr style="vertical-align: top;">
	<td width="110">
		<?php foreach($reportage->getReporters() as $reporter): ?>
			<br />
			<?php echo link_to($reporter->getPseudo(), 'membres/profil?id='.$reporter->getId(),
								array('class' => 'texte_gras'))?>
			<?php $dossier = sfConfig::get('app_dossiers_images_membres') ?>
			<?php echo image_tag(Util::getUrlImage($dossier.'/'.$reporter->getFichierImageProfil(), 110),
									array('alt' => 'Image profil membre')) ?>
		<?php endforeach; ?>
	</td>
	
	<td width="332" style="text-align: center;">
		<a href="<?php echo url_for('main/devenirReporter') ?>">
			<?php echo image_tag('divers/pub-reporter.jpg', array('alt' => 'Toi aussi deviens photographe')) ?>
		</a>
	</td>
	
	<td width="190">
		<?php 
		$evenement = $reportage->getEvenement();
		if(!empty($evenement)):
		?>
			<!-- Informations sur l'evenement -->
			<b>C'était noté dans l'agenda !!!</b><br />
			<?php $dossier = sfConfig::get('app_dossiers_images_agenda') ?>
			<?php echo image_tag(Util::getUrlImage($dossier.'/'.$evenement->getImage_1(), 35),
								array('alt' => 'Image soiree',
									  'style' => 'float: left; display: inline;')) ?>
			<?php echo format_date($evenement->getDateDebut(), 'dd/MM/yyyy') ?> <br />
			<?php echo $evenement->getTitre() ?><br />
			
			<div style="clear: both;"></div><br />
		
		<?php endif;?>
		
		
		
		
		<!-- Informations sur le lieu -->
		<span class="texte_moyen texte_gras"><?php echo $reportage->getLieu()->getNom() ?></span> <br />
		<?php $dossier = sfConfig::get('app_dossiers_images_lieux') ?>
		<?php echo image_tag(Util::getUrlImage($dossier.'/'.$reportage->getLieu()->getImage_1(), 60),
							array('alt' => 'Image lieu',
								 'style' => 'float: left; display: inline;')) ?>
		<?php echo $reportage->getLieu()->getAdresse() ?>
		<?php echo $reportage->getLieu()->getCodePostal() ?>
		<?php echo $reportage->getLieu()->getVille() ?><br />
		<?php echo $reportage->getLieu()->getTelephone() ?>
		<div style="clear: both;"></div>
		<br/><br />
		
		
		<!-- Dernièrement dans ce lieu -->
		<div class="titre_moyen">Dernièrement dans ce lieu:</div>
		<?php if(count($liste_derniers_evenements) > 0): ?>
			<?php foreach($liste_derniers_evenements as $ev) :?>
				<a href="<?php echo url_for('agenda/zoom?id='.$ev->getId()) ?>">
					<?php echo format_date($ev->getDateDebut(), 'dd/MM/yyyy')?> 
					<?php echo truncate_text($ev->getTitre(), 15) ?>
				</a><br />
			<?php endforeach; ?>
		<?php else:?>
			Aucun événement...<br />
		<?php endif;?>
		<br />
		
		
		<!-- Autres reportages dans ce lieu -->
		<div class="titre_moyen">Autres reportgages:</div>
		<?php if(count($liste_autres_reportages) > 0): ?>
			<?php foreach($liste_autres_reportages as $rep) :?>
				<a href="<?php echo url_for('reportages/zoom?id='.$rep->getId()) ?>">
					<?php echo format_date($rep->getDate(), 'dd/MM/yyyy')?> 
					<?php echo truncate_text($rep->getTitre(), 15) ?>
				</a><br />
			<?php endforeach; ?>
		<?php else:?>
			Aucun reportage...<br />
		<?php endif;?>
		<br />
		
		<!-- Prochainement dans ce lieu  -->
		<div class="titre_moyen">Prochainement dans ce lieu:</div>
		<?php if(count($liste_prochains_evenements) > 0): ?>
			<?php foreach($liste_prochains_evenements as $ev) :?>
				<a href="<?php echo url_for('agenda/zoom?id='.$ev->getId()) ?>">
					<?php echo format_date($ev->getDateDebut(), 'dd/MM/yyyy')?> 
					<?php echo truncate_text($ev->getTitre(), 15) ?>
				</a><br />
			<?php endforeach; ?>
		<?php else:?>
			Aucun événement...<br />
		<?php endif;?>
	</td>
</tr>
</table>
</div>