<?php

/**
 * search actions.
 *
 * @package    anbnws
 * @subpackage search
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 360 2010-08-19 13:10:25Z hlecorche $
 */
class searchActions extends sfActions
{
	
	//Nom de variable de session
	const VAR_SESSION = 'criteres_recherche';

	
	/*
	 * *************************************
	 *
	 * Actions
	 *
	 * *************************************
	 */
	
	//Fonction qui affiche les resultats des recherches
	//ainsi que le formulaire de rercherche developpée
	public function executeIndex(sfWebRequest $request)
	{		
		//On creer le formulaire avec les valeurs par défauts (valeurs en session)
		$this->form = new SearchForm();
		
		//On prépare les résultats
		$this->generateResults($request);
		
		//On définie les valeurs par défauts du formulaire
		$criteres = $this->getUser()->getAttribute(self::VAR_SESSION, null);
		if(isset($criteres['text']) && strlen($criteres['text']) >= 4)
		{
			$this->form->setDefault('text', $criteres['text']);
		}
		if(isset($criteres['date']) && strlen($criteres['date']) >= 4)
		{
			$date_timestamp = Util::dateToTime($criteres['date']);
			$date = date('d/m/Y', $date_timestamp);
			$this->form->setDefault('date', $date);
		}
		$defaults_type = array();
		if(isset($criteres['search_photos']) && $criteres['search_photos'] == true)
		{
			$defaults_type[] = 'photos';
		}
		if(isset($criteres['search_videos']) && $criteres['search_videos'] == true)
		{
			$defaults_type[] = 'videos';
		}
		if(isset($criteres['search_agenda']) && $criteres['search_agenda'] == true)
		{
			$defaults_type[] = 'agenda';
		}
		if(isset($criteres['search_membres']) && $criteres['search_membres'] == true)
		{
			$defaults_type[] = 'membres';
		}
		$this->form->setDefault('type', $defaults_type);
		
		
	}
	
	
	//Fonction qui traite le formulaire de recherche simple
	public function executeRechercheSimple(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod(sfRequest::POST));
		
		//Vérifie présence donnée entrée
		$this->forwardUnless($text = $request->getParameter('search'), 'search', 'index');
		$text = trim($text);
		
		$user = $this->getUser();
		
		//Vérifie donnée entrée, si pas bonne message d'erreur
		if(strlen($text) < 4 || strlen($text) > 255 || $text == 'Recherche')
		{
			$user->setFlash('search_message_error', '4 caractères minimum, 255 maximum');
			$this->getUser()->setAttribute(self::VAR_SESSION, array()); //Quand formulaire pas valide, on vide
		//les anciennes criteres de recherches (bonnes) pour ne pas perturber l'utilisateur
			$this->redirect('search/index');
		}
		
		//Remplis la variable de session (toutes les valeurs)
		$var_session = array('text' => $text,
							 'search_photos' => true,
							 'search_videos' => true,
							 'search_agenda' => true,
							 'search_membres' => true,
							 'date' => null);
		$user->setAttribute(self::VAR_SESSION, $var_session);		
		
		//Redirige vers la page de résultats
		$this->redirect('search/index');
	}
	
	
	
	//Fonction qui traite le formulaire de recherche complete
	public function executeRecherche(sfWebRequest $request)
	{
		$this->forward404Unless($request->isMethod('post'));
		$this->form = new SearchForm();
		
		$this->form->bind($request->getParameter($this->form->getName()), $request->getFiles($this->form->getName()));
		if ($this->form->isValid())
		{
			$this->form->processForm($this);
			$this->redirect('search/index');
		}
		
		$this->setTemplate('index');
		$this->getUser()->setAttribute(self::VAR_SESSION, array()); //Quand formulaire pas valide, on vide
		//les anciennes criteres de recherches (bonnes) pour ne pas perturber l'utilisateur
		$this->generateResults($request);
	}
	
	
	
	/*
	 * *************************************
	 *
	 * Méthodes privées
	 *
	 * *************************************
	 */
	
	/**
	 * Fonction qui prepare les résultats de la recherche, transmis au template.
	 * @param sfRequest $request
	 * @return unknown_type
	 */
	protected function generateResults($request)
	{
		//On récupère les critères de recherche en session
		$criteres = $this->getUser()->getAttribute(self::VAR_SESSION, null);
		$this->active_recherche_photos = false;
		$this->active_recherche_videos = false;
		$this->active_recherche_agenda = false;
		$this->active_recherche_membres = false;
		
		if(isset($criteres['text']) && strlen($criteres['text']) >= 4)
		{
			//Valeur de critère OK, on va faire la recherche
			$text = '%'.$criteres['text'].'%';
			
			if(isset($criteres['search_photos']) && $criteres['search_photos'] == true)
			{
				//On decide de faire une recherche sur les rerportages photos
				$this->active_recherche_photos = true;
			
				//Recherche sur les reportages photos
				$query_reportages_photos = Doctrine::getTable('Reportage')->createQuery('r')
				->innerJoin('r.Lieu l')
				->innerJoin('l.Type t')
				->leftJoin('r.Evenement e')
				->select('r.id, r.titre, r.date, r.description, r.path_dossier, l.nom, t.nom, e.titre')
				->addselect('(SELECT m1.nom_fichier FROM ReportageMedia m1 WHERE m1.reportage_id = r.id and m1.is_video = 0 ORDER BY m1.id ASC LIMIT 1) as image_1')
				->addWhere('(r.is_reportage_video = 0 AND r.active = 1)')
				->addWhere('(r.titre LIKE ? OR l.nom LIKE ? OR e.titre LIKE ?)', array($text, $text, $text));
				
				if(isset($criteres['date']) && !is_null($criteres['date']))
				{
					$query_reportages_photos->addWhere('r.date = ?', $criteres['date']);
				}
				
				$query_reportages_photos->orderBy('r.date DESC, r.id DESC')
				->limit(20);
				
				$this->resultats_reportages_photos = $query_reportages_photos->execute();
				
				
			}
			
			
			
			
			
			if(isset($criteres['search_videos']) && $criteres['search_videos'] == true)
			{
				//On decide de faire une recherche sur les rerportages videos
				$this->active_recherche_videos = true;
			
				//Recherche sur les reportages videos
				$query_reportages_videos = Doctrine::getTable('Reportage')->createQuery('r')
				->innerJoin('r.Lieu l')
				->innerJoin('l.Type t')
				->leftJoin('r.Evenement e')
				->select('r.id, r.titre, r.date, r.description, l.nom, t.nom, e.titre')
				->addWhere('(r.is_reportage_video = 1 AND r.active = 1)')
				->addWhere('(r.titre LIKE ? OR l.nom LIKE ? OR e.titre LIKE ?)', array($text, $text, $text));
				
				if(isset($criteres['date']) && !is_null($criteres['date']))
				{
					$query_reportages_videos->addWhere('r.date = ?', $criteres['date']);
				}
				
				$query_reportages_videos->orderBy('r.date DESC, r.id DESC')
				->limit(20);
				
				$this->resultats_reportages_videos = $query_reportages_videos->execute();
				
			}
			
			
			
			
			
			if(isset($criteres['search_agenda']) && $criteres['search_agenda'] == true)
			{
				//On decide de faire une recherche sur les evenements
				$this->active_recherche_agenda = true;
			
				//Recherche sur les evenements
				$query_agenda = Doctrine::getTable('Evenement')->createQuery('e')
				->innerJoin('e.Lieu l')
				->innerJoin('l.Type t')
				->select('e.id, e.titre, e.date_debut, e.description, e.image_1, l.nom, t.nom')
				->addWhere('(e.active = 1)')
				->addWhere('(e.titre LIKE ? OR l.nom LIKE ?)', array($text, $text));
				
				if(isset($criteres['date']) && !is_null($criteres['date']))
				{
					$query_agenda->addWhere('e.date_debut = ?', $criteres['date']);
				}
				
				$query_agenda->orderBy('e.date_debut DESC, e.id DESC')
				->limit(20);
				
				$this->resultats_agenda= $query_agenda->execute();
				
			}
			
			
			
			
			
			
			if(isset($criteres['search_membres']) && $criteres['search_membres'] == true)
			{
				//On decide de faire une recherche sur les membres
				$this->active_recherche_membres = true;
			
				//Recherche sur les membres
				$query_membres = Doctrine::getTable('Membre')->createQuery('m')
				->select('m.id, m.pseudo, m.image_profil')
				->addWhere('m.confirmation = 1')
				->addWhere('m.pseudo LIKE ?', $text)
				->orderBy('m.pseudo ASC')
				->limit(20);
				
				$this->resultats_membres= $query_membres->execute();
				
			}
		}
	}
}
