<?php

/**
 * videos actions.
 *
 * @package    anbnws
 * @subpackage videos
 * @author     Hubert LECORCHE
 * @version    SVN: $Id: actions.class.php 431 2010-09-27 14:42:23Z hlecorche $
 */
class videosActions extends sfActions
{
	/**
	 * ******************************************************
	 * 
	 * Actions générales
	 * 
	 * ******************************************************
	 */
	
	//Action qui affiche la liste des videos
	public function executeIndex(sfWebRequest $request)
	{
		//Configuration
		$this->nom_session = 'videos';
		$this->url_page = $this->getModuleName().'/'.$this->getActionName();
		$user = $this->getUser();
		
		if($request->isMethod(sfRequest::POST) || $request->hasParameter('categorie'))
		{
			//On vient du formulaire du changement des propriétés d'affichage
			//on modifie les paramètres
			$this->changeDisplay($this->nom_session, $request);
		}
		
		//On cree le pager de résultats
		$this->pager = Doctrine::getTable('Video')->generatePager($this->nom_session);
		$this->pager->setPage($this->getRequestParameter('page',1));
		$this->pager->init();
		
		//Données fournis au formulaire de recherche
		//Liste des catégories
		$this->liste_categories = Doctrine::getTable('VideoCategorie')->getVideoCategoriesForm();
		$this->liste_tri = array(0 => 'Trier par...', 1 => 'Trier par titre', 2 => 'Trier par date');
		$this->liste_ordre = array(0 => 'Croissant', 1 => 'Décroissant');
		$this->liste_nombre_pages = array(12 => '12', 24 => '24', 64 => '64');
		//Valeurs par défaults du formulaire
		$this->selected_categorie = $user->getAttribute($this->nom_session.'_categorie', 0);
		$this->selected_tri = $user->getAttribute($this->nom_session.'_tri', 0);
		$this->selected_nombre_pages = $user->getAttribute($this->nom_session.'_nombre_pages', 64);
		$this->selected_ordre = $user->getAttribute($this->nom_session.'_ordre', 1);
		
		$this->setTemplate('list');
	}
	
	//Action qui affiche une video
	public function executeZoom(sfWebRequest $request)
	{
		//On regarde si la personne est connectee. Dans le cas contraire, renvoie d'une image
		//l'invitant à se connecter.
		$user = $this->getUser();
		if(!$user->isAuthenticated())
		{
			$this->forward('videos', 'erreurConnexion');
		}
		
		//On recupere l'id du media à afficher, erreur 404 si non existante dans la table
		$video = Doctrine::getTable('Video')->findVideoJoinAll(array($request->getParameter('id')));
		$this->forward404Unless($video, 'Object Video does not exists');
		
		//Si la video n'est pas active, erreur 404
		$this->forward404Unless($video->getActive(), 'Vidéo pas active');
		$this->video = $video;
		$this->page_list = $request->getParameter('p', 1);
	}
	
	
	//Action qui affiche l'erreur si pas connecte
	public function executeErreurConnexion(sfWebRequest $request)
	{
	}
	
	
	/**
	 * ******************************************************
	 * 
	 * Méthodes privées
	 * 
	 * ******************************************************
	 */
	
	
	/**
	 * Fonction qui change les priorités d'affichage sur la liste, et
	 * qui sauvegarde en session
	 * @param String $nom_session Nom de la session
	 * @param sfRequest $request
	 * @return unknown_type
	 */
	private function changeDisplay($nom_session, $request)
	{
		$user = $this->getUser();

		//Traitement du champ "categorie"
		$categorie = $request->getParameter('categorie');
		if(!is_null($categorie))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_categorie', $categorie);
		}



		//Traitement du champ 'tri'
		$tri = $request->getParameter('tri');
		if(!is_null($tri))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_tri', $tri);
		}

		//Traitement du champ 'nombre_pages'
		$nombre_pages = $request->getParameter('nombre_pages');
		if(!is_null($nombre_pages))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_nombre_pages', $nombre_pages);
		}

		//Traitement du champ 'ordre'
		$ordre = $request->getParameter('ordre');
		if(!is_null($ordre))
		{
			//Le champ est présent, on modifie la valeur
			$user->setAttribute($nom_session.'_ordre', $ordre);
		}
	}
}
