<?php

/**

 * This file is part of "anbnws"

 * Copyright (c) 2009 Hubert LECORCHE

 * 

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Formulaire qui permet de choisir la partie des images des événements, à afficher

 *

 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: EvenementImageTruncateForm.class.php 336 2010-01-11 11:09:36Z hlecorche $ 

 */



class EvenementImageTruncateForm extends BaseEvenementForm

{

	protected $num_image;				// Numéro de l'image

	protected $source_file_name;		// Chemin du fichier source

	protected $source_width;			// Largeur de l'image source

	protected $source_height;			// Hauteur de l'image source

	protected $source_width_resize;		// Largeur de l'image source, lors de l'affichage du formulaire

	protected $source_height_resize;	// Hauteur de l'image source, lors de l'affichage du formulaire

	protected $source_resize_factor;	// Nombre à multiplier par $source_height pour avoir $source_height_resize (idem pour width)

	protected $source_mine;				// Mine Type de l'image

	protected $ratio;					// Largeur de l'image source / Hauteur de l'image source

	

	public function configure()

	{

		//Champs desactives

		unset($this['id']);

		unset($this['active']);

		unset($this['type_id']);

		unset($this['lieu_id']);

		unset($this['auteur_membre_id']);

		unset($this['date']);

		unset($this['titre']);

		unset($this['description']);

		unset($this['active_index']);

		unset($this['created_at']);

		unset($this['image_1']);

		unset($this['image_2']);

		unset($this['image_1_truncate']);

		unset($this['image_2_truncate']);

		unset($this['heure_debut']);

		unset($this['heure_fin']);

		

		//On prepare les infos sur l'image

		$this->initImage();

		

		

		//Widget x1

		$this->setWidget('x1', new sfWidgetFormInputHidden());

		$this->setValidator('x1', new sfValidatorNumber(array('required' => true, 'min' => 0, 'max' => $this->source_width_resize)));

		

		//Widget y1

		$this->setWidget('y1', new sfWidgetFormInputHidden());

		$this->setValidator('y1', new sfValidatorNumber(array('required' => true, 'min' => 0, 'max' => $this->source_height_resize)));

		

		//Widget w (largeur)

		$this->setWidget('w', new sfWidgetFormInputHidden());

		$this->setValidator('w', new sfValidatorNumber(array('required' => true, 'min' => 1, 'max' => $this->source_width_resize)));

		

		//Widget h (hauteur)

		$this->setWidget('h', new sfWidgetFormInputHidden());

		$this->setValidator('h', new sfValidatorNumber(array('required' => true, 'min' => 1, 'max' => $this->source_height_resize)));

		

		//Validateur général

		$this->validatorSchema->setPostValidator(

		new sfValidatorCallback(array('callback' => array($this, 'validateurGeneral'))));

		

		$this->widgetSchema->setNameFormat('evenementImageTruncate[%s]');

		$this->errorSchema = new sfValidatorErrorSchema($this->validatorSchema);

		

	}

	

	

	

	

	

	

	//Validateur general

	public function validateurGeneral($validator, $values)

	{

		//On verifie que les points donnes rentrent dans l'image

		$pt_haut_droite = intval($values['x1']) + intval($values['w']);

		$pt_bas_gauche = intval($values['y1']) + intval($values['h']);

		if($pt_haut_droite > $this->source_width_resize || $pt_bas_gauche > $this->source_height_resize)

		{

			throw new sfValidatorError($validator, 'Points invalides');

		}

		

		//On verifie le ratio

		$width = intval($values['w']);

		$height = intval($values['h']);

		if($height > 0 && abs(round($width / $height, 2) - $this->ratio) > 0.1)

		{

			throw new sfValidatorError($validator, 'Ratio invalide');

		}

		

		return $values;

	}

	

	

	

	

	

	

	/**

	 * Fonction qui prepare le formulaire, en fonction de l'image à éditer

	 * @return unknown_type

	 */

	private function initImage()

	{

		//On recupere le numero de l'image que l'on veut tronquer

		if($this->getOption('num_image') == 1 || $this->getOption('num_image') == 2)

		{

			$this->num_image = $this->getOption('num_image');

		}

		else

		{

			throw new Exception('Numéro d\'image incorect');

		}

		

		//On verifie que l'image "source" existe bien en base de données et sur le serveur

		//de fichiers

		$file = $this->getObject()->get('image_'.$this->num_image);

		if(empty($file))

		{

			throw new Exception('Image source absente de la BDD');

		}

		$file = sfConfig::get('app_uploads_images_agenda').'/'.$file;

		$this->source_file_name = $file;

		if(!is_file($file))

		{

			throw new Exception('Image source absente sur le serveur de fichiers');

		}

		

		

		//On verifie que le fichier est bien une image et on recupere les dimensions de l'image source ainsi que son

		//type

		$info_img = @getimagesize($file);

		if(!$info_img )

		{

			throw new Exception('Le fichier n\'est pas une image');

		}

		$this->source_width = $info_img[0];

		$this->source_height = $info_img[1];

		$this->source_mine = $info_img[2];

		$this->source_width_resize = intval(sfConfig::get('app_agenda_thumb_width_select'));

		$this->source_resize_factor = round($this->source_width_resize / $this->source_width, 2);

		$this->source_height_resize = round($this->source_height * $this->source_resize_factor); 

		

		//On recupere le ratio de l'image

		$this->ratio = round(intval(sfConfig::get('app_agenda_thumb_width')) / intval(sfConfig::get('app_agenda_thumb_height')), 2);

	}

	

	

	

	

	/**

	 * Action apellée si le formulaire est valide

	 * @return Evenement 		Objet sauvegardé

	 */

	public function ProcessForm()

	{

		$evenement = $this->getObject();

		

		//On recupere les points de l'image dont on remet à l'échelle leur valeur

		$x1 = intval($this->getValue('x1')) / $this->source_resize_factor;

		$y1 = intval($this->getValue('y1')) / $this->source_resize_factor;

		$w = intval($this->getValue('w')) / $this->source_resize_factor;

		$h = intval($this->getValue('h')) / $this->source_resize_factor;

		

		//On définie le nom de l'image de destination

		$name_file_dest = 'event_'.$evenement->getId().'_image_'.$this->num_image.'_truncate';

		$file_dest =  sfConfig::get('app_uploads_images_agenda').'/'.$name_file_dest;

		

		//On cree l'image

		$img_out = imagecreatetruecolor($w, $h);

		

		if($this->source_mine == IMAGETYPE_JPEG)

		{

			$img_in = imagecreatefromjpeg($this->source_file_name);

			imagecopyresampled($img_out, $img_in, 0, 0, $x1, $y1, imagesx($img_out), imagesy($img_out), $w, $h);

			$file_dest = $file_dest.'.jpg';

			$name_file_dest = $name_file_dest.'.jpg';

			imagejpeg($img_out, $file_dest);

		}

		elseif($this->source_mine == IMAGETYPE_GIF)

		{

			$img_in = imagecreatefromgif($this->source_file_name);

			imagecopyresampled($img_out, $img_in, 0, 0, $x1, $y1, imagesx($img_out), imagesy($img_out), $w, $h);

			$file_dest = $file_dest.'.gif';

			$name_file_dest = $name_file_dest.'.gif';

			imagegif($img_out, $file_dest);

		}

		elseif($this->source_mine == IMAGETYPE_PNG)

		{

			$img_in = imagecreatefrompng($this->source_file_name);

			imagecopyresampled($img_out, $img_in, 0, 0, $x1, $y1, imagesx($img_out), imagesy($img_out), $w, $h);

			$file_dest = $file_dest.'.png';

			$name_file_dest = $name_file_dest.'.png';

			imagepng($img_out, $file_dest);

		}

		else

		{

			throw new Exception('Format image incorret');

		}

		

		

		//On sauvegarde 

		$evenement->set('image_'.$this->num_image.'_truncate', $name_file_dest);

		$evenement->save();

		

		//On supprime le cache des images

		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_agenda').'/'.$evenement->getId();

		Util::deleteFolder($folder_cache);

		

		return $evenement;

	}

	

	

	/**

	 * Fonction qui retourne le ratio de l'image

	 * @return Double	Ratio

	 */

	public function getRatio()

	{

		return $this->ratio;

	}

	

	/**

	 * Fonction qui retourne le nombre à multiplier par $source_height pour 

	 * avoir $source_height_resize (idem pour width)

	 * @return Double

	 */

	public function getSourceResizeFactor()

	{

		return $this->source_resize_factor;

	}

}

?>