<?php

/**

 * This file is part of "Annecy By Night"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * classe du formulaire d'oublie de mot de passe

 *

 * @author   Sylvain JEANDROZ <sjeandroz@e-commit.fr>

 * @version    SVN: $Id: ForgottenPasswordForm.class.php 377 2010-08-25 11:43:20Z hlecorche $

 */





require_once(dirname(__FILE__).'/../lib-ecommit/chiffrement.class.php');



class ForgottenPasswordForm extends BaseForm

{







	public function configure()

	{

		//Classe des champs du formulaire

  		$class = 'fields';

  		

		//champ login

		$this->setWidget('login', new sfWidgetFormInputText(array(), array('class' => $class,

																		'size' => 30)));





		$this->setValidator('login', new sfValidatorString(array('min_length' => 3),

		array('min_length'=> '%min_length% caractères mini',

  									  		 					 'required' => 'Champ obligatoire')

		));



		//champ adresse mail

		$this->setWidget('adresse_mail' , new sfWidgetFormInputText(array(), array('class' => $class,

																				'size' => 30)));



		$this->setValidator('adresse_mail',new sfValidatorEmail(array('required' => true,

  												'min_length' => 3),

		array('min_length'=> '%min_length% caractères mini',

  									  		  'invalid' => 'Adresse e-mail invalide',

  									  		  'required' => 'Champ obligatoire'))

		);





		//Champs captcha

  		$this->setWidget('captcha', new sfWidgetFormInputText(array(), array('class' => $class,

  																		'size' => 25)));

  		$this->setValidator('captcha', new sfValidatorSfCryptoCaptcha(array('required' => true, 

  																			'trim' => true),

                                                   					  array('wrong_captcha' => 'Code invalide',

                                                         					'required' => 'Champ obligatoire')));											 



		

        $this->widgetSchema->setNameFormat('mot_passe[%s]');



		$this->errorSchema = new sfValidatorErrorSchema($this->validatorSchema);

		parent::setup();



	}

	/**

	 * methode qui compare les pseudo et mail de la base et du formulaire pour 

	 * eventuellement envoyé le mail avec le mot de passe, ou alors renvoyé un message d'erreur 

	 * 

	 * @param sfController $controller le controlleur du site

	 * @return unknown_type

	 */

	public function ProcessForm($controller){



		//recuperation des données entrées par l'utilisateur

		$login=$this->getValue('login');

		$mail=$this->getValue('adresse_mail');



		//recuperation des données de navigation de l'utilisateur (pour pouvoir créer des messages flash

		$user=$controller->getUser();



		//on recupere l'objet membre dont le pseudo correspond au login du formulaire

		$membre = Doctrine::getTable('Membre')->findOneByPseudo($login);

		

		//si on ne recupere rien, c'est que le login ne correspond pas au login d'un membre

		if(empty($membre))

		{

			//on enregistre un message flash d'erreur

			$user->setFlash('main_oubliMP_error', 'Login et/ou e-mail incorrect',false);

			$controller->setTemplate('oubliMotPasse');



			//sinon cela signifie que le login correspond a un membre

		}else

		{

			//on recupere le mail du membre

			$mail_membre=$membre->getEmail();



			//si le mail du membre est le meme que le mail du formulaire

			if($mail==$mail_membre)

			{

				//on recupere le mot de passe crypté du membre dans la base

				$mot_passe_crypte=$membre->getMotPasseCrypte();

				//si ce mot de passe crypté est nul

				if(empty($mot_passe_crypte))

				{

					//on enregistre un message flash d'erreur

					$user->setFlash('main_oubliMP_error', 'Nous ne sommes pas en mesure de vous envoyer votre mot de passe. Veuillez contacter l\'administrateur du site',false);

					$controller->setTemplate('oubliMotPasse');



				}else

				{

					//sinon si on a bien le mot de passe crypté, on va envoyer les info par mail



					//On prepare le mail à la personne

					$expediteur = sfConfig::get('app_email_expediteur', 'contact@annecybynight.com');

					$destinataire = $mail_membre;



					//on decrypte le mot de passe crypté qui était dans la base

					$mot_passe = Chiffrement::decryptage($mot_passe_crypte);



					//on prepare le sujet du mail

					$sujet = sfConfig::get('app_email_sujet_perte_mot_de_passe', 'Vos identifiants de connexion à AnnecyByNight');

					//on prepare le corps du message en passant au partial qui contient ce corps

					//les infos dont il a besoin ( mdp et login)

					$mailBody = $controller->getPartial('oubli_mot_passe', array('pseudo' => $login,

																	'mdp' => $mot_passe));



					// On cree le mail					

					$message = Swift_Message::newInstance()

					->setFrom($expediteur)

					->setTo($destinataire)

					->setSubject($sujet)

					->setBody($mailBody, 'text/html');



					// On envoie le mail

					$controller->getMailer()->send($message);



					$user->setFlash('main_oubliMP_ok', 'Le mail contenant votre mot de passe a été envoyé',false);

					$controller->setTemplate('oubliMotPasse');

				}

			}else

			{

				//sinon si le mail du formulaire ne correspond pas au mail du membre, on enregistre

				//un message d'erreur flash

				$user->setFlash('main_oubliMP_error', 'Login et/ou e-mail incorrect',false);

				$controller->setTemplate('oubliMotPasse');





			}

		}



	}





}

?>