<?php
/**
 * This file is part of "Annecy By Night"
 * Copyright (c) 2009 Hubert LECORCHE
 * 
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */


/**
 * Classe de formulaire d'inscription
 *
 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>
 * @version    SVN: $Id: InscriptionForm.class.php 381 2010-08-26 09:18:49Z hlecorche $ 
 */
class InscriptionForm extends BaseMembreForm
{
  public function configure()
  {
  		//Classe des champs du formulaire
  		$class = 'fields';
  		
  		
  		//Définition des listes
  		$liste_sexes = array(0 => '', 1 => 'Masculin', 2 => 'Féminin');
  		$liste_fumeur = array(null => '', 0 => 'Non fumeur', 1 => 'Fumeur');
  		$liste_enfants = array(null => '', 0 => 'N\'a pas d\'enfant', 1 => 'A des enfants');
  		$liste_annees = array();
  		for($i=intval(date('Y', time())); $i>= intval(date('Y', time() - 31536000 * 100)); $i--) { $liste_annees[$i] = $i; }	
  		
  		//Champ "pseudo" (Obligatoire)
  		$this->setWidget('pseudo', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 30)));
  		
  		$validator_pseudo_general = new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 5,
  																'max_length' => 40),
  														  array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi'));
  		
  		$validator_pseudo_unique = new sfValidatorDoctrineUnique(array('model' => 'Membre',
  																	   'column' => 'pseudo',
  																	   'throw_global_error' => true,
  																	   'required' => true),
  																 array('invalid' => 'Le pseudo est déjà pris',
  																 	   'required' => 'Champ obligatoire'));
  		
  		$this->setValidator('pseudo', new sfValidatorAnd(
  									  array($validator_pseudo_general, $validator_pseudo_unique ),
  									  array(), array('required' => 'Champ obligatoire')));
  		
  									  
  		
  		//Champ "prenom" (facultatif)
  		$this->setWidget('prenom', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('prenom', new sfValidatorString(array('required' => true,
  																  'trim' => true,
  																  'min_length' => 3,
  																  'max_length' => 25),
  														  	array('min_length'=> '%min_length% caractères mini',
  														  		  'max_length'=> '%max_length% caractères maxi',
  														  		  'required' => 'Champ obligatoire')));
  		
  		//Champ mot de passe (obligatoire)
  		$this->setWidget('mot_passe', new sfWidgetFormInputText(array('type' => 'password'), array('class' => $class,
  																							   'size' => 30)));
  		$this->setValidator('mot_passe', new sfValidatorString(array('required' => true,
  																	'min_length' => 6,
  																	'max_length' => 255),
  														  	   array('required' => 'Champ obligatoire',
  														  			 'min_length'=> '%min_length% caractères mini',
  														  			 'max_length'=> '%max_length% caractères maxi')));
  		
  		//Champ mot de passe confirmation (obligatoire)
  		$this->setWidget('mot_passe_confirmation', new sfWidgetFormInputText(array('type' => 'password'), array('class' => $class,
  																							   'size' => 30)));
  		$this->setValidator('mot_passe_confirmation', new sfValidatorPass());
  											  	   
  		//Champ "email" (obligatoire)
  		$this->setWidget('email', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 30)));
  		
  		$validator_mail_format = new sfValidatorEmail(array('required' => true,
  																  'trim' => true,
  																  'min_length' => 3,
  																  'max_length' => 255),
  														  	array('min_length'=> '%min_length% caractères mini',
  														  		  'max_length'=> '%max_length% caractères maxi',
  														  		  'invalid' => 'Adresse e-mail invalide',
  														  		  'required' => 'Champ obligatoire'));
  														  	
  		$validator_mail_unique = new sfValidatorDoctrineUnique(array('model' => 'Membre',
  																	   'column' => 'email',
  																	   'throw_global_error' => true,
  																	   'required' => true),
  																 array('invalid' => 'L\'email est déjà pris',
  																 	   'required' => 'Champ obligatoire'));
  		$this->setValidator('email', new sfValidatorAnd(
  									  array($validator_mail_format, $validator_mail_unique ),
  									  array(), array('required' => 'Champ obligatoire')));
  														  	
  		//Champ "portable" (facultatif))
  		$this->setWidget('portable', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('portable', new sfValidatorString(array('required' => false,
  																  'trim' => true,
  																  'min_length' => 10,
  																  'max_length' => 20),
  														  	array('min_length'=> '%min_length% caractères mini',
  														  		  'max_length'=> '%max_length% caractères maxi')));
  														  	
  		//Champ "sexe" (obligatoire)
  		$this->setWidget('sexe', new sfWidgetFormSelect(array('choices' => $liste_sexes), 
  														array('class' => $class)));
  		$this->setValidator('sexe', new sfValidatorChoice(array('choices' => array(1, 2),
  																'required' => true),
  														  array('required' => 'Champ obligatoire',
  														  		'invalid' => 'Champ obligatoire')));
  		
  		//Champ "civilite_id" (facultatif)
  		$this->setWidget('civilite_id', new sfWidgetFormDoctrineChoice(array('model' => 'Civilite',
  																		  'add_empty' => true,
  																		  'order_by' => array('nom', 'ASC')), 
  														array('class' => $class)));
  		$this->setValidator('civilite_id', new sfValidatorDoctrineChoice(array('model' => 'Civilite',
  																'required' => false,
  																'column' => 'id'),
  														  array('required' => 'Champ obligatoire',
  														  		'invalid' => 'Champ invalide'
  														  		)));
  														  
  		//Champ "fume" (facultatif)
  		$this->setWidget('fume', new sfWidgetFormSelect(array('choices' => $liste_fumeur), 
  														array('class' => $class)));
  		$this->setValidator('fume', new sfValidatorChoice(array('choices' => array_keys($liste_fumeur),
  																'required' => false),
  														  array('invalid' => 'Champ obligatoire')));
  														  
  		//Champ "enfants" (facultatif)
  		$this->setWidget('enfants', new sfWidgetFormSelect(array('choices' => $liste_enfants), 
  														array('class' => $class)));
  		$this->setValidator('enfants', new sfValidatorChoice(array('choices' => array_keys($liste_enfants),
  																'required' => false),
  														  array('invalid' => 'Champ obligatoire')));
  														  
  		//Champ "date_naissance" (obligatoire")
  		$this->setWidget('date_naissance', new sfWidgetFormDate(array('format' => '%day%/%month%/%year%',
  																	  'empty_values' => array('year' => 'Année',
  																							  'month' => 'Mois',
  																							  'day' => 'Jour'),
  																		'years' => $liste_annees),
  																array('class' => $class)));
  																
  		$this->setValidator('date_naissance', new sfValidatorDate(array('required' => true,
  																	 'max' => time(),
  																	 'min' => time() - 31536000 * 100),
  															   array('required' => 'Champ obligatoire',
  																	 'max' => 'Date invalide',
  															   		 'min' => 'Date invalide',
  															   		 'invalid' => 'Date invalide')));
  															   
  		
		//Champ "ville" (obligatoire)
  		$this->setWidget('ville', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 25)));	
  		$this->setValidator('ville', new sfValidatorString(array('required' => true,
  																	'min_length' => 3,
  																	'max_length' => 40),
  														  	   array('required' => 'Champ obligatoire',
  														  			 'min_length'=> '%min_length% caractères mini',
  														  			 'max_length'=> '%max_length% caractères maxi')));								   

  														  	   
  		//Champ "code_postal" (obligatoire)
  		$this->setWidget('code_postal', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('code_postal', new sfValidatorInteger(array('required' => true,
  																  'min' => 100,
  																  'max' => 999999),
  																  array('required' => 'Champ obligatoire',
  																  		'min' => 'Code postal invalide',
  																  		'max' => 'Code postal invalide',
  																  		'invalid' =>'Code postal invalide')));

  		//Champ pour l'image de profil
  		$this->setWidget('image', new sfWidgetFormInputFile(array(), array('class' => $class)));
  																  
  		$this->setValidator('image', new sfValidatorFile(array('max_size' => 1000000,
  															   'mime_types' => 'web_images',
  															   'required' => false),
  														 array('max_size' => 'La photo doit faire 1Mo maximum',
  														 	   'mime_types' => 'Format du fichier incorrect')));
		
  		//Champs condition utilisation
		$this->setWidget('condition', new sfWidgetFormInputCheckbox(array('value_attribute_value' => 1)));
		
		
		$this->setValidator('condition', new sfValidatorChoice(array('required' => true,
																	'choices' => array(1)),
															  array('required' => 'Merci d\'accepter les conditions générales d\'utilisation',
															  		'invalid' => 'Champ invalide')));									 
  														 
  		//Champs captcha
  		$this->setWidget('captcha', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('captcha', new sfValidatorSfCryptoCaptcha(array('required' => true, 
  																			'trim' => true),
                                                   					  array('wrong_captcha' => 'Code invalide',
                                                         					'required' => 'Champ obligatoire')));											 
  		
 		//Champs désactivés car remplis dans l'action
 		unset($this['id']);
		unset($this['confirmation']);
		unset($this['confirmation_code']);
		unset($this['derniere_requete']);
		unset($this['level_id']);
		unset($this['annonce']);
		unset($this['img_1']);
		unset($this['img_2']);
		unset($this['img_3']);
		unset($this['site_web']);
		unset($this['mot_passe_crypte']);
		unset($this['notification_newsletter']);
		unset($this['fonction_id']);
		unset($this['reportages_list']); //Champ virtuel
		unset($this['reportages_presents_list']); //Champ virtuel
		unset($this['lieux_list']); //Champ virtuel
		
		//Champs desactives car traites par SF
		unset($this['created_at']);
		
		unset($this['image_profil']);
		
		
		//Validateur pour comparer les deux mots de passe
		$this->validatorSchema->setPostValidator(new sfValidatorSchemaCompare('mot_passe_confirmation', sfValidatorSchemaCompare::EQUAL, 'mot_passe',
  																array(),
  																array('invalid' => 'Les mots de passe ne correpondent pas')));
  }
  
  
  
  
	//Fonction qui formate les checkbox du formulaire
	public function formatterCheckBoxBox($widget, $inputs)
 	{
	    $html = '';
	    foreach ($inputs as $input)
	    {
	    	$html .=  $input['input'];
	    }
	    return $html;
 	}
}