<?php

/**

 * This file is part of "AnnecyByNight"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Formulaire de proposition d'evenement

 *

 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: SuggestEventForm.php 417 2010-09-07 14:11:49Z hlecorche $

 */



require_once(dirname(__FILE__).'/../../plugins/sfJqueryReloadedPlugin/lib/helper/jQueryHelper.php');

sfContext::getInstance()->getConfiguration()->loadHelpers('Url');



class SuggestEventForm extends BaseEvenementForm

{

	

	private $new_lieu_empty = false; //Si cette variable vaut true, tous les champs du "sous-formulaire"

	//pour creer un nouveau lieu sont vides

	

	

	/*

	 * Valeur de la variable type_id associee à l'événement.

	 * Cette valeur est utilisee pour: Afficher la valeur par défaut du filtre de recherche ("select_type_id". Afficher le

	 * contenu de la liste "lieu_id"

	 * 

	 * Une fonction setSelectTypeId permet de modifier cette valeur puis apres de rappeler la methode configure()

	 * avant de refaire tous les widgets

	 * 

	 * A la construction du formulaire, cette valeur est initialisee à partir de la valeur de l'objet (donc

	 * si objet nouveau, valeur nulle).

	 * Lorsque l'on change la valeur de la liste "select_type_id", on appel Ajax est généré, qui appele la fonction

	 * setSelectTypeId et qui envoie le nouveau widget

	 * Lorsque le formulaire est envoye par le client, lors du bind, la fonction setSelectTypeId est apelée (avec

	 * comme paramètre la valeur envoyée dans le request) pour mettre à jour cette variable.

	 */

	private $type_id = null; 



	

	public function __construct($defaults = array(), $options = array(), $CSRFSecret = null)

	{

		parent::__construct($defaults, $options, $CSRFSecret);

		$value  = $this->getObject()->getTypeId();

		$this->type_id = $value; //Ne pas utiliser le setter pour pas faire le construct deux fois

	}

	

	public function configure()

	{

		

		$class = "fields";

		

		//Champ "select_type_id" (pour filter le champ "lieu_id")

		//Quand la valeur de ce champ sera changé, un appel ajax sera fait pour actualiser le champ "lieu_id"

		$javascript = jq_remote_function(array('url' => 'agenda/ajaxListeLieux', 'update' => 'liste_lieu_id', 'with' => '{type_id: jQuery(this).val()}'));

		$this->setWidget('select_type_id', new sfWidgetFormDoctrineChoice(array('model' => 'Type', 'add_empty' => 'Selectionnez un type'), array('class' => $class, 'onchange' => $javascript)));

		$this->setValidator('select_type_id', new sfValidatorPass()); //On peut mettre tout comme valeur

		$this->setDefault('select_type_id', $this->type_id);

		

		//Champ "lieu_id"

		//Ce champ n'affiche pas la liste de tous les lieux (car trop longue).

		//On recupere la valeur $this->type_id (derniere valeur choisie dans ce champ)

		//et on affiche uniquement les lieux associes à ce type

		$query = Doctrine::getTable('Lieu')->createQuery('l')->where('l.type_id = ?', $this->type_id)->orderBy('l.nom ASC');

		$this->setWidget('lieu_id', new sfWidgetFormDoctrineChoice(array('model' => 'Lieu', 'query' => $query, 'add_empty' => 'Selectionnez un lieu'), array('class' => $class)));

		$this->setValidator('lieu_id', new sfValidatorDoctrineChoice(array('model' => 'Lieu',

																		   'required' => true),

																	array('required' => 'Champ obligatoire',

																		  'invalid' => 'Champ invalide')));

																	

		

		//Champ "date_debut"

		$this->setWidget('date_debut', new ecWidgetFormDateRich(array('buttonImage' => '/images/icones/16/date.png'), 

														  array('class' => $class,

															    'size' => 20)));

		$this->setValidator('date_debut', new sfValidatorDate(array('date_format' => '@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@',

														   'required' => true), 

													 array('required' => 'Champ obligatoire',

													 	   'invalid' => 'Date invalide',

													 	   'bad_format' => 'Date invalide')));

													 

		//Champ "date_fin"

		$this->setWidget('date_fin', new ecWidgetFormDateRich(array('buttonImage' => '/images/icones/16/date.png'), 

														  array('class' => $class,

															    'size' => 20)));

		$this->setValidator('date_fin', new sfValidatorDate(array('date_format' => '@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@',

														   'required' => false), 

													 array('invalid' => 'Date invalide',

													 	   'bad_format' => 'Date invalide')));

		

		//Champ "titre"

		$this->setWidget('titre', new sfWidgetFormInputText(array(), array('class' => $class,

																	 'size' => 50)));

		

		$this->setValidator('titre', new sfValidatorString(array('required' => true,

  																'trim' => true,

  																'min_length' => 5,

  																'max_length' => 55),

  														  array('required' => 'Champ obligatoire',

  														  		'min_length'=> '%min_length% caractères mini',

  														  		'max_length'=> '%max_length% caractères maxi')));

		

		//Champ "description"

		$this->setWidget('description', new sfWidgetFormTextarea(array(), array('class' => $class,

																	 			'rows' => 5,

																	 			'cols' => 50)));

		

		$this->setValidator('description', new sfValidatorString(array('required' => true,

  																'trim' => true,

  																'min_length' => 5,

  																'max_length' => 1000),

  														  array('required' => 'Champ obligatoire',

  														  		'min_length'=> '%min_length% caractères mini',

  														  		'max_length'=> '%max_length% caractères maxi')));

  		

  														  

  		//Champ "flyer1"

  		$this->setWidget('flyer1', new sfWidgetFormInputFile(array(), array('class' => $class)));

  																  

  		$this->setValidator('flyer1', new sfValidatorFile(array('max_size' => 2000000,

  															   'mime_types' => array('image/jpeg'),

  															   'required' => false),

  														 array('max_size' => 'La photo doit faire 2Mo maximum',

  														 	   'mime_types' => 'Format du fichier incorrect')));

  														 

  		//Champ "flyer2"

  		$this->setWidget('flyer2', new sfWidgetFormInputFile(array(), array('class' => $class)));

  																  

  		$this->setValidator('flyer2', new sfValidatorFile(array('max_size' => 2000000,

  															   'mime_categories' => array('image/jpeg'),

  															   'required' => false),

  														 array('max_size' => 'La photo doit faire 2Mo maximum',

  														 	   'mime_types' => 'Format du fichier incorrect')));

		

  		

  		//Champ "heure_debut"

		$this->setWidget('heure_debut', new sfWidgetFormInputText(array(), array('class' => $class,

																	 'size' => 7)));

		$regular_expression = '/^((0?[0-9])|(1[0-9])|(2[0-4])):[0-5][0-9]$/i';

		$this->setValidator('heure_debut', new sfValidatorRegex(array('required' => false,

																	  'pattern' => $regular_expression),

																array('invalid' => 'Heure invalide')));

																

		//Champ "heure_fin"

		$this->setWidget('heure_fin', new sfWidgetFormInputText(array(), array('class' => $class,

																	 'size' => 7)));

		$this->setValidator('heure_fin', new sfValidatorRegex(array('required' => false,

																	  'pattern' => $regular_expression),

																array('invalid' => 'Heure invalide')));												 

  														 

  														 

  														 

  		//Champs captcha

  		$this->setWidget('captcha', new sfWidgetFormInputText(array(), array('class' => $class,

  																		'size' => 25)));

  		$this->setValidator('captcha', new sfValidatorSfCryptoCaptcha(array('required' => true, 

  																			'trim' => true),

                                                   					  array('wrong_captcha' => 'Code invalide',

                                                         					'required' => 'Champ obligatoire')));														 

  														 

		//Champs désactives car traites plus tard

		unset($this['active']);

		unset($this['active_index']);

		unset($this['type_id']);

		unset($this['auteur_membre_id']);

		unset($this['image_1']);

		unset($this['image_2']);

		unset($this['image_1_truncate']);

		unset($this['image_2_truncate']);

		

		//Champs desactives car traites par SF

		unset($this['created_at']);

		unset($this['id']);

														

																

		//Formulaire embarqué, d'ajout de lieu

		$form = new LieuForm();

		$form->useFields(array('nom', 'adresse', 'code_postal', 'ville', 'telephone', 'fax', 'type_id'));

      	     	

      	$this->embedForm('nouveau_lieu', $form);

      	

      	//Validateur général

      	//appelé apres tous les valideteurs individuels

		$this->validatorSchema->setPreValidator(

		new sfValidatorCallback(array('callback' => array($this, 'preValidateurGeneral'))));

		

		//Validateur général

      	//appelé apres tous les validateurs individuels

		$this->validatorSchema->setPostValidator(

		new sfValidatorCallback(array('callback' => array($this, 'postValidateurGeneral'))));

	}

	

	

	

	

	

	public function bind(array $taintedValues = null, array $taintedFiles = null)

	{

		//On binde le formulaire. Pour le moment aucun validateur n'a été declanché.

		

		//Avant de faire quoi que se soit, on regarde si les champs du formulaire embarque (nouveau

		//lieu) ont été remplis.

		$this->checkNewLieu($taintedValues);

		

		//Mise à jour de la variable privee 'type_id' (derniere valeur selctionnee dans la liste de tri)

		if(!empty($taintedValues['select_type_id']))

		{

			$this->setSelectTypeId($taintedValues['select_type_id']);

		}

		

		//On procede maintenant au BIND du formulaire. Les données membres de l'objet "Form" vont etre

		//remplis en fonction du request ($taintedValues), puis la fonction va proceder à la vérification du

		//formulaire

		parent::bind($taintedValues, $taintedFiles);

		

		//Le formulaire a été vérifie (avec ou sans erreurs)

		

	}

	

	

	/**

	 * Action executee, si le formulaire est valide

	 * @param sfActions $action action

	 * @return unknown_type

	 */

	public function processForm($action)

	{

		//Le formulaire est valide, on procede à son traitement

		

		//On recupere l'objet Evenement

		$event = $this->getObject();

		

		//On n'active pas les evenements

		$event->setActive(0);

		$event->setActiveIndex(0);

		

		//On associe à l'evenement l'auteur connecte

		$membre_id = MembreTable::getMembreIdConnecte();

		$event->setAuteurMembreId($membre_id);

		

		if($this->new_lieu_empty)

		{

			//Les champs du nouveau lieu ne sont pas remplis. La personne a donc décider

			//de choisir un lieu en BDD. On peut donc supprimer

			//le formulaire embarqué (pour pas que le nouveau lieu "vide" soit sauvegardé

			unset($this->embeddedForms['nouveau_lieu']); 

			//Inutile de faire le sfValidatorPass sur l'ancien formulaire embarqué car il a

			//été déja fait dans le validateur general

			

			//Le type d'evenement est le meme que le type de lieu.

			//Comme la personne a choisi un lieu dans la BDD, on va recuperer son type et on affecte le

			//meme au nouvel evenement

			/*

			 Fait maintenant dans le save de l'objet Evenement

			$lieu_id = $this->getValue('lieu_id');

			$lieu = Doctrine::getTable('Lieu')->find($lieu_id);

			$type_id = $lieu->getTypeId();

			$event->setTypeId($type_id); */

		}

		else

		{

			//On decide de choisir un lieu sur un lieu que l'on cree maintenant

			//Le formulaire d'ajout de lieu est toujours là, on va donc creer un nouveau lieu

			$embedded_forms = $this->getEmbeddedForms();

			$nouveau_lieu = $embedded_forms['nouveau_lieu']->getObject();

			

			//On rend inactif ce nouveau lieu, et on associe notre evenement a ce nouveau lieu

			$nouveau_lieu->setActive(0);

			$nouveau_lieu->setActiveIndex(0);

			$event->setLieu($nouveau_lieu);

			

			//Le type d'evenement est le meme que le type de lieu. On recupere alors le type

			//du nouveau lieu, que l'on affecte au nouvel evenement

			/*

			  Fait maintenant dans le save de l'objet Evenement

			$form_values = $this->getValue('nouveau_lieu');

			$type_id = $form_values['type_id'];

			$event->setTypeId($type_id); */

		}

		

		//On recupere les flyers

		$flyer1 = $this->getValue('flyer1');

		$flyer2 = $this->getValue('flyer2');

		

		//Si les flyers ne sont pas présents, on desactive les widgets associes

		//pour eviter une erreur SF

		if(empty($flyer1))

		{

			unset($this['flyer1']);

		}

		if(empty($flyer2))

		{

			unset($this['flyer2']);

		}



		//On sauvegarde l'evenement

		$evenement = $this->save();

		

		//Si la date de fin n'est pas precisee, on l'ajoute (la meme que la date de debut)

		$date_fin = $this->getValue('date_fin');

		if(empty($date_fin))

		{

			$evenement->setDateFin($this->getValue('date_debut'));

		}

		

		//On traite l'enregistrement des flyers, si presents

		$liste_flyers = array($flyer1, $flyer2);

		$numero_image = 0;

		foreach($liste_flyers as $file)

		{

			if(!empty($file))

			{

				//L'image est presente on la traite

				$numero_image = $numero_image + 1;

				

				//On le renomme

				$extension = $file->getExtension($file->getOriginalExtension());

				$name = 'event_'.$evenement->getId().'_image_'.$numero_image.$extension;

				

				//On sauvegarde le fichier

				$dossier = sfConfig::get('app_uploads_images_agenda');

				$file->save($dossier.'/'.$name);

				

				//On modifie la BDD

				$evenement->set('image_'.$numero_image, $name);

			}		

		}

		$evenement->save();

		

		

		//On envoie un message perso à l'admin

		$expediteur = sfConfig::get('app_administrateur_expediteur_id');

		$destinataire = sfConfig::get('app_administrateur_destinataire_id');

		if(!empty($expediteur) && !empty($destinataire))

		{

			$sujet = 'Notification ajout événement';

			$text = "Bonjour, un événement a été ajouté sur le site. Il peut être adminitré depuis le back-office.";

			$message = new Message();

			$message->setTitre($sujet);

			$message->setMessage($text);

			$message->setLu(0);

			$message->setExpediteurMembreId($expediteur);

			$message->setDestinataireMembreId($destinataire);

			$message->save();

		}

	}

	

	

	//Fonction appelée par le validateur général

	public function preValidateurGeneral($validator, $values)

	{

		//Nous sommes dans la procedure de validation du formulaire (pendant le BIND du formulaire).

		//A cette etape, lec champs du formulaire n'ont pas encore été validés.

		//On procede maintenant a une validation generale

		

		if(!empty($values['lieu_id']) && !$this->new_lieu_empty)

		{

			//L'utilisateur a choisi un lieu dans la base de données et veux creer

			//un nouveau lieu. Erreur sur le champ "lieu_id"

			$error = new sfValidatorError($validator, 'Vous ne pouvez pas choisir un lieu dans la liste et creer un nouveau lieu.');

			throw new sfValidatorErrorSchema($validator, array('lieu_id' => $error));

		}

		elseif(!empty($values['lieu_id']) && $this->new_lieu_empty)

		{

			//L'utilisateur a choisi un lieu dans la BDD mais n'a rien rempli dans "nouveau lieu".

			//Si on reste comme cela, le formulaire sera jamais valide car les validateurs "required" du

			//formulaire de lieu apporteront des erreurs.

			//Pour eviter ce probleme, on desactive les validateurs du formulaire embarque, dans ce cas

			//bien precis

			$this->validatorSchema['nouveau_lieu'] = new sfValidatorPass();

		}

		elseif(empty($values['lieu_id']) && !$this->new_lieu_empty)

		{

			//L'utilisateur a choisi de creer un nouveau lieu mais n'a rien choisi dans la BDD

			//Si on reste comme cela, le formulaire sera jamais valide car le validateur "required" du

			//champ "lieu_id" provoquera des erreurs.

			//Pour eviter ce probleme, on desactive les validateurs du formulaire embarque, dans ce cas

			//bien precis

			$this->validatorSchema['lieu_id'] = new sfValidatorPass();

		}

		

		return $values;

	}

	

	

	//Fonction appelée par le validateur général

	public function postValidateurGeneral($validator, $values)

	{

		//On verifie si la date de début et la date de fin on été remplit par l'utilisateur

		if(!empty($values['date_debut']) && !empty($values['date_fin']))

		{

			//Si les deux sont remplit, on verifie que la date de début soit avant la date de fin, sinon erreur

			if($values['date_debut'] > $values['date_fin'])

			{

				$error = new sfValidatorError($validator, 'La date de début doit être inférieure à la date de fin');

				throw new sfValidatorErrorSchema($validator, array('date_fin' => $error));

			}

		}

		return $values;

	}

	

	public function setSelectTypeId($type_id)

	{

		$this->type_id = $type_id;

		//On regenere les widgets pour qu'ils prennent cette nouvelle valeur

		$this->configure();

	}

	

	

	

	/**

	 * Regarde si tous les champs du nouveau lien sont vides. Mais à true $this->new_lieu_empty si c'est vrai

	 * @param Array $taintedValues taintedValues recue par la fonction bind

	 * @return unknown_type

	 */

	private function checkNewLieu($taintedValues)

	{

		$form_values = $taintedValues['nouveau_lieu'];

		

		if(empty($form_values['nom']) && empty($form_values['type_id'])

		   && empty($form_values['adresse']) && empty($form_values['code_postal'])

		   && empty($form_values['ville']) && empty($form_values['telephone']))

		{

		   	$this->new_lieu_empty = true;

		}

		else

		{

			$this->new_lieu_empty = false;

		}

	}



}

?>