<?php

/**
 * Banniere form.
 *
 * @package    anbnws
 * @subpackage form
 * @author     Hubert LECORCHE
 * @version    SVN: $Id: BanniereForm.class.php 455 2010-10-01 12:00:41Z hlecorche $
 */
class BanniereForm extends BaseBanniereForm
{
	public function configure()
	{
		//Classe des champs du formulaire
  		$class = 'fields';
  		
  		$this->useFields(array('date_debut', 'date_fin', 'type'));
  		
  		if($this->getObject()->isNew())
  		{
	  		//Champ "banniere"
	  		$this->setWidget('banniere', new sfWidgetFormInputFile(array(), array('class' => $class)));
	  																  
	  		$this->setValidator('banniere', new sfValidatorFile(array('max_size' => '2000000',
	  															   'mime_types' =>array('application/x-shockwave-flash'),
	  															   'required' => true),
	  														 array('max_size' => 'La photo doit faire 2Mo maximum',
	  														 	   'mime_types' => 'Format du fichier incorrect',
	  														 		'required' => 'Vous n\'avez pas séléctionné un fichier')));
  		}
		
		//Champ "html" FIX DEK
		/*$this->setWidgets('html' => new sfWidgetFormTextarea(array(),array('class' => $class)));*/
	
		//Champ "date_debut"
		$this->setWidget('date_debut', new ecWidgetFormDateRich(array('buttonImage' => '/images/icones/16/date.png'), 
														  array('class' => $class,
															    'size' => 20)));
		$this->setValidator('date_debut', new sfValidatorDate(array('date_format' => '@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@',
														   'required' => true), 
													 array('required' => 'Champ obligatoire',
													 	   'invalid' => 'Date invalide',
													 	   'bad_format' => 'Date invalide')));
		$this->setDefault('date_debut', date('d/m/Y', time()));
													 
		//Champ "date_fin"
		$this->setWidget('date_fin', new ecWidgetFormDateRich(array('buttonImage' => '/images/icones/16/date.png'), 
														  array('class' => $class,
															    'size' => 20)));
		$this->setValidator('date_fin', new sfValidatorDate(array('date_format' => '@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@',
														   'required' => false), 
													 array('invalid' => 'Date invalide',
													 	   'bad_format' => 'Date invalide')));

		//Type
		$this->setWidget('type', new sfWidgetFormInputHidden());
		$this->setValidator('type', new sfValidatorChoice(array('required' => true,
																'choices' => array($this->getOption('type'))),
														  array('required' => 'Champ obligatoire',
														  		'invalid' => 'Champ invalide')));
		$this->setDefault('type', $this->getOption('type'));
				
													 
		//Validateur général
      	//appelé apres tous les validateurs individuels
		$this->validatorSchema->setPostValidator(
		new sfValidatorCallback(array('callback' => array($this, 'postValidateurGeneral'))));
	
  		$this->widgetSchema->setNameFormat($this->getOption('type').'[%s]');
	}
	
	
	
	
	//Fonction appelée par le validateur général
	public function postValidateurGeneral($validator, $values)
	{
		//On verifie si la date de début et la date de fin on été remplit par l'utilisateur
		if(!empty($values['date_debut']) && !empty($values['date_fin']))
		{
			//Si les deux sont remplit, on verifie que la date de début soit avant la date de fin, sinon erreur
			if($values['date_debut'] > $values['date_fin'])
			{
				$error = new sfValidatorError($validator, 'La date de début doit être inférieure à la date de fin');
				throw new sfValidatorErrorSchema($validator, array('date_fin' => $error));
			}
		}
		return $values;
	}
	
	/**
	 * fonction apellée lorsque le formulaire d'upload de banniere est validé, et qui enregistre
	 * la banniere dans le bon dossier
	 * @param   banniereAction $action objet de type banniereAction
	 * @return unknown_type
	 */
	public function ProcessForm($action)
	{
		//recuperation du fichier uploadé
		$file = $this->getValue('banniere');
		$user = $action->getUser();
		
		if(empty($file))
		{
			unset($this['banniere']);
		}
		
		$banniere = $this->save();
		
		if(!empty($file))
		{
			//On recupere le nom du fichier
			$file_name = $file->getOriginalName();
			
			//On supprime certains caracteres
			$file_name = str_replace('/', '', $file_name);
			$file_name = str_replace('\\', '', $file_name);
			
			//On regarde si un ancien fichier est present, et si oui on change de nom
			$ok = false;
			while(!$ok)
			{
				$file_path = BanniereTable::getFolderUpload($this->getOption('type')).'/'.$file_name;
				if(file_exists($file_path))
				{
					$file_name = 'bis-'.$file_name;
				}
				else
				{
					$ok = true;
				}
			}
			
				
			//On ajoute le nouveau fichier
			$file->save($file_path);
				
			//On mets à jour la BDD avec cette nouvelle valeur
			$banniere->setNomFichier($file_name);
			$banniere->save();
		}
		$user->setFlash('bannieres_ok', 'La bannière a bien été éditée');
	}
}
