<?php

/**
 * BonPlan form.
 *
 * @package    form
 * @subpackage BonPlan
 * @version    SVN: $Id: BonPlanForm.class.php 309 2009-10-15 11:28:07Z hlecorche $
 */
class BonPlanForm extends BaseBonPlanForm
{
  public function configure()
  {
  		//Classe des champs du formulaire
  		$class = 'fields';
  		
  		//Champ desactive car traite dans le processForm
  		unset($this['url_image']);
  		//champ desactivé car traité dans sf
  		unset($this['created_at']);
  		
  		
  		//champ texte
  		$this->setWidget('texte', new sfWidgetFormTextarea(array(), array('class' => $class,
		  																		'cols' => 55,
		  																		'rows' => 4)));	
	  	$this->setValidator('texte', new sfValidatorString(array('required' => true,
		  																  'trim' => true,
		  																  'min_length' => 3,
		  																  'max_length' => 500),
		  														  	array('min_length'=> '%min_length% caractères mini',
		  														  		  'max_length'=> '%max_length% caractères maxi',
		  														  		  'required' => 'Champ obligatoire')));
  		
  		//Champ "image"
  		$this->setWidget('image', new sfWidgetFormInputFile(array(), array('class' => $class)));
  		//on verifie si on ajoute ou on edite un bon plan, pour savoir si le champ image est obligatoire ou pas
  		//Ajout : Champ obligatoire
  		//Edition: Champ facultatif
  		$required = $this->getObject()->isNew();												  
  		$this->setValidator('image', new sfValidatorFile(array('max_size' => 200000,
  															   'mime_types' => 'web_images',
  															   'required' => $required),
  														 array('max_size' => 'La photo doit faire 200ko maximum',
  														 	   'mime_types' => 'Format du fichier incorrect',
  														 		'required' => 'Vous n\'avez pas séléctionné un fichier')));
	
	
  		
  														 
		//Champ "active" 
		$liste_active = array(0 => 'Non', 1 => 'Oui');
  		$this->setWidget('active', new sfWidgetFormSelect(array('choices' => $liste_active), 
  														array('class' => $class)));
  		$this->setValidator('active', new sfValidatorChoice(array('choices' => array_keys($liste_active),
  																'required' => true),
  														  array('required' => 'Champ obligatoire',
  														  		'invalid' => 'Champ obligatoire')));
  		
  														  
  														  
		$this->setDefault('active',1);
  																  
  		//Champ désativé
  		unset($this['id']);														  
  																  
		$this->errorSchema = new sfValidatorErrorSchema($this->validatorSchema);
  }
  
/**
	 * fonction qui enregistre ou modifie le bon plan dans la base, et qui gere l'image associée
	 * @param bons_plansActions $action
	 * @return unknown_type
	 */
	public function ProcessForm($action){

		//on recupere l'objet bon plan
		$bon_plan = $this->getObject();
		
		//on recupere le dossier ou stocker les photos
		$dossier = sfConfig::get('app_uploads_images_bons_plans');
		
		//on recupere le fichier de l'image
		$image = $this->getValue('image');
		
	
		//si l'image est vide on desactive son validateur pour eviter un bug de doctrine
		if(empty($image))
		{
			unset($this['image']);
		}
		
		$isnew=false;
		//si l'objet est nouveau, on met temporairement son champ url_image a # pour eviter 
		//une erreur mysql de champ null
		if($bon_plan->isNew())
		{
			$bon_plan->setUrlImage('#');
			$isnew=true;	
		}
		
		//on enregistre l'objet bon_plan
		$bon_plan = $this->save();	
		
		//si l'image n'est pas vide on l'enregistre puis on remplit le champ url_image avec un 
		//nom que l'on crée et on re-sauvegarde l'enregistrement
		if(!empty($image))
		{
			//on supprime l'ancienne image si elle existe en BDD et sur le serveur
			$ancienne_image = $bon_plan->getUrlImage();
			if(!empty($ancienne_image)&& !$isnew && file_exists($dossier.'/'.$ancienne_image))
			{
				unlink($dossier.'/'.$ancienne_image);
			}
			
			$extension = $image->getExtension($image->getOriginalExtension());
			$nom_fichier= 'bon_plan_'.$bon_plan->getId().$extension;
			$image->save($dossier.'/'.$nom_fichier);
			$bon_plan->setUrlImage($nom_fichier);
			$bon_plan->save();
		}
		
		
		
		//recuperation des données de navigation de l'utilisateur (pour pouvoir créer des messages flash
		$user = $action->getUser();
		
		$user->setFlash('bon_plan_ok', 'Le bon plan a bien été sauvegardé');

		return $bon_plan;
		
		
	
	}
}