<?php

/**
 * Evenement form.
 *
 * @package    form
 * @subpackage Evenement
 * @version    SVN: $Id: EvenementForm.class.php 375 2010-08-25 09:21:15Z hlecorche $
 */

require_once(dirname(__FILE__).'/../../../plugins/sfJqueryReloadedPlugin/lib/helper/jQueryHelper.php');
sfContext::getInstance()->getConfiguration()->loadHelpers('Url');

class EvenementForm extends BaseEvenementForm
{
	
	/*
	 * Valeur de la variable type_id associee à l'événement.
	 * Cette valeur est utilisee pour: Afficher la valeur par défaut du filtre de recherche ("type_id". Afficher le
	 * contenu de la liste "lieu_id"
	 * 
	 * Une fonction setSelectTypeId permet de modifier cette valeur puis apres de rappeler la methode configure()
	 * avant de refaire tous les widgets
	 * 
	 * A la construction du formulaire, cette valeur est initialisee à partir de la valeur de l'objet (donc
	 * si objet nouveau, valeur nulle).
	 * Lorsque l'on change la valeur de la liste "type_id", on appel Ajax est généré, qui appele la fonction
	 * setSelectTypeId et qui envoie le nouveau widget
	 * Lorsque le formulaire est envoye par le client, lors du bind, la fonction setSelectTypeId est apelée (avec
	 * comme paramètre la valeur envoyée dans le request) pour mettre à jour cette variable.
	 */
	private $type_id = null; 

	
	
	
	public function configure()
	{
		if(is_null($this->type_id))
		{
			$this->type_id = $this->getObject()->getTypeId(); //Ne pas utiliser le setter pour ne pas faire de boucle
		}
		
		$class = "fields";
		
		//Champ "type_id"
		//Quand la valeur de ce champ sera changé, un appel ajax sera fait pour actualiser le champ "lieu_id"
		$javascript = jq_remote_function(array('url' => 'agenda/ajaxListeLieux', 'update' => 'liste_lieu_id', 'with' => '{type_id: jQuery(this).val()}'));
		$this->setWidget('type_id', new sfWidgetFormDoctrineChoice(array('model' => 'Type', 'add_empty' => 'Selectionnez un type'), array('class' => $class, 'onchange' => $javascript)));
		$this->setValidator('type_id', new sfValidatorDoctrineChoice(array('model' => 'Type',
																		   'required' => true),
																	 array('required' => 'Champ obligatoire',
																	 	   'invalid' => 'Champ invalide')));
		$this->setDefault('type_id', $this->type_id);
		
		//Champ "lieu_id"
		//Ce champ n'affiche pas la liste de tous les lieux (car trop longue).
		//On recupere la valeur $this->type_id (derniere valeur choisie dans ce champ)
		//et on affiche uniquement les lieux associes à ce type
		$query = Doctrine::getTable('Lieu')->createQuery('l')->where('l.type_id = ?', $this->type_id)->orderBy('l.nom ASC');
		$this->setWidget('lieu_id', new sfWidgetFormDoctrineChoice(array('model' => 'Lieu', 'query' => $query, 'add_empty' => 'Selectionnez un lieu', 'method' => '__toStringWithActive'), array('class' => $class)));
		$this->setValidator('lieu_id', new sfValidatorDoctrineChoice(array('model' => 'Lieu',
																		   'required' => true,
																		   'query' => Doctrine::getTable('Lieu')->createQuery('a')->addwhere('a.type_id = ?', $this->type_id)),
																	array('required' => 'Champ obligatoire',
																		  'invalid' => 'Champ invalide')));
																
		
		//Champ "date_debut"
		$this->setWidget('date_debut', new ecWidgetFormDateRich(array('buttonImage' => '/images/icones/16/date.png'), 
														  array('class' => $class,
															    'size' => 20)));
		$this->setValidator('date_debut', new sfValidatorDate(array('date_format' => '@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@',
														   'required' => true), 
													 array('required' => 'Champ obligatoire',
													 	   'invalid' => 'Date invalide',
													 	   'bad_format' => 'Date invalide')));

		//Champ "date_fin"
		$this->setWidget('date_fin', new ecWidgetFormDateRich(array('buttonImage' => '/images/icones/16/date.png'), 
														  array('class' => $class,
															    'size' => 20)));
		$this->setValidator('date_fin', new sfValidatorDate(array('date_format' => '@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@',
														   'required' => false), 
													 array('invalid' => 'Date invalide',
													 	   'bad_format' => 'Date invalide')));
		
		//Champ "titre"
		$this->setWidget('titre', new sfWidgetFormInputText(array(), array('class' => $class,
																	 'size' => 50)));
		
		$this->setValidator('titre', new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 5,
  																'max_length' => 55),
  														  array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi')));
		
		//Champ "description"
		$this->setWidget('description', new sfWidgetFormTextarea(array(), array('class' => $class,
																	 			'rows' => 5,
																	 			'cols' => 50)));
		
		$this->setValidator('description', new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 5,
  																'max_length' => 1000),
  														  array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi')));
  		
  														  
  		//Champ "flyer1"
  		$this->setWidget('flyer1', new sfWidgetFormInputFile(array(), array('class' => $class)));
  																  
  		$this->setValidator('flyer1', new sfValidatorFile(array('max_size' => 2000000,
  															   'mime_types' => array('image/jpeg'),
  															   'required' => false),
  														 array('max_size' => 'La photo doit faire 2Mo maximum',
  														 	   'mime_types' => 'Format du fichier incorrect')));
  														 
  		//Champ "flyer2"
  		$this->setWidget('flyer2', new sfWidgetFormInputFile(array(), array('class' => $class)));
  																  
  		$this->setValidator('flyer2', new sfValidatorFile(array('max_size' => 2000000,
  															   'mime_categories' => array('image/jpeg'),
  															   'required' => false),
  														 array('max_size' => 'La photo doit faire 2Mo maximum',
  														 	   'mime_types' => 'Format du fichier incorrect')));
		
  		//Champ "active"
		$choices = array(0 => 'Non', 1 => 'Oui');
		$this->setWidget('active', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('active', new sfValidatorChoice(array('choices' => array_keys($choices),
																	 'required' => true),
															   array('invalid' => 'Champ invalide',
															   	 	 'required' => 'Champ obligatoire')));
		$this->setDefault('active', 1);														 
  														 
		
		//Champ "heure_debut"
		$this->setWidget('heure_debut', new sfWidgetFormInputText(array(), array('class' => $class,
																	 'size' => 7)));
		$regular_expression = '/^((0?[0-9])|(1[0-9])|(2[0-4])):[0-5][0-9]$/i';
		$this->setValidator('heure_debut', new sfValidatorRegex(array('required' => false,
																	  'pattern' => $regular_expression),
																array('invalid' => 'Heure invalide')));
																
		//Champ "heure_fin"
		$this->setWidget('heure_fin', new sfWidgetFormInputText(array(), array('class' => $class,
																	 'size' => 7)));
		$this->setValidator('heure_fin', new sfValidatorRegex(array('required' => false,
																	  'pattern' => $regular_expression),
																array('invalid' => 'Heure invalide')));
																
		//Champs désactives car traites plus tard
		unset($this['active_index']);
		unset($this['auteur_membre_id']);
		unset($this['image_1']);
		unset($this['image_2']);
		unset($this['image_1_truncate']);
		unset($this['image_2_truncate']);
		
		//Champs desactives car traites par SF
		unset($this['created_at']);
		unset($this['id']);
		
		//Validateur général
      	//appelé apres tous les validateurs individuels
		$this->validatorSchema->setPostValidator(
		new sfValidatorCallback(array('callback' => array($this, 'validateurGeneral'))));											
	}
	
	//Fonction appelée par le validateur général
	public function validateurGeneral($validator, $values)
	{
		//On verifie si la date de début et la date de fin on été remplit par l'utilisateur
		if(!empty($values['date_debut']) && !empty($values['date_fin']))
		{
			//Si les deux sont remplit, on verifie que la date de début soit avant la date de fin, sinon erreur
			if($values['date_debut'] > $values['date_fin'])
			{
				$error = new sfValidatorError($validator, 'La date de début doit être inférieure à la date de fin');
				throw new sfValidatorErrorSchema($validator, array('date_fin' => $error));
			}
		}
		return $values;
	}
	
	
	
	public function bind(array $taintedValues = null, array $taintedFiles = null)
	{
		//On binde le formulaire. Pour le moment aucun validateur n'a été declanché.
		
		//Mise à jour de la variable privee 'type_id' (derniere valeur selectionnee dans la liste de tri)
		if(!empty($taintedValues['type_id']))
		{
			$this->setSelectTypeId($taintedValues['type_id']);
		}
		
		//On procede maintenant au BIND du formulaire. Les données membres de l'objet "Form" vont etre
		//remplis en fonction du request ($taintedValues), puis la fonction va proceder à la vérification du
		//formulaire
		parent::bind($taintedValues, $taintedFiles);
		
		//Le formulaire a été vérifie (avec ou sans erreurs)
		
	}
	
	
	/**
	 * Fonction apelee quand formulaire valide
	 * @param sfActions $action
	 * @return Evenement
	 */
	public function processForm(sfActions $action)
	{
		//On recupere l'objet Evenement
		$evenement = $this->getObject();
		
		//Si les images ne sont pas présentes, on desactive les widgets associes
		//pour eviter une erreur SF
		for($i=1; $i<=2; $i++)
		{
			$image = $this->getValue('flyer'.$i);
			if(empty($image))
			{
				unset($this['flyer'.$i]);
			}
		}
		
		//Si l'objet est nouveau, on ajoute l'auteur de l'evenement et on passe l'activation sur index à 0
		if($evenement->isNew())
		{
			$membre_id = MembreTable::getMembreIdConnecte();
			$evenement->setAuteurMembreId($membre_id);
			$evenement->setActiveIndex(0);
		}
		
		//Si on passe l'evenement en actif 
		if(!$evenement->isNew() && $evenement->getActive() == 0 && $this->getValue('active') == 1)
		{
			//On envoie un message perso de notification à l'auteur
			$expediteur_id = MembreTable::getMembreIdConnecte();
			$destinataire_id = $evenement->getMembre()->getId();
			$sujet = sfConfig::get('sujet_active_evenement', 'Date acceptée');
			
			//Si l'expditeur est égal au destinataire (une personne qui accepte son propre evenement)
			//on envoie pas le mail
			if($expediteur_id != $destinataire_id)
			{
				$message = new Message();
				$message->setTitre($sujet);
				$message->setExpediteurMembreId($expediteur_id);
				$message->setDestinataireMembreId($destinataire_id);
				$message->setMessage($action->getPartial('mailBody', array('nom' => $this->getValue('titre'))));
				$message->setLu(0);
				$message->save();
			}
		
		}
		
		
		//Si l'evenement est actif et que le lieu associe n'est pas actif,
		//on passe le lieu en actif
		/*
		 *Option desactivee, par demande du client 
		 
		$lieu = Doctrine::getTable('Lieu')->find($this->getValue('lieu_id'));
		if($lieu->getActive() == 0)
		{
			$lieu->setActive(1);
			$lieu->save();
		}
		*/
		
		//On sauvegarde les données
		$evenement = $this->save();
		
		//Si la date de fin n'est pas precisee, on l'ajoute (la meme que la date de debut)
		$date_fin = $this->getValue('date_fin');
		if(empty($date_fin))
		{
			$evenement->setDateFin($this->getValue('date_debut'));
		}
		
		//On traite les nouvelles images
		$dossier_images = sfConfig::get('app_uploads_images_agenda');
		
		for($i=1; $i<=2; $i++)
		{
			$image = $this->getValue('flyer'.$i);
			if(!empty($image))
			{
				//On regarde si une ancienne photo est presente, et si oui on la supprime
				$ancienne_image = $evenement->get('image_'.$i);
				if(!empty($ancienne_image) && file_exists($dossier_images.'/'.$ancienne_image))
				{
					unlink($dossier_images.'/'.$ancienne_image);
				}
				
				//On regarde si une l'image tronquee est presente, et si oui on la supprime
				//de la BDD et du serveur de fichiers
				$image_tronquee = $evenement->get('image_'.$i.'_truncate');
				if(!empty($image_tronquee) && file_exists($dossier_images.'/'.$image_tronquee))
				{
					unlink($dossier_images.'/'.$image_tronquee);
				}
				$evenement->set('image_'.$i.'_truncate', null);
				
				//On ajoute la nouvelle photo
				$extension = $image->getExtension($image->getOriginalExtension());
				$name = 'event_'.$evenement->getId().'_image_'.$i.$extension;
				$image->save($dossier_images.'/'.$name);
				
				//On mets à jour la BDD avec cette nouvelle valeur
				$evenement->set('image_'.$i, $name);
			}
		}
		
		//On sauvegarde le tout
		$evenement->save();
		
		//On vide le cache des images du lieu
		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_agenda').'/'.$evenement->getId();
		Util::deleteFolder($folder_cache);
		
		//On affiche le message de confirmation
		$user = $action->getUser();
		$user->setFlash('bo_agenda_form_ok', 'Evénement sauvegardé');
		
		return $evenement;
	}
	
	
	
	
	
	
	public function setSelectTypeId($type_id)
	{
		$this->type_id = $type_id;
		//On regenere les widgets pour qu'ils prennent cette nouvelle valeur
		$this->configure();
	}
	
}