<?php

/**
 * GalerieArtsCategorie form.
 *
 * @package    form
 * @subpackage GalerieArtsCategorie
 * @version    SVN: $Id: GalerieArtsCategorieForm.class.php 375 2010-08-25 09:21:15Z hlecorche $
 */
class GalerieArtsCategorieForm extends BaseGalerieArtsCategorieForm
{
  public function configure()
	{
		$class = 'fields';
		
		unset($this['id']);
		
		//Widget Nom
		$this->setWidget('nom', new sfWidgetFormInputText(array(), array('size' => '50',
																	 'class' => $class)));
		$this->setValidator('nom', new sfValidatorString(array('max_length' => 55,
															   'min_length' => 3,
															   'required' => true,
															   'trim' => true),
														 array('max_length' => '%max_length% caractères maxi.',
														 	   'min_length' => '%min_length% caractères mini.',
														 	   'required' => 'Champ obligatoire')));
	
		//Champ vignette
		$this->setWidget('file_vignette', new sfWidgetFormInputFile(array(), array('class' => $class)));
  																  
  		$this->setValidator('file_vignette', new sfValidatorFile(array('max_size' => 2000000,
  															   'mime_types' => array('image/jpeg'),
  															   'required' => false),
  														 array('max_size' => 'La photo doit faire 2Mo maximum',
  														 	   'mime_types' => 'Format du fichier incorrect')));
		
		//Widget active
		$choices = array(0 => 'Non', 1 => 'Oui');
		$this->setWidget('active', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('active', new sfValidatorChoice(array('choices' => array_keys($choices),
																	 'required' => true),
															   array('invalid' => 'Champ invalide',
															   	 	 'required' => 'Champ obligatoire')));
		$this->setDefault('active', 1);
	}
	
	
	
	
	/**
	 * Fonction apelee quand formulaire valide
	 * @param sfActions $action
	 * @return GalerieArtsCategorie
	 */
	public function processForm(sfActions $action)
	{
		//On recupere l'objet GalerieArtsCategorie
		$categorie = $this->getObject();
		
		//Si l'images n'est pas présente, on desactive le widget associe
		//pour eviter une erreur SF
		$image = $this->getValue('file_vignette');
		if(empty($image))
		{
			unset($this['file_vignette']);
		}
		
		//On sauvegarde les données
		$categorie = $this->save();
		
		//On traite les nouvelles images
		$dossier_images = sfConfig::get('app_uploads_images_galeries');
		
		if(!empty($image))
		{
			//On regarde si une ancienne photo est presente, et si oui on la supprime
			$ancienne_image = $categorie->getVignette();
			if(!empty($ancienne_image) && file_exists($dossier_images.'/'.$ancienne_image))
			{
				unlink($dossier_images.'/'.$ancienne_image);
			}
				
			//On ajoute la nouvelle photo
			$extension = $image->getExtension($image->getOriginalExtension());
			$name = 'vignette_categorie_'.$categorie->getId().$extension;
			$image->save($dossier_images.'/'.$name);
				
			//On mets à jour la BDD avec cette nouvelle valeur
			$categorie->setVignette($name);
		}		
		
		//On sauvegarde le tout
		$categorie->save();
		
		//On vide le cache des categories
		$folder_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_galeries').'/categories';
		Util::deleteFolder($folder_cache);
		
		return $categorie;
	}
}