<?php

/**
 * GalerieArts form.
 *
 * @package    form
 * @subpackage GalerieArts
 * @version    SVN: $Id: GalerieArtsForm.class.php 381 2010-08-26 09:18:49Z hlecorche $
 */
class GalerieArtsForm extends BaseGalerieArtsForm
{

	public function configure()
	{

		$class = "fields";

	

		//Champ "nom"
		$this->setWidget('nom', new sfWidgetFormInputText(array(), array('class' => $class,
																	 'size' => 50)));

		$this->setValidator('nom', new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 3,
  																'max_length' => 50),
															array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi')));
		
		//Champ "galerie_arts_categorie_id"
		$this->setWidget('galerie_arts_categorie_id', new sfWidgetFormDoctrineChoice(array('model' => 'GalerieArtsCategorie',
																						   'add_empty' => true),
																				     array()));
		$this->setValidator('galerie_arts_categorie_id', new sfValidatorDoctrineChoice(array('model' => 'GalerieArtsCategorie',
																							 'required' => true),
																					   array('invalid' => 'Champ invalide',
																					   		 'required' => 'Champ obligatoire')));													
		
		//Champ "email"
		$this->setWidget('email', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 30)));
  		
  		$this->setValidator('email', new sfValidatorEmail(array('required' => true,
  																  'trim' => true,
  																  'min_length' => 3,
  																  'max_length' => 100),
  														  	array('min_length'=> '%min_length% caractères mini',
  														  		  'max_length'=> '%max_length% caractères maxi',
  														  		  'invalid' => 'Adresse e-mail invalide',
  														  		  'required' => 'Champ obligatoire')));

  														  	
  		//Champ "url_site"												  	
  		$this->setWidget('url_site', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 30)));	
  		$this->setValidator('url_site', new sfValidatorUrl(array('required' => false,
  																	'min_length' => 10,
  																	'max_length' => 255,
  																	'trim' => true),
  														  	   array('invalid' => 'Adresse invalide',
  														  			 'min_length'=> '%min_length% caractères mini',
  														  			 'max_length'=> '%max_length% caractères maxi')));													  	
  														  	
		//Champ "description"
		$this->setWidget('description', new sfWidgetFormTextarea(array(), array('class' => $class,
																	 			'rows' => 5,
																	 			'cols' => 50)));

		$this->setValidator('description', new sfValidatorString(array('required' => true,
		  																'trim' => true,
		  																'min_length' => 5,
		  																'max_length' => 500),
																array('required' => 'Champ obligatoire',
  														  			'min_length'=> '%min_length% caractères mini',
  														  			'max_length'=> '%max_length% caractères maxi')));
		//Champ "is_galerie_video"
		$choices = array(0 => 'Galerie photos', 1 => 'Galerie vidéos');
		$this->setWidget('is_galerie_video', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('is_galerie_video', new sfValidatorChoice(array('choices' => array_keys($choices),
																  			'required' => true),
																		array('invalid' => 'Champ invalide',
															   	  			 'required' => 'Champ obligatoire')));
		$this->setDefault('is_galerie_video', 0);
		

		//Champ "archive"
		$this->setWidget('archive', new sfWidgetFormInputFile(array(), array('class' => $class)));

		$this->setValidator('archive', new sfValidatorFile(array('max_size' => 20000000,
  															   'mime_types' => array('application/zip', 'multipart/x-zip', 'application/x-zip-compressed', 'application/x-zip'),
  															   'required' => false),
															array('max_size' => 'La photo doit faire 20 Mo maximum',
  														 	   'mime_types' => 'Format du fichier incorrect (.zip)')));
			
		//Champ "active"
		$choices = array(0 => 'Non', 1 => 'Oui');
		$this->setWidget('active', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('active', new sfValidatorChoice(array('choices' => array_keys($choices),
																  'required' => true),
															array('invalid' => 'Champ invalide',
															   	 	 'required' => 'Champ obligatoire')));
		$this->setDefault('active', 1);
			
		//Champs désactives car traites plus tard
		unset($this['path_dossier']);

		//Champs desactives car traites par SF
		unset($this['created_at']);
		unset($this['id']);

	}








	/**
	 * Fonction apelee quand formulaire valide
	 * @param sfActions $action
	 * @return GalerieArts
	 */
	public function processForm(sfActions $action)
	{
		$user = $action->getUser();

		//On recupere l'objet GalerieArts
		$galerie = $this->getObject();

		//Si l'archive n'est pas presente, on desactive le widget associe
		//pour eviter une erreur SF
		$archive = $this->getValue('archive');
		if(empty($archive))
		{
			unset($this['archive']);
		}

		//Si l'objet est nouveau, on ajoute passe le chemin à vide (il sera modifié plus bas)
		if($galerie->isNew())
		{
			$galerie->setPathDossier('');
		}
		
		//On sauvegarde les données
		$galerie = $this->save();

		//Si archive présente, on la traite
		if(!empty($archive))
		{
			$galerie = $this->processArchive($archive, $galerie, $user);
			
			//Mise à jour du repertoire de la galerie
			$dossier = sfConfig::get('app_dossiers_images_galeries');
			$galerie->setPathDossier($dossier.'/'.$galerie->getId());
			$galerie->save();			
		}

		//On affiche le message de confirmation
		
		$user->setFlash('bo_galeries_form_ok', 'Galerie sauvegardée');

		return $galerie;
	}



	
	
	
	/**
	 * Fonction privee qui traite l'archive envoyee
	 * @param File $archive
	 * @param GalerieArts $galerie
	 * @param sfUser $user
	 * @return GalerieArts $galerie
	 */
	private function processArchive($archive, $galerie, $user)
	{
		$nombre_photos_ajoutees = 0;
		$nombre_videos_ajoutees = 0;
		
		//On cherche le nom que va avoir notre premier fichier importé
		$id_photo = 1;
		$id_video = 1;
		
		if(!$galerie->isNew())
		{
			//On cherche pour la photo
			$search = Doctrine::getTable('GalerieArtsMedia')->createQuery('m')
			->select("substr(nom_fichier, locate('_', m.nom_fichier) + 1, locate('.', m.nom_fichier) - locate('_', m.nom_fichier) - 1) as nombre")
			->where('m.galerie_arts_id = ?', $galerie->getId())
			->addWhere('m.is_video = 0')
			->fetchArray();
				
			if(count($search) > 0)
			{
				$id_photo = max($search);
				$id_photo = $id_photo['nombre'] + 1;
			}
				
			//On cherche pour la video
			$search = Doctrine::getTable('GalerieArtsMedia')->createQuery('m')
			->select("substr(nom_fichier, locate('_', m.nom_fichier) + 1, locate('.', m.nom_fichier) - locate('_', m.nom_fichier) - 1) as nombre")
			->where('m.galerie_arts_id = ?', $galerie->getId())
			->addWhere('m.is_video = 1')
			->fetchArray();
				
			if(count($search) > 0)
			{
				$id_video = max($search);
				$id_video = $id_video['nombre'] + 1;
			}
		}
		
		//Si le dossier de le galerie n'existe pas, on le cree
		$dossier_galerie = sfConfig::get('app_uploads_images_galeries').'/'.$galerie->getId();
		if(!is_dir($dossier_galerie))
		{
			mkdir($dossier_galerie, 0775, true);
		}	
			
		//On genere un nom temporaire
		$name_temp = MembreTable::getMembreIdConnecte().rand(0, 1000);
			
		//On creer dans le repertoire temporaire, un sous repertoire (appele sous-repertoire temporaire)
		//portant le nom temporaire
		$dossier_temporaire = sfConfig::get('app_uploads_dossier_temporaire');
		$sous_dossier_temporaire = $dossier_temporaire.'/'.$name_temp;
		mkdir($sous_dossier_temporaire, 0775, true);
			
		//On met dans le repertoire temporaire le fichier .zip, portant le nom temporaire
		$extension = $archive->getExtension($archive->getOriginalExtension());
		$name_archive = $name_temp.$extension;
		$archive->save($dossier_temporaire.'/'.$name_archive);
		
		//On dezippe l'archive dans le sous repertoire temporaire
		$zip = new ZipArchive();
		if($zip->open($dossier_temporaire.'/'.$name_archive))
		{
			$zip->extractTo($sous_dossier_temporaire.'/');
			$zip->close();
		}
			
		//On recupere les fichiers un par un
		if(is_dir($sous_dossier_temporaire))
		{ 
			foreach(scandir($sous_dossier_temporaire) as $file)
			{
				if($file != "." && $file != "..")
				{
					$extension = stristr($file, '.');
					$file = $sous_dossier_temporaire.'/'.$file;
					
					//Si fichier correct (jpeg ou flv), on le déplace au bon endroit
					//en le renommant, et on l'ajoute en base de données
					if($extension == '.jpeg' || $extension == '.jpg' || $extension == '.JPEG' || $extension == '.JPG')
					{
						//C'est une image
						$new_file = $dossier_galerie.'/photo_'.$id_photo.'.jpg';
						copy($file, $new_file);
						$media = new GalerieArtsMedia();
						$media->setGalerieArtsId($galerie->getId());
						$media->setIsVideo(0);
						$media->setNomFichier('photo_'.$id_photo.'.jpg');
						$media->save();
					
						$id_photo = $id_photo + 1;
						$nombre_photos_ajoutees = $nombre_photos_ajoutees + 1;
					}
					elseif($extension == '.flv' || $extension == '.FLV')
					{
						//C'est une video
						$new_file = $dossier_galerie.'/video_'.$id_video.'.flv';
						copy($file, $new_file);
						$media = new GalerieArtsMedia();
						$media->setGalerieArtsId($galerie->getId());
						$media->setIsVideo(1);
						$media->setNomFichier('video_'.$id_video.'.flv');
						$media->save();
						
						$id_video = $id_video + 1;
						$nombre_videos_ajoutees = $nombre_videos_ajoutees + 1;
					}
				}
			}
		}
			
			//On supprime l'archive
			unlink($dossier_temporaire.'/'.$name_archive);
			
			//On supprime le sous repertoire temporaire
			Util::deleteFolder($sous_dossier_temporaire);
			
			//On affiche le nombre de medias ajoutés
			$user->setFlash('bo_galeries_upload_ok', $nombre_photos_ajoutees.' photos et '.$nombre_videos_ajoutees.' vidéos ajouté(es)');
		
		return $galerie;
	}
}