<?php

/**
 * LieuGalerieMedia form.
 *
 * @package    form
 * @subpackage LieuGalerieMedia
 * @version    SVN: $Id: LieuGalerieMediaForm.class.php 375 2010-08-25 09:21:15Z hlecorche $
 */
class LieuGalerieMediaForm extends BaseLieuGalerieMediaForm
{
	public function configure()
	{
		 $class = 'fields';
		 
		 //Widget "lieu_id"
		 $this->setWidget('lieu_id', new sfWidgetFormInputHidden());
		 
		 //Si l'option "force_lieu_id" est presente, on force la valeur (utilisee dans le FO pour
		 //qu'une personne ne modifie que son lieu
		 if($this->getOption('force_lieu_id'))
		 {
		 	$this->setDefault('lieu_id', $this->getOption('force_lieu_id'));
		 	$query = Doctrine::getTable('Lieu')->createQuery('a')->addWhere('a.id = ?', $this->getOption('force_lieu_id'));
		 	$this->setValidator('lieu_id', new sfValidatorDoctrineChoice(array('model' => 'Lieu',
		 																	   'query' => $query)));
		 }
		 
		 //Widget "titre"
		 $this->setWidget('titre', new sfWidgetFormInputText(array(), array('class' => $class,
		 																'size' => 50)));
		 
		 $this->setValidator('titre', new sfValidatorString(array('required' => false,
		 														  'trim' => true,
		 														  'max_length' => 255),
		 													array('max_length' => '%max_length% caractères maxi.')));
		 													
		//Champ "image"
  		$this->setWidget('image', new sfWidgetFormInputFile(array(), array('class' => $class)));
  		//on verifie si on ajoute ou on edite une image, pour savoir si le champ image est obligatoire ou pas
  		//Ajout : Champ obligatoire
  		//Edition: Champ facultatif
  		$required = $this->getObject()->isNew();												  
  		$this->setValidator('image', new sfValidatorFile(array('max_size' => 200000,
  															   'mime_types' => 'web_images',
  															   'required' => $required),
  														 array('max_size' => '200Ko maximum',
  														 	   'mime_types' => 'Format du fichier incorrect',
  														 		'required' => 'Vous n\'avez pas séléctionné un fichier')));
	
  		//Champ désactive car traite plus tard
  		unset($this['nom_fichier']);

  		unset($this['id']);
  														 
	}
	
	
	
 	/* Fonction qui enregistre ou modifie une image dans la base, et qui gere l'image associée
	 * @param sfActions $action
	 * @return LieuGalerieMedia
	 */
	public function ProcessForm(sfActions $action){

		//on recupere l'objet media
		$media = $this->getObject();
		
		//On recupere l'id du lieu associe
		$lieu_id = $this->getValue('lieu_id');
		
		//on recupere le dossier ou stocker les photos
		$dossier = sfConfig::get('app_uploads_images_galeries_lieux');
		
		//on recupere le fichier de l'image
		$image = $this->getValue('image');
		
	
		//si l'image est vide on desactive son validateur pour eviter un bug de doctrine
		if(empty($image))
		{
			unset($this['image']);
		}
		
		$media_new = false;
		//si l'objet est nouveau, on met temporairement son champ nom_fichier a # pour eviter 
		//une erreur mysql de champ null
		if($media->isNew())
		{
			$media->setNomFichier('#');	
			$media_new = true;
		}
		
		//on enregistre l'objet media
		$media = $this->save();	
		
		//si l'image n'est pas vide on l'enregistre puis on remplit le champ nom_fichier avec un 
		//nom que l'on crée et on re-sauvegarde l'enregistrement
		if(!empty($image))
		{
			//on supprime l'ancienne image si elle existe en BDD et sur le serveur
			$ancienne_image = $media->getNomFichier();
			if(!empty($ancienne_image) && !$media_new && file_exists($dossier.'/'.$ancienne_image))
			{
				unlink($dossier.'/'.$ancienne_image);
			}
			
			$extension = $image->getExtension($image->getOriginalExtension());
			$nom_fichier= $lieu_id.'/image_'.$media->getId().$extension;
			$image->save($dossier.'/'.$nom_fichier);
			$media->setNomFichier($nom_fichier);
			$media->save();
		}
		
		//On vide le cache des images de la galerie
		$dossier_cache = sfConfig::get('app_dossiers_cache_images').'/'.sfConfig::get('app_dossiers_images_galeries_lieux').'/'.$lieu_id;
		Util::deleteFolder($dossier_cache, true);
		
		//Message de confirmation (sauf si on vient du FO)
		if(!$this->getOption('force_lieu_id'))
		{
			$user=$action->getUser();
			$user->setFlash('bo_lieux_message_ok', 'Photo sauvegardée');
		}
				
		return $media;
	}
}