<?php

/**
 * LieuVideo form.
 *
 * @package    anbnws
 * @subpackage form
 * @author     Hubert LECORCHE
 * @version    SVN: $Id: LieuVideoForm.class.php 434 2010-09-27 18:40:29Z hlecorche $
 */
class LieuVideoForm extends BaseLieuVideoForm
{
	const pattern = '/("(?P<url_youtube>http:\/\/www\.youtube\.com\/v\/[a-zA-Z0-9_-]+))/';
	
	public function configure()
	{
		$class = 'fields';
		
		$this->useFields(array('lieu_id', 'titre'));
		 
		 //Widget "lieu_id"
		 $this->setWidget('lieu_id', new sfWidgetFormInputHidden());
		
		 //Si l'option "force_lieu_id" est presente, on force la valeur (utilisee dans le FO pour
		 //qu'une personne ne modifie que son lieu
		 if($this->getOption('force_lieu_id'))
		 {
		 	$this->setDefault('lieu_id', $this->getOption('force_lieu_id'));
		 	$query = Doctrine::getTable('Lieu')->createQuery('a')->addWhere('a.id = ?', $this->getOption('force_lieu_id'));
		 	$this->setValidator('lieu_id', new sfValidatorDoctrineChoice(array('model' => 'Lieu',
		 																	   'query' => $query)));
		 }
		 
		 //Widget "titre"
		 $this->setWidget('titre', new sfWidgetFormInputText(array(), array('class' => $class,
		 																'size' => 50)));
		 
		 $this->setValidator('titre', new sfValidatorString(array('required' => false,
		 														  'trim' => true,
		 														  'max_length' => 255),
		 													array('max_length' => '%max_length% caractères maxi.')));
		 													
		 													
		//Champ "video"
		if($this->isNew())
		{
			$this->setWidget('video', new sfWidgetFormTextarea(array(), array('class' => $class,
																			  'rows' => 4,
																			  'cols' => 30)));
	
			$this->setValidator('video', new sfValidatorRegex(array('required' => true,
	  																'trim' => true,
	  																'min_length' => 3,
	  																'max_length' => 5000,
																	'pattern' => self::pattern),
																array('required' => 'Champ obligatoire',
	  														  		'min_length'=> '%min_length% caractères mini',
	  														  		'max_length'=> '%max_length% caractères maxi',
																	'invalid' => 'Source invalide. Uniquement vidéos YouTube autorisées.')));
		}
	}
	
	
	/**
	 * Fonction appelee quand formulaire valide
	 * @param sfActions action
	 * @return
	 */
	public function processForm(sfActions $action)
	{
		$user = $action->getUser();
		
		if($this->isNew())
		{
			try
			{
				//On creer une transaction
				$conn = Doctrine::getTable('LieuVideo')->getConnection();
				$conn->beginTransaction();
				
				//On recupere l'objet Video
				$video = $this->getObject();
				
				//On configure l'url de la video
				$video->setUrl(self::generateUrl($this->getValue('video')));
	
				//On sauvegarde l'enregistrement de l'objet MembreAlbum
				$video = $this->save($conn);
				
				//On commit la transaction
				$conn->commit();
				
				if(!$this->getOption('force_lieu_id'))
				{
					//Message de confirmation (sauf si on vient du FO)
					$user->setFlash('bo_lieux_message_ok', 'Vidéo ajoutée avec succès.');
				}
				return $video;
				
			}
			catch(Exception $e)
			{
				$conn->rollback();
				
				//Une erreur est survenue, on redirige vers le formulaire d'ajout
				//avec un message d'erreur (sauf si FO)
				if(!$this->getOption('force_lieu_id'))
				{
					$user->setFlash('bo_lieux_message_error', 'Une erreur est survenue pendant la sauvegarde de la vidéo.');
				}
				return false;
			}
		}
		else
		{
			$video = $this->save();
			if(!$this->getOption('force_lieu_id'))
			{
				//Message de confirmation (sauf si on vient du FO)
				$user->setFlash('bo_lieux_message_ok', 'Vidéo éditée avec succès.');
			}
			return $video;
		}
	}
	
	
	
	
	/**
 	 * Fonction qui retourne l'url d'une video, en fonction  du code source donne
 	 * par l'utilisateur
 	 * @param String $source Source donnee par l'utilisateur
 	 * @return String Url de la video
 	 */
 	public static function generateUrl($source)
 	{
 		if(preg_match(self::pattern, $source, $matches))
 		{
 			if(!empty($matches['url_youtube']))
 			{
 				return $matches['url_youtube'];
 			}
 			else
 			{
 				return '';
 			}
 		}
 		else
 		{
 			return '';
 		}
 	}
}
