<?php

/**
 * MembreGuestbook form.
 *
 * @package    form
 * @subpackage MembreGuestbook
 * @version    SVN: $Id: MembreGuestbookForm.class.php 377 2010-08-25 11:43:20Z hlecorche $
 */
class MembreGuestbookForm extends BaseMembreGuestbookForm
{
  public function configure()
  {
  	//Champ id, desactive car inutile
	unset($this['id']);
		
	//Champ membre_id, desactive, car sera ajoute manuellement dans l'action
	unset($this['membre_id']);
	
	//Champ posteur_membre_id, desactive, car sera ajoute manuellement dans l'action
	unset($this['posteur_membre_id']);
	
	//Champs created_at, descative car gere par Doctrine
	unset($this['created_at']);
  	
  	//Champ message
	$this->setWidget('message', new sfWidgetFormInputText(array(), array('class' => 'fields', 'size' => 35)));
	$this->setValidator('message', new sfValidatorString(array('max_length' => 255,
																'min_length' => 3,
															 	'trim' => true),
														 array('required' => 'Message non précisé',
															 	'max_length' => '255 caractères maxi.',
														 		'min_length' => '3 caractères mini')));
															 
	
  }
  /**
   * fonction apellée lorsque le formulaire est validé
   * enregistre le message dans la table "membre_guestbook" (apres tests de securité)
   * @param membresActions $action objet de type membresActions
   * @param Membre $membre membre qui recoit le message
   * @return unknown_type
   */
	public function ProcessForm($action,$membre){

		$user = $action->getUser();
		
		//on recupere l'id du membre connecté (le membre qui poste le message)
		$posteur_membre_id = MembreTable::getMembreIdConnecte();
		
		//on recupere le temps a attendre entre deux messages dans le livre d'or
		$delai = intval(sfConfig::get('app_livre_or_delai', '180'));
	
		//on calcule la date limite a partir delaquelle le membre n'a pas le droit de reposter sur ce livre d'or
		$date_limite=date('Y-m-d H:i:s',time()-$delai); 
		
		//on fait une requete pour afficher un message posté par ce membre, sur ce livre d'or,
		// qui date de moins de x secondes ( x definit dans le fichier de config)
		$messages = Doctrine::getTable('MembreGuestbook')->createQuery()
		->where('MembreGuestbook.created_at > ?',$date_limite)
		->addwhere('MembreGuestbook.membre_id = ?',$membre->getId())
		->addwhere('MembreGuestbook.posteur_membre_id = ?',$posteur_membre_id)
		->execute();
		
		//si cette requete nous renvoi au moins un resultat, le posteur n'a pas encore le droit de poster
		if($messages->count() > 0)
		{
			$user->setFlash('add_livre_or_time', 'Vous devez attendre '.$delai/60 .' minute(s) avant de poster de nouveau un message sur ce livre d\'or', false);
		}
		else
		{
		
			//On récupère l'objet "MembreGuestbook"
			$guestbook = $this->getObject();
			
			//on remplit le champ membre_id
			$guestbook->setMembreId($membre->getId());
			
			//on remplit le champ posteur_membre_id avec l'id du membre connecté
			$guestbook->setPosteurMembreId($posteur_membre_id);
			
			//on enregistre le tout dans la table
			$this->save();
			
			
			//on prepare l'expediteur du mail
			$expediteur=sfConfig::get('app_email_administrateur', 'contact@annecybynight.com');
			//on prepare le sujet du mail
			$sujet = sfConfig::get('app_email_sujet_livre_or', 'Livre d\'or');
			
			
			//on recupere l'adresse mail du membre a qui envoyer le message
			$destinataire= $membre->getEmail();
			
			//on prepare le corps du message en passant au partial qui contient ce corps
			//les infos dont il a besoin 
			$mailBody = $action->getPartial('mailLivreOr', array('membre' => $membre));
		
			// On cree le mail
			$message = Swift_Message::newInstance()
			->setFrom($expediteur)
			->setTo($destinataire)
			->setSubject($sujet)
			->setBody($mailBody, 'text/html');
		
			// On envoie le mail
			$action->getMailer()->send($message);
			
			//message de confirmation
			$user->setFlash('add_livre_or_ok', 'Votre message a bien été enregistré. Un email vient d\'être envoyé à cette personne pour la prevenir de votre message');
			
			//on se redirige vers le profil
			$action->redirect('membres/profil?id='.$membre->getId().'&tab='.membresActions::PUBLIC_PROFIL_TAB_LIVRE_OR);
		
		}

	
	}
  
  
  
  
}