<?php

/**
 * Partenaire form.
 *
 * @package    form
 * @subpackage Partenaire
 * @version    SVN: $Id: PartenaireForm.class.php 375 2010-08-25 09:21:15Z hlecorche $
 */
class PartenaireForm extends BasePartenaireForm
{
public function configure()
	{
		
		//Classe des champs du formulaire
  		$class = 'fields';
  		
  		//Champ desactive car traite dans le processForm
  		unset($this['url_image']);
  		
  		
  		
  		//Champ "image"
  		$this->setWidget('image', new sfWidgetFormInputFile(array(), array('class' => $class)));
  		//on verifie si on ajoute ou on edite un partenaire, pour savoir si le champ image est obligatoire ou pas
  		//Ajout : Champ obligatoire
  		//Edition: Champ facultatif
  		$required = $this->getObject()->isNew();												  
  		$this->setValidator('image', new sfValidatorFile(array('max_size' => 200000,
  															   'mime_types' => 'web_images',
  															   'required' => $required),
  														 array('max_size' => 'La photo doit faire 200ko maximum',
  														 	   'mime_types' => 'Format du fichier incorrect',
  														 		'required' => 'Vous n\'avez pas séléctionné un fichier')));
	
	
  		//Champ "url_lien"												 
  		$this->setWidget('url_lien', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 30)));	
  		$this->setValidator('url_lien', new sfValidatorUrl(array('required' => false,
  																	'min_length' => 10,
  																	'max_length' => 255,
  																	'trim' => true),
  														  	   array('invalid' => 'Adresse invalide (Format: http://....)',
  														  			 'min_length'=> '%min_length% caractères mini',
  														  			 'max_length'=> '%max_length% caractères maxi')));													 
  														 
  														 
		//Champ "active" 
		$liste_active = array(0 => 'Non', 1 => 'Oui');
  		$this->setWidget('active', new sfWidgetFormSelect(array('choices' => $liste_active), 
  														array('class' => $class)));
  		$this->setValidator('active', new sfValidatorChoice(array('choices' => array_keys($liste_active),
  																'required' => true),
  														  array('required' => 'Champ obligatoire',
  														  		'invalid' => 'Champ obligatoire')));
  		
  														  
  		//Champ "priorite"
  		$this->setWidget('priorite', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 4)));
  		$this->setValidator('priorite', new sfValidatorInteger(array('required' => true,
  																  'min' => 1,
  																  'max' => 100),
  																  array('required' => 'Champ obligatoire',
  																  		'min' => 'Le nombre doit être un entier compris entre 1 et 100',
  																  		'max' => 'Le nombre doit être  un entier compris entre 1 et 100',
  																  		'invalid' =>'Nombre invalide')));												  
  														  

  																  
  		//Champ desactive
  		unset($this['id']);														  
  																  
		$this->errorSchema = new sfValidatorErrorSchema($this->validatorSchema);
		
	}
	
	/**
	 * fonction qui enregistre ou modifie le partenaire dans la base, et qui gere l'image associée
	 * @param partenairesActions $action
	 * @return unknown_type
	 */
	public function ProcessForm($action){

		//on recupere l'objet partenaire
		$partenaire = $this->getObject();
		
		//on recupere le dossier ou stocker les photos
		$dossier = sfConfig::get('app_uploads_partenaires');
		
		//on recupere le fichier de l'image
		$image = $this->getValue('image');
		
	
		//si l'image est vide on desactive son validateur pour eviter un bug de doctrine
		if(empty($image))
		{
			unset($this['image']);
		}
		
		$isnew=false;
		//si l'objet est nouveau, on met temporairement son champ url_image a # pour eviter 
		//une erreur mysql de champ null
		if($partenaire->isNew())
		{
			$partenaire->setUrlImage('#');
			$isnew=true;
				
		}
		
		//on enregistre l'objet partenaire
		$partenaire = $this->save();	
		
		//si l'image n'est pas vide on l'enregistre puis on remplit le champ url_image avec un 
		//nom que l'on crée et on re-sauvegarde l'enregistrement
		if(!empty($image))
		{
			//on supprime l'ancienne image si elle existe en BDD et sur le serveur
			$ancienne_image = $partenaire->getUrlImage();
			if(!empty($ancienne_image)&& !$isnew && file_exists($dossier.'/'.$ancienne_image) )
			{
				unlink($dossier.'/'.$ancienne_image);
			}
			
			$extension = $image->getExtension($image->getOriginalExtension());
			$nom_fichier= 'partenaire_'.$partenaire->getId().'_'.rand(1,1000).$extension;
			$image->save($dossier.'/'.$nom_fichier);
			$partenaire->setUrlImage($nom_fichier);
			$partenaire->save();
		}
		
		
		
		//recuperation des données de navigation de l'utilisateur (pour pouvoir créer des messages flash
		$user=$action->getUser();
		
		$user->setFlash('partenaire_ok', 'Le partenaire a bien été sauvegardé');

		$action->redirect('partenaires/edit?id='.$partenaire->getId());
		
	
	}
}