<?php

/**
 * ReportageEcard form.
 *
 * @package    form
 * @subpackage ReportageEcard
 * @version    SVN: $Id: ReportageEcardForm.class.php 381 2010-08-26 09:18:49Z hlecorche $
 */
class ReportageEcardForm extends BaseReportageEcardForm
{
	public function configure()
	{
		$class = 'fields';
		
		//Champ "email"
		$this->setWidget('email', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 30)));
		$this->setValidator('email', new sfValidatorEmail(array('required' => true,
  																  'trim' => true,
  																  'min_length' => 3,
  																  'max_length' => 255),
  														  	array('min_length'=> '%min_length% caractères mini',
  														  		  'max_length'=> '%max_length% caractères maxi',
  														  		  'invalid' => 'Adresse e-mail invalide',
  														  		  'required' => 'Champ obligatoire')));
		
		//Champ "objet"
		$this->setWidget('objet', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 30)));
  		
  		$this->setValidator('objet', new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 4,
  																'max_length' => 255),
  														  array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi')));
	
		//Champ "message"
		$this->setWidget('message', new sfWidgetFormTextarea(array(), array('class' => $class,
																	 			'rows' => 5,
																	 			'cols' => 50)));
		
		$this->setValidator('message', new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 5,
  																'max_length' => 1000),
  														  array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi')));

		//Champ "email_client"
		$this->setWidget('email_client', new sfWidgetFormInputCheckbox(array('value_attribute_value' => 1)
																), array('class' => $class));
		$this->setValidator('email_client', new sfValidatorChoice(array('required' => false,
																		'choices' => array(1)),
																  array('invalid' => 'Champ invalide')));
		
		//Champ captcha
  		$this->setWidget('captcha', new sfWidgetFormInputText(array(), array('class' => $class,
  																		'size' => 25)));
  		$this->setValidator('captcha', new sfValidatorSfCryptoCaptcha(array('required' => true, 
  																			'trim' => true),
                                                   					  array('wrong_captcha' => 'Code invalide',
                                                         					'required' => 'Champ obligatoire')));
		
		//Champs desactives car traites plus tard
		unset($this['membre_id']);
		unset($this['reportage_media_id']);
		unset($this['code_visualisation']);
		unset($this['lu']);
		unset($this['email_reply']);
		
		//Champ desactive car traite par SF
		unset($this['created_at']);
		unset($this['id']);
		
	}
	
	
	
	/**
	 * Action executee, si le formulaire est valide
	 * @param sfActions $action action
	 * @return unknown_type
	 */
	public function processForm($action)
	{
		//On recupere l'objet
		$ecard = $this->getObject();
		
		//On recupere l'ID de la personne connectee
		//et on l'associe comme auteur de l'ecard
		$membre = MembreTable::getMembreConnecte();
		$membre_id = $membre->getId();
		$ecard->setMembreId($membre_id);
		
		//On associe le media a l'ecard
		$media_id = $action->getRequest()->getParameter('id');
		$ecard->setReportageMediaId($media_id);
		
		//On construit un code de validation
		$code = md5('anbnws'.time().$membre_id.rand(0,20000));
		$ecard->setCodeVisualisation($code);
		$ecard->setLu(0);
		
		//Si la personne a cochée "inserrer mon email en reponse"
		//on ajoute son email à "email_reply"
		$email_client = $this->getValue('email_client');
		if(!empty($email_client) && $email_client == 1)
		{
			$ecard->setEmailReply($membre->getEmail());
		}
		
		//On sauvegarde l'ecard
		$ecard = $this->save();
		
		//On envoie le mail au destinataire
		$expediteur = sfConfig::get('app_email_expediteur', 'contact@annecybynight.com');
		$destinataire = $this->getValue('email');
		$sujet = sfConfig::get('app_email_sujet_ecard', 'Envoi d\'une ecard');
		$lien_visualisation = sfConfig::get('app_url_portail').'/reportages/zoomEcard?id='.$ecard->getId().'&cle='.$ecard->getCodeVisualisation();
		$mailBody = $action->getPartial('mailEcard', array('lien_visualisation' => $lien_visualisation,
														   'pseudo' => $membre->getPseudo(),
														   'prenom' => $membre->getPrenom()));
		
		$message = Swift_Message::newInstance()
		->setFrom($expediteur)
		->setTo($destinataire)
		->setSubject($sujet)
		->setBody($mailBody, 'text/html');
		if(!empty($email_client) && $email_client == 1)
		{
			$message->setReplyTo($membre->getEmail());
		}
		$action->getMailer()->send($message);
		
	}
}