<?php

/**
 * Reportage form.
 *
 * @package    form
 * @subpackage Reportage
 * @version    SVN: $Id: ReportageForm.class.php 429 2010-09-27 11:49:59Z hlecorche $
 */

require_once(dirname(__FILE__).'/../../../plugins/sfJqueryReloadedPlugin/lib/helper/jQueryHelper.php');
sfContext::getInstance()->getConfiguration()->loadHelpers('Url');

class ReportageForm extends BaseReportageForm
{
	/*
	 * Valeur de la variable type_id associee à l'événement.
	 * Cette valeur est utilisee pour: Afficher la valeur par défaut du filtre de recherche ("type_id". Afficher le
	 * contenu de la liste "lieu_id"
	 *
	 * Une fonction setSelectTypeId permet de modifier cette valeur puis apres de rappeler la methode configure()
	 * avant de refaire tous les widgets
	 *
	 * A la construction du formulaire, cette valeur est initialisee à partir de la valeur de l'objet (donc
	 * si objet nouveau, valeur nulle).
	 * Lorsque l'on change la valeur de la liste "type_id", on appel Ajax est généré, qui appele la fonction
	 * setSelectTypeId et qui envoie le nouveau widget
	 * Lorsque le formulaire est envoye par le client, lors du bind, la fonction setSelectTypeId est apelée (avec
	 * comme paramètre la valeur envoyée dans le request) pour mettre à jour cette variable.
	 */
	private $type_id = null;




	public function configure()
	{
		if(is_null($this->type_id) && !$this->getObject()->isNew())
		{
			$this->type_id = $this->getObject()->getLieu()->getTypeId(); //Ne pas utiliser le setter pour ne pas faire de boucle
		}

		$class = "fields";

		//Champ "type_id"
		//Quand la valeur de ce champ sera changé, un appel ajax sera fait pour actualiser le champ "lieu_id"
		$javascript = jq_remote_function(array('url' => 'reportages/ajaxListeLieux', 'update' => 'liste_lieu_id', 'with' => '{type_id: jQuery(this).val()}'));
		$this->setWidget('type_id', new sfWidgetFormDoctrineChoice(array('model' => 'Type', 'add_empty' => 'Selectionnez un type'), array('class' => $class, 'onchange' => $javascript)));
		$this->setValidator('type_id', new sfValidatorDoctrineChoice(array('model' => 'Type',
																		   'required' => true),
																	array('required' => 'Champ obligatoire',
																	 	   'invalid' => 'Champ invalide')));
		$this->setDefault('type_id', $this->type_id);

		//Champ "lieu_id"
		//Ce champ n'affiche pas la liste de tous les lieux (car trop longue).
		//On recupere la valeur $this->type_id (derniere valeur choisie dans ce champ)
		//et on affiche uniquement les lieux associes à ce type
		$query = Doctrine::getTable('Lieu')->createQuery('a')->where('a.type_id = ?', $this->type_id)->orderBy('a.nom ASC');
		$this->setWidget('lieu_id', new sfWidgetFormDoctrineChoice(array('model' => 'Lieu', 'query' => $query, 'add_empty' => 'Selectionnez un lieu'), array('class' => $class)));
		$query = Doctrine::getTable('Lieu')->createQuery('a')->addwhere('a.type_id = ?', $this->type_id);
		$this->setValidator('lieu_id', new sfValidatorDoctrineChoice(array('model' => 'Lieu',
																		   'required' => true,
																		   'query' => $query),
																	array('required' => 'Champ obligatoire',
																		  'invalid' => 'Champ invalide')));


		//Champ "date"
		$this->setWidget('date', new ecWidgetFormDateRich(array('buttonImage' => '/images/icones/16/date.png'),
														 array('class' => $class,
															    'size' => 20)));
		$this->setValidator('date', new sfValidatorDate(array('date_format' => '@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@',
														   'required' => true), 
														array('required' => 'Champ obligatoire',
													 	   'invalid' => 'Date invalide',
													 	   'bad_format' => 'Date invalide')));

		//Champ "titre"
		$this->setWidget('titre', new sfWidgetFormInputText(array(), array('class' => $class,
																	 'size' => 50)));

		$this->setValidator('titre', new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 3,
  																'max_length' => 255),
															array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi')));
		
															
		//Champ "lier_agenda"
		$choices = array(0 => 'Non', 1 => 'Oui');
		$this->setWidget('lier_agenda', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('lier_agenda', new sfValidatorChoice(array('choices' => array_keys($choices),
																  'required' => true),
															array('invalid' => 'Champ invalide',
															   	  'required' => 'Champ obligatoire')));													
		$this->setDefault('lier_agenda', (is_null($this->getObject()->getEvenementId()))? 0 : 1 );
															
		//Champ "description"
		$this->setWidget('description', new sfWidgetFormTextarea(array(), array('class' => $class,
																	 			'rows' => 5,
																	 			'cols' => 50)));

		$this->setValidator('description', new sfValidatorString(array('required' => true,
		  																'trim' => true,
		  																'min_length' => 5,
		  																'max_length' => 500),
																array('required' => 'Champ obligatoire',
  														  			'min_length'=> '%min_length% caractères mini',
  														  			'max_length'=> '%max_length% caractères maxi')));
		//Champ "is_reportage_video"
		/*
		 Reportages videos desactives
		$choices = array(0 => 'Reportage photos', 1 => 'Reportage vidéos');
		$this->setWidget('is_reportage_video', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('is_reportage_video', new sfValidatorChoice(array('choices' => array_keys($choices),
																  			'required' => true),
																		array('invalid' => 'Champ invalide',
															   	  			 'required' => 'Champ obligatoire')));
		$this->setDefault('is_reportage_video', 0);
		*/
		$choices = array(0 => 0);
		$this->setWidget('is_reportage_video', new sfWidgetFormInputHidden());
		$this->setValidator('is_reportage_video', new sfValidatorChoice(array('choices' => array_keys($choices),
																  			'required' => true),
																		array('invalid' => 'Champ invalide',
															   	  			 'required' => 'Champ obligatoire')));
		$this->setDefault('is_reportage_video', 0);
		

		//Champ "archive"
		$this->setWidget('archive', new sfWidgetFormInputFile(array(), array('class' => $class)));

		$this->setValidator('archive', new sfValidatorFile(array('max_size' => 20000000,
  															   'mime_types' => array('application/zip', 'multipart/x-zip', 'application/x-zip-compressed', 'application/x-zip' ),
  															   'required' => false),
															array('max_size' => 'La photo doit faire 20 Mo maximum',
  														 	   'mime_types' => 'Format du fichier incorrect (.zip)')));
			
		//Champ "active"
		$choices = array(0 => 'Non', 1 => 'Oui');
		$this->setWidget('active', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('active', new sfValidatorChoice(array('choices' => array_keys($choices),
																  'required' => true),
															array('invalid' => 'Champ invalide',
															   	 	 'required' => 'Champ obligatoire')));
		$this->setDefault('active', 1);
		
	
		

		//Champ "reporters_list"
		$liste_reporters = Doctrine::getTable('Membre')->createQuery('m')
		->where('m.level_id != ?', Level::LEVEL_UTILISATEUR)->orderBy('m.pseudo ASC')->execute();
		$reporters = array();
		foreach($liste_reporters as $reporter)
		{
			$reporters[$reporter->getId()] = $reporter->getPseudo();
		}	
		$this->setWidget('reporters_list', new sfWidgetFormSelectDoubleList(array('choices' => $reporters,
																				  'label_associated' => 'Reporters du reportage',
																				  'label_unassociated' => 'Reporters disponibles')));
		$this->setValidator('reporters_list', new sfValidatorChoice(array('multiple' => true, 'choices' => array_keys($reporters),
																			  'required' => true),
																		array('invalid' => 'Champ invalide',
																			  'required' => 'Un reporter minimum')));														
																	
		//Champs désactives car traites plus tard
		unset($this['active_index']);
		unset($this['path_dossier']);
		unset($this['evenement_id']);

		//Champs desactives car traites par SF
		unset($this['created_at']);
		unset($this['id']);
		
		//Champs virtuels
		unset($this['membres_presents_list']);

	}





	public function bind(array $taintedValues = null, array $taintedFiles = null)
	{
		//On binde le formulaire. Pour le moment aucun validateur n'a été declanché.

		//Mise à jour de la variable privee 'type_id' (derniere valeur selectionnee dans la liste de tri)
		if(!empty($taintedValues['type_id']))
		{
			$this->setSelectTypeId($taintedValues['type_id']);
		}

		//On procede maintenant au BIND du formulaire. Les données membres de l'objet "Form" vont etre
		//remplis en fonction du request ($taintedValues), puis la fonction va proceder à la vérification du
		//formulaire
		parent::bind($taintedValues, $taintedFiles);

		//Le formulaire a été vérifie (avec ou sans erreurs)

	}


	/**
	 * Fonction apelee quand formulaire valide
	 * @param sfActions $action
	 * @return Evenement
	 */
	public function processForm(sfActions $action)
	{
		$user = $action->getUser();

		//On recupere l'objet Evenement
		$reportage = $this->getObject();

		//Si l'archive n'est pas presente, on desactive le widget associe
		//pour eviter une erreur SF
		$archive = $this->getValue('archive');
		if(empty($archive))
		{
			unset($this['archive']);
		}

		//Si l'objet est nouveau, on passe l'activation sur index à 0
		if($reportage->isNew())
		{
			$reportage->setActiveIndex(0);
			$reportage->setPathDossier('');
		}
		
		//Si la cache "lier_agenda" a été cochée, on lie l'evenement à l'agenda
		$lier_agenda = $this->getValue('lier_agenda');
		if(!empty($lier_agenda) && $lier_agenda == '1')
		{
			//On recupere dans les évenements celui qui est la meme date
			//et au meme lieu
			$date = $this->getValue('date');
			$evenement = Doctrine::getTable('Evenement')->createQuery('e')
			->where('e.date_debut <= ? AND ? <= e.date_fin', array($date, $date))
			->addWhere('e.lieu_id = ?', $this->getValue('lieu_id'))
			->fetchOne();
			
			if(is_object($evenement))
			{
				if($evenement->getActive())
				{
					//L'evenement a été trouvé et est atif, on le lie
					$reportage->setEvenementId($evenement->getId());
				}
				else
				{
					//L'evenement a été trouvé mais n'est pas actif
					$user->setFlash('bo_reportages_form_error', 'Le reportage n\'a pas pu être lié à l\'agenda car l\'événement associé n\'est pas actif');
				}
			}
			else
			{
				//L'evenement n'a pas été trouve
				$user->setFlash('bo_reportages_form_error', 'Le reportage n\'a pas pu être lié à l\'agenda car aucun événement n\'a été trouvé.');
			}
		}
		else
		{
			$reportage->setEvenementId(null);
		}

		

		//On sauvegarde les données
		$reportage = $this->save();

		//Si archive présente, on la traite
		if(!empty($archive))
		{			
			$reportage = $this->processArchive($archive, $reportage, $user);
			
			//Mise à jour du repertoire du reportage
			$dossier = sfConfig::get('app_dossiers_images_reportages');
			$reportage->setPathDossier($dossier.'/'.$reportage->getId());
			$reportage->save();			
		}

		//On affiche le message de confirmation
		
		$user->setFlash('bo_reportages_form_ok', 'Reportage sauvegardé');

		return $reportage;
	}






	public function setSelectTypeId($type_id)
	{
		$this->type_id = $type_id;
		//On regenere les widgets pour qu'ils prennent cette nouvelle valeur
		$this->configure();
	}
	
	
	
	/**
	 * Fonction privee qui traite l'archive envoyee
	 * @param File $archive
	 * @param Reportage $reportage
	 * @param sfUser $user
	 * @return Reportage $reportage
	 */
	private function processArchive($archive, $reportage, $user)
	{
		$nombre_photos_ajoutees = 0;
		$nombre_videos_ajoutees = 0;
		
		//On cherche le nom que va avoir notre premier fichier importé
		$id_photo = 1;
		$id_video = 1;
		
		if(!$reportage->isNew())
		{
			//On cherche pour la photo
			$search = Doctrine::getTable('ReportageMedia')->createQuery('m')
			->select("substr(nom_fichier, locate('_', m.nom_fichier) + 1, locate('.', m.nom_fichier) - locate('_', m.nom_fichier) - 1) as nombre")
			->where('m.reportage_id = ?', $reportage->getId())
			->addWhere('m.is_video = 0')
			->fetchArray();
				
			if(count($search) > 0)
			{
				$id_photo = max($search);
				$id_photo = $id_photo['nombre'] + 1;
			}
				
			//On cherche pour la video
			$search = Doctrine::getTable('ReportageMedia')->createQuery('m')
			->select("substr(nom_fichier, locate('_', m.nom_fichier) + 1, locate('.', m.nom_fichier) - locate('_', m.nom_fichier) - 1) as nombre")
			->where('m.reportage_id = ?', $reportage->getId())
			->addWhere('m.is_video = 1')
			->fetchArray();
				
			if(count($search) > 0)
			{
				$id_video = max($search);
				$id_video = $id_video['nombre'] + 1;
			}
		}
		
		//Si le dossier du reportage n'existe pas, on le cree
		$dossier_reportage = sfConfig::get('app_uploads_images_reportages').'/'.$reportage->getId();
		if(!is_dir($dossier_reportage))
		{
			mkdir($dossier_reportage, 0775, true);
		}	
			
		//On genere un nom temporaire
		$name_temp = MembreTable::getMembreIdConnecte().rand(0, 1000);
			
		//On creer dans le repertoire temporaire, un sous repertoire (appele sous-repertoire temporaire)
		//portant le nom temporaire
		$dossier_temporaire = sfConfig::get('app_uploads_dossier_temporaire');
		$sous_dossier_temporaire = $dossier_temporaire.'/'.$name_temp;
		mkdir($sous_dossier_temporaire, 0775, true);
			
		//On met dans le repertoire temporaire le fichier .zip, portant le nom temporaire
		$extension = $archive->getExtension($archive->getOriginalExtension());
		$name_archive = $name_temp.$extension;
		$archive->save($dossier_temporaire.'/'.$name_archive);
		
		//On dezippe l'archive dans le sous repertoire temporaire
		$zip = new ZipArchive();
		if($zip->open($dossier_temporaire.'/'.$name_archive))
		{
			$zip->extractTo($sous_dossier_temporaire.'/');
			$zip->close();
		}
			
		//On recupere les fichiers un par un
		if(is_dir($sous_dossier_temporaire))
		{ 
			foreach(scandir($sous_dossier_temporaire) as $file)
			{
				if($file != "." && $file != "..")
				{
					$extension = stristr($file, '.');
					$file = $sous_dossier_temporaire.'/'.$file;
					
					//Si fichier correct (jpeg ou flv), on le déplace au bon endroit
					//en le renommant, et on l'ajoute en base de données
					if($extension == '.jpeg' || $extension == '.jpg' || $extension == '.JPEG' || $extension == '.JPG')
					{
						//C'est une image
						$new_file = $dossier_reportage.'/photo_'.$id_photo.'.jpg';
						copy($file, $new_file);
						$media = new ReportageMedia();
						$media->setReportageId($reportage->getId());
						$media->setIsVideo(0);
						$media->setNomFichier('photo_'.$id_photo.'.jpg');
						$media->save();
					
						$id_photo = $id_photo + 1;
						$nombre_photos_ajoutees = $nombre_photos_ajoutees + 1;
					}
					elseif($extension == '.flv' || $extension == '.FLV')
					{
						//C'est une video
						$new_file = $dossier_reportage.'/video_'.$id_video.'.flv';
						copy($file, $new_file);
						$media = new ReportageMedia();
						$media->setReportageId($reportage->getId());
						$media->setIsVideo(1);
						$media->setNomFichier('video_'.$id_video.'.flv');
						$media->save();
						
						$id_video = $id_video + 1;
						$nombre_videos_ajoutees = $nombre_videos_ajoutees + 1;
					}
				}
			}
		}
			
			//On supprime l'archive
			unlink($dossier_temporaire.'/'.$name_archive);
			
			//On supprime le sous repertoire temporaire
			Util::deleteFolder($sous_dossier_temporaire);
			
			//On affiche le nombre de medias ajoutés
			$user->setFlash('bo_reportages_upload_ok', $nombre_photos_ajoutees.' photos et '.$nombre_videos_ajoutees.' vidéos ajouté(es)');
		
		return $reportage;
	}
}