<?php

/**
 * SondageReponseMembre form.
 *
 * @package    form
 * @subpackage SondageReponseMembre
 * @version    SVN: $Id: SondageReponseMembreForm.class.php 309 2009-10-15 11:28:07Z hlecorche $
 */
class SondageReponseMembreForm extends BaseSondageReponseMembreForm
{
	public function configure()
	{
		unset($this['id']);
		
		//Champ "sondage_id"
		$this->setWidget('sondage_id', new sfWidgetFormInputHidden());
				
		//Le validateur n'accepte pas les sondages non actifs et different de celui donne dans l'urls
		$sondage_id = $this->getOption('sondage_id');
		$query = Doctrine::getTable('Sondage')->createQuery('a')
		->where('a.active = 1')
		->addWhere('a.id = ?', $sondage_id);
		$this->setValidator('sondage_id', new sfValidatorDoctrineChoice(array('model' => 'Sondage',
																			  'query' => $query)));
		$this->setDefault('sondage_id', $sondage_id);
		
		
		
		//Champ "sondage_reponse_id" 
		$reponses  = Doctrine::getTable('SondageReponse')->createQuery('r')
		->where('r.sondage_id = ?', $sondage_id)
		->orderBy('r.id ASC')
		->execute();
		$liste_reponses = array();
		foreach($reponses as $reponse)
		{
			$liste_reponses[$reponse->getId()] = $reponse->getTexte();
		}
		$this->setWidget('sondage_reponse_id', new sfWidgetFormSelectRadio(array('choices' => $liste_reponses,
																		   'formatter' => array($this, 'formatterRadioBox' ))));
		
		//Le validateur n'accepe pas les réponses non associees au bon sondage
		$this->setValidator('sondage_reponse_id', new sfValidatorChoice(array('choices' => array_keys($liste_reponses),
																			  'multiple' => false)));
		
		
		
		
		//Champ "ip"
		$this->setWidget('ip', new sfWidgetFormInputHidden());
		
		//Adresse IP du client
		$ip_client = sfContext::getInstance()->getRequest()->getHttpHeader ('addr','remote');
		
		//Le validateur accepte uniquement l'adresse ip du client, et uniquement une adresse ip unique 
		//par sondage
		//Note: Pour l'unicité de l'adresse IP, celle-ci est controllee dans le validateur global
		$this->setValidator('ip', new sfValidatorChoice(array('choices' => array($ip_client))));
		$this->setDefault('ip', $ip_client);
		
		
		
		//Validateur global
		//appelé apres tous les valideteurs individuels
		$this->validatorSchema->setPreValidator(
		new sfValidatorCallback(array('callback' => array($this, 'validateurGeneral'))));
		
		//Format du nom de formulaire
		$this->widgetSchema->setNameFormat('sondage_'.$sondage_id.'[%s]');

	}
	
	
	
	
	
	//Fonction appelée par le validateur général
	public function validateurGeneral($validator, $values)
	{
		//On recupere la valeur ip et la valeur sondage_id
		$ip = $values['ip'];
		$sondage_id = $values['sondage_id'];
		
		//On regarde si l'adresse ip a déjà repondu à sondage.
		//Dans ce cas, on ne valide pas le formulaire
		$nombre_reponses = Doctrine::getTable('SondageReponseMembre')->createQuery('m')
		->where('m.sondage_id = ?', $sondage_id)
		->addWhere('m.ip = ?', $ip)
		->count();
		
		if($nombre_reponses > 0)
		{
			throw new sfValidatorError($validator, 'Deja vote');
		}
	
		return $values;
	}
	
	
	
	
	//Fonction qui formate les checkbox du formulaire
	public function formatterRadioBox($widget, $inputs)
 	{
	    $html = '';
	    foreach ($inputs as $input)
	    {
	    	$html .=  $input['input'].' '.$input['label'].'<br />';
	    }
	    return $html;
 	}
}