<?php

/**
 * Video form.
 *
 * @package    anbnws
 * @subpackage form
 * @author     Hubert LECORCHE
 * @version    SVN: $Id: VideoForm.class.php 432 2010-09-27 14:50:10Z hlecorche $
 */
class VideoForm extends BaseVideoForm
{
	const pattern = '/("(?P<url_youtube>http:\/\/www\.youtube\.com\/v\/[a-zA-Z0-9_-]+))/';
	
	public function configure()
	{
		//Classe
		$class = 'fields';
		
		$this->useFields(array('titre', 'video_categorie_id', 'active'));
		
		//Champ "titre"
		$this->setWidget('titre', new sfWidgetFormInputText(array(), array('class' => $class,
																	 'size' => 50)));
		$this->setValidator('titre', new sfValidatorString(array('required' => true,
  																'trim' => true,
  																'min_length' => 3,
  																'max_length' => 255),
															array('required' => 'Champ obligatoire',
  														  		'min_length'=> '%min_length% caractères mini',
  														  		'max_length'=> '%max_length% caractères maxi')));
		//Champ "video_categorie_id"
		$this->setWidget('video_categorie_id', new sfWidgetFormDoctrineChoice(array('model' => 'VideoCategorie',
																						   'add_empty' => true),
																				     array()));
		$this->setValidator('video_categorie_id', new sfValidatorDoctrineChoice(array('model' => 'VideoCategorie',
																							 'required' => true),
																					   array('invalid' => 'Champ invalide',
																					   		 'required' => 'Champ obligatoire')));
																					   
		//Champ "video"
		if($this->isNew())
		{
			$this->setWidget('video', new sfWidgetFormTextarea(array(), array('class' => $class,
																			  'rows' => 4,
																			  'cols' => 30)));
	
			$this->setValidator('video', new sfValidatorRegex(array('required' => true,
	  																'trim' => true,
	  																'min_length' => 3,
	  																'max_length' => 5000,
																	'pattern' => self::pattern),
																array('required' => 'Champ obligatoire',
	  														  		'min_length'=> '%min_length% caractères mini',
	  														  		'max_length'=> '%max_length% caractères maxi',
																	'invalid' => 'Source invalide. Uniquement vidéos YouTube autorisées.')));
		}
															
															
		//Champ "active"
		$choices = array(0 => 'Non', 1 => 'Oui');
		$this->setWidget('active', new sfWidgetFormSelect(array('choices' => $choices)));
		$this->setValidator('active', new sfValidatorChoice(array('choices' => array_keys($choices),
																  'required' => true),
															array('invalid' => 'Champ invalide',
															   	 	 'required' => 'Champ obligatoire')));
	}
	
	
	
	
	/**
	 * Fonction appelee quand formulaire valide
	 * @param albumsActions action
	 * @return
	 */
	public function processForm(videosActions $action)
	{
		$user = $action->getUser();
		
		if($this->isNew())
		{
			try
			{
				//On creer une transaction
				$conn = Doctrine::getTable('Video')->getConnection();
				$conn->beginTransaction();
				
				//On recupere l'objet Video
				$video = $this->getObject();
				
				//On configure l'url de la video
				$video->setUrl(self::generateUrl($this->getValue('video')));
	
				//On sauvegarde l'enregistrement de l'objet MembreAlbum
				$video = $this->save($conn);
				
				//On commit la transaction
				$conn->commit();
				
				$user->setFlash('bo_video_ok', 'Vidéo ajoutée avec succès.');
				return $video;
				
			}
			catch(Exception $e)
			{
				$conn->rollback();
				
				//Une erreur est survenue, on redirige vers le formulaire d'ajout
				//avec un message d'erreur
				$user->setFlash('bo_video_error', 'Une erreur est survenue pendant la sauvegarde de la vidéo.');
				return false;
			}
		}
		else
		{
			$video = $this->save();
			$user->setFlash('bo_video_ok', 'Vidéo éditée avec succès.');
			return $video;
		}
	}
	
	
	
	
	/**
 	 * Fonction qui retourne l'url d'une video, en fonction  du code source donne
 	 * par l'utilisateur
 	 * @param String $source Source donnee par l'utilisateur
 	 * @return String Url de la video
 	 */
 	public static function generateUrl($source)
 	{
 		if(preg_match(self::pattern, $source, $matches))
 		{
 			if(!empty($matches['url_youtube']))
 			{
 				return $matches['url_youtube'];
 			}
 			else
 			{
 				return '';
 			}
 		}
 		else
 		{
 			return '';
 		}
 	}
}
