<?php

/**

 * This file is part of "AnnecyByNight"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Helper sur les listes

 *

 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: ecomlisteHelper.php 87 2009-07-16 16:41:29Z hlecorche $

 */





/**

 * Helper qui affiche la pagination d'un pager

 * @param sfDoctrinePager $pager

 * @param String $image_first icone premiere page

 * @param String $image_last icone derniere page

 * @param String $image_previous icone page precedente

 * @param String $image_next icone page suivante

 * @param Int $max_pages nombre de pages maxi à afficher

 * @param String $url url pour acceder à la page (de type 'module/action?page=')

 * @param Array $options_ajax Si non null, lorsque l'on clique sur un numéro de page, un appel ajax est généré

 * avec ces options

 * @return String pagination

 */

function affiche_pagination($pager, $image_first, $image_last, $image_previous, $image_next, $max_pages_avant, $max_pages_apres, $url, $options_ajax = null)

{

	$navigation = '';

	if ($pager->haveToPaginate())

	{

		//Premiere et precedente page

		if ($pager->getPage() != 1)

		{

			$navigation .= ecomlistePrivateLink(image_tag($image_first, array('alt' => 'first', 'style' => 'vertical-align: top;')), $url.'1', array(), $options_ajax);

			$navigation .= ecomlistePrivateLink(image_tag($image_previous, array('alt' => 'previous', 'style' => 'vertical-align: top;')), $url.$pager->getPreviousPage(), array(), $options_ajax).' ';

		}

		 

		 

		// Pages une par une

		$links = array();

		

		//Pages avant la page courrante

		for($page = $pager->getPage() - $max_pages_avant; $page < $pager->getPage(); $page++)

		{

			if($page <= $pager->getLastPage() && $page >= $pager->getFirstPage())

			{

				//La page existe, on l'affiche

				$links[] = ecomlistePrivateLink($page, $url.$page, array('class' => 'pagination_no_actual'), $options_ajax);

			}

		}

		

		//Page courante

		$links[] = '<span class="pagination_actual">[ '.$pager->getPage().' ]</span>';

		

		//Pages apres la page courrante

		for($page = $pager->getPage() + 1; $page <= $pager->getPage() + $max_pages_apres; $page++)

		{

			if($page <= $pager->getLastPage() && $page >= $pager->getFirstPage())

			{

				//La page existe, on l'affiche

				$links[] = ecomlistePrivateLink($page, $url.$page, array('class' => 'pagination_no_actual'), $options_ajax);

			}

		}

		

		

		$navigation .= join('&nbsp;&nbsp;', $links);

		

		

		

		

		// Precedente et derniere page

	    if ($pager->getPage() != $pager->getLastPage())

	    {

	      $navigation .= '&nbsp;&nbsp;'.ecomlistePrivateLink(image_tag($image_next, array('alt' => 'next', 'style' => 'vertical-align: top;')), $url.$pager->getNextPage(), array(), $options_ajax);

	      $navigation .= ecomlistePrivateLink(image_tag($image_last, array('alt' => 'last', 'style' => 'vertical-align: top;')), $url.$pager->getLastPage(), array(), $options_ajax);

	    }

		

		 

			

	}

	return $navigation;

}











/**

 * Fonction privee du helper qui permet de creer les liens de la pagination.

 * @param Sting $name parametre $name du link_to($name, $url, $options)

 * @param String $url parametre $url du link_to($name, $url, $options)

 * @param Array $options_link_to parametre $options du link_to($name, $url, $options)

 * @param Array $options_ajax Si non null, une requette ajax sera executee lorsque l'on cliquera

 * sur le lien. Ce tableau correspond à la variable $options de la fonction jq_remote_function($options).

 * Attention exclure du tableau le parametre 'url' (le variable @param $url de cette fonction sera utilisee)

 * @return String

 */

function ecomlistePrivateLink($name, $url, $options_link_to = array(), $options_ajax = null)

{

	if(is_null($options_ajax))

	{

		//On ne desire pas faire une requete AJAX, on fait un simple link_to

		return link_to($name, $url, $options_link_to);

	}

	else

	{

		//On desire faire une requete AJAX

		

		//On remplie les options du liens

		$str_options_link = '';

		foreach($options_link_to as $attribue => $value)

		{

			$str_options_link .= ' '.$attribue.' = "'.$value.'"';

		}

		

		//On creer le code Javascript

		require_once(dirname(__FILE__).'/../../plugins/sfJqueryReloadedPlugin/lib/helper/jQueryHelper.php');

		$options_ajax['url'] = $url; 

		$javascript = jq_remote_function($options_ajax);

		

		return '<a href="#" onclick="'.$javascript.'"'.$str_options_link.'>'.$name.'</a>';

	}

}











/**

 * *************************************************

 * 

 * Fonctions qui permettent d'afficher une liste d'éléments, 

 * sous forme d'un tableau (plusieurs elements

 * par lignes)

 * 

 * *************************************************

 */





/**

 * Fonction qui initialise le tableau, pour l'affichage

 * des éléments

 * @param Int $chariot

 * @param Array $html_options

 * @return unknown_type

 */

function ec_init_list(&$chariot, $html_options = array())

{

	$chariot = 0;

	return "\n".tag('table', $html_options, true)."\n";

}





/**

 * Fonction qui ouvre un TD (et un TR si necessaire) pour afficher un element

 * @param Int $chariot

 * @param Int $nombre_elements Nombre d'élements à afficher sur une ligne

 * @param Array $td_options_html

 * @param Array $tr_options_html

 * @return unknown_type

 */

function ec_list_open_element(&$chariot, $nombre_elements, $td_options_html = array(), $tr_options_html = array())

{

	$str = '';

	

	//On regarde si il faut ouvrir un nouveau TR

	if(($chariot % $nombre_elements == 0))

	{

		$str .= " ".tag('tr', $tr_options_html, true)."\n";

	}

	

	$str .="    ".tag('td', $td_options_html, true)."\n";

	

	$chariot = $chariot + 1;

	

	return $str;

}





/**

 * Fonction qui ferme un TD (et un TR si necessaire) pour afficher un element

 * @param Int $chariot

 * @param Int $nombre_elements Nombre d'élements à afficher sur une ligne

 * @return unknown_type

 */

function ec_list_close_element(&$chariot, $nombre_elements)

{

	$str = '';

	

	$str .="\n    </td>\n";

	

	//On regarde si il faut fermer le TR courrant

	if($chariot % $nombre_elements == 0)

	{

		$str .= " </tr>\n";

	}

	

	return $str;

}



/**

 * Fonction qui ferme le tableau, pour l'affichage

 * des éléments

 * @param Int $chariot

 * @param Int $nombre_elements Nombre d'élements à afficher sur une ligne

 * @return unknown_type

 */

function ec_list_close(&$chariot, $nombre_elements)

{

	$ret  = '';

	

	//On regarde combien de TD il manque pour fermer la ligne

	$difference  = $nombre_elements - ($chariot % $nombre_elements);

	if($difference == $nombre_elements)

	{

		$difference = 0;

	}

	

	//On ajoute le TD manquants

	for($i=1; $i <= $difference; $i++)

	{

		$ret .= "    <td></td>\n";

	}

	

	//Si on a ajouté des TD, on ferme ensuite la ligne

	if($difference > 0)

	{

		$ret .= " </tr>\n";

	}

	

	//On ferme le tableau

	$ret .= "</table>";

	

	return $ret;

}



?>