<?php
/**
 * This file is part of "Annecy By Night"
 * Copyright (c) 2009 Hubert LECORCHE
 * 
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */


/**
 * Classe permettant de creer un calendrier graphique.
 * Un calendrier est un componant
 * 
 * Infos sur la variable passee en constructeur:
 * Variable de session ou seront stockee les informations sur le calendrier. Cette variable 
 * stoquee en session est un tableau contenant deux variables: $month et $year (mois et annee à afficher).
 * Attention ces variables peuvent etre corrompues (l'utilisateur peut mettre n'importe quoi)
 *
 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>
 * @version    SVN: $Id: ecCalendar.class.php 376 2010-08-25 09:37:20Z hlecorche $ 
 */

class ecCalendar
{
	
	/*
	 * Début variables de configuration
	 */
	
	//Action apellee lorsque l'on change de date (sous la forme 'module/action').
	//Cette action doit recuperer les variables 'month' et 'year' dans le request
	//et les stoquer en session (voir variable $name_session), puis doit rediriger
	//vers la page définie dans la variable $redirect_change_month_action
	protected static $change_month_action = '@agenda_calendar'; 
		
	//Action (sous la forme 'module/action") dont laquelle l'utilisateur est redigige quand l'utilisateur
	//clique sur une journee du calendrier (le lien genera aura la forme: $evenement_link.'?date=LaDate'=
	protected static $evenement_link = '@liste_evenements_with_date';
	
	//Nom de la table dans laquelle il faut aller chercher les resultats
	protected static $table_name = 'Evenement';
	
	//Nom de la colonne ou est stockee la date de l'evenement
	protected static $column_name_date_debut = 'date_debut';
	protected static $column_name_date_fin = 'date_fin';
	
	//Nom de la colonne ou est stockee la valeur qui permet de savoir si l'evenement est actif
	protected static $column_name_active = 'active';
	
	
	/**
	 * Fin des variables de configuration
	 */
	
	
	//Donnees membres
	protected $month; //Mois a afficher sur le calendrier
	protected $year; //Mois a afficher sur le calendrier
	protected $results; //Evenements associes au mois
	protected $now_month; //Mois d'aujourd'hui
	protected $now_day; //Jour d'aujoud'hui
	protected $now_year; //Annee d'aujourd'hui
	
	//Donnees statiques
	protected static $labels_mois = array('', 'JANVIER', 'FEVRIER', 'MARS', 'AVRIL', 'MAI', 'JUIN',
			'JUILLET', 'AOUT', 'SEPTEMBRE', 'OCTOBRE', 'NOVEMBRE', 'DECEMBRE');
	protected static $labels_jours = array('Lu.', 'Ma.', 'Me.', 'Je.', 'Ve.', 'Sa.', 'Di.');
	
	
	
	
	/**
	 * Constructeur de la classe
	 * @param Array $session_calendar Tableau contenant la session du tableau (Voir haut de page)
	 * @return unknown_type
	 */
	public function __construct($session_calendar)
	{
		//On définit les parametres d'aujourd'hui
		$this->now_day = date('d');
		$this->now_month = date('m');
		$this->now_year = date('Y');
		
		//On definit le mois et l'annee a afficher
		$year = $this->now_year;
		$month = $this->now_month;
		
		?><!-- <?php print_r($_SESSION); ?>--><?php
        
		
		if(isset($session_calendar['year']))
		{
			$year = intval($session_calendar['year']);
		}
		if(isset($session_calendar['month']))
		{
			$month = intval($session_calendar['month']);
		}
		
		//On definit les parametres du calendrier a afficher
		if(is_int($month) && $month > 0 && $month < 13)
		{
			$this->month = $month;
		}
		else
		{
			$this->month = $this->now_month;
		}
		if(is_int($year) && $year > 1980 && $year < 2030)
		{
			$this->year = $year;
		}
		else
		{
			$this->year = $this->now_year;
		}
		
		//On va chercher les resultats en base de donnees
		$this->getResults();
		//Et on les arrange
		$this->rangeResults();
		
	}
	
	
	
	
	/**
	 * Va chercher dans la base de données les resultats du mois en cours
	 * et enregistre les resultats dans un tableau, dans la variables locales
	 * $results
	 * @return unknown_type
	 */
	private function getResults()
	{
		//Creation des delemiteurs de date pour la requette
		$premier_jour = $this->year.'-'.$this->month.'-01';
		$nombre_jours = self::number_of_days($this->month, $this->year);
		$dernier_jour = $this->year.'-'.$this->month.'-'.$nombre_jours;
		
		//Creation des parametres de la requete
		$column_date_debut = 't.'.self::$column_name_date_debut;
		$column_date_fin = 't.'.self::$column_name_date_fin;
		$column_active = 't.'.self::$column_name_active;
		
		//Creation de la requete
		$query = Doctrine::getTable(self::$table_name)->createQuery('t')
			->select($column_date_debut)
			->addSelect($column_date_fin)
			->where($column_active.' = 1 AND ? <= '.$column_date_debut.' AND '.$column_date_debut.' <= ?', array($premier_jour, $dernier_jour))
			->orWhere($column_active.' = 1 AND ? <= '.$column_date_fin.' AND '.$column_date_fin.' <= ?', array($premier_jour, $dernier_jour))
			->orWhere($column_active.' = 1 AND ? > '.$column_date_debut.' AND '.$column_date_fin.' > ?', array($premier_jour, $dernier_jour))
			->orderBy($column_date_debut.' ASC');
		
		//On execute la requette, que l'on stocke dans l'objet
		$this->results = $query->fetchArray();
	}
	
	
	/**
	 * La fonction getResults renvoie les resultats de la BDD sous la forme 
	 * array(0 => array('date_debut' = '2009-01-01', 'date_fin' = '2009-01-01'), ...). Cette fonction change la variable $this->results
	 * pour la transformer en array('01' => 1, ....)
	 * @return unknown_type
	 */
	private function rangeResults()
	{
		$timestamp_premier_jour_mois = mktime(0, 0, 0, $this->month, 1, $this->year);
		$timestamp_dernier_jour_mois = $timestamp_premier_jour_mois + (self::number_of_days($this->month, $this->year) * 86400);
		
		$tmp = array();
		foreach($this->results as $row)
		{
			$evenement_debut_timestamp = Util::dateToTime($row['date_debut']);
			$evenement_fin_timestamp = Util::dateToTime($row['date_fin']);
			
			//Si date de debut de l'evenement pendant ce mois
			if($timestamp_premier_jour_mois <= $evenement_debut_timestamp && $evenement_debut_timestamp <= $timestamp_dernier_jour_mois)
			{
				//De la date de debut jusqu'à la date de fin (sauf s'arreter à la fin du mois)
				for($i=$evenement_debut_timestamp ; $i <= $evenement_fin_timestamp ; $i = $i + 86400)
				{
					$date = date('d', $i);
					$date = intval($date);
					$tmp[$date] = 1;
					if($timestamp_dernier_jour_mois == $i)
					{
						break;
					}
				}
			}
				
			//Sinon si date de fin de l'evenement pendant ce mois
			elseif($timestamp_premier_jour_mois <= $evenement_fin_timestamp && $evenement_fin_timestamp <= $timestamp_dernier_jour_mois)
			{
				//Du 1er jour du mois jusqu'à la date de fin
				for($i=$timestamp_premier_jour_mois ; $i <= $evenement_fin_timestamp ; $i = $i + 86400)
				{
					$date = date('d', $i);
					$date = intval($date);
					$tmp[$date] = 1;
				}
			}
			
			//Sinon tous les jours du mois
			else
			{
				for($i=$timestamp_premier_jour_mois ; $i <= $timestamp_dernier_jour_mois ; $i = $i + 86400)
				{
					$date = date('d', $i);
					$date = intval($date);
					$tmp[$date] = 1;
				}
				break;
			}
		}
		$this->results = $tmp;
	}
	
	
	
	
	/**
	 * Methode qui affiche le calendrier
	 * @return unknown_type
	 */
	public function render()
	{
		$html = '';
		$html .= '<div class="calendar"><table border="0" cellpadding="2" class="moiscourant">';
		
		$mois_moins_1 = date("m") - 1;
		$mois_plus_1 = date("m") + 1;
		$an_moins_1 = date("Y") - 1;
		$an_plus_1 = date("Y") + 1;
		$mois_avant = date('m', mktime(0, 0, 0, $mois_moins_1, 1, $this->year));
		$mois_apres = date('m', mktime(0, 0, 0, $mois_plus_1, 1, $this->year));
		$annee_avant = date('Y', mktime(0, 0, 0, $this->month, 1, $an_moins_1));
		$annee_apres = date('Y', mktime(0, 0, 0, $this->month, 1, $an_plus_1));
		
		//Entete du calendrier
		$html .= '<tr><td colspan="7" class="moiscourant">'.self::$labels_mois[intval($this->month)].' '.$this->year.'</td></tr>';
		
		$html .= '<tr>';
		$html .= '<td class="fleche"><a href="'.url_for(self::$change_month_action.'?year='.$annee_avant.'&month='.$this->month).'">'.image_tag('icones/15/arrow_precedent.gif', array('alt' => 'P', 'border' => '0')).'</a></td>';
		$html .= '<td class="fleche"><a href="'.url_for(self::$change_month_action.'?year='.$this->year.'&month='.$mois_avant).'">'.image_tag('icones/15/arrow_precedent.gif', array('alt' => 'P', 'border' => '0')).'</a></td>';
		
		$html .= '<td colspan="3" align="center" class="text"><a href="'.url_for(self::$change_month_action.'?year='.$this->now_year.'&month='.$this->now_month).'" class="lien" style="color:#00FF68" title="Aujourd\'hui">Aujourd\'hui</a></td>';
		
		$html .= '<td class="fleche"><a href="'.url_for(self::$change_month_action.'?year='.$this->year.'&month='.$mois_apres).'">'.image_tag('icones/15/arrow_suivant.gif', array('alt' => 'S', 'border' => '0')).'</a></td>';
		$html .= '<td class="fleche"><a href="'.url_for(self::$change_month_action.'?year='.$annee_apres.'&month='.$this->month).'">'.image_tag('icones/15/arrow_suivant.gif', array('alt' => 'S', 'border' => '0')).'</a></td>';
		
		$html .= '</tr>';
		
		//Affichage des entêtes des jours (lundi => dimanche)
		$html .= '<tr>';
		foreach(self::$labels_jours as $jour)
		{
			$html .= '<td align="center">'.$jour.'</td>';
		}
		$html .= '</tr>';
		
		//Ouverture de la premiere ligne
		$html .='<tr>';
		
		//On laisse les espaces vides du calendrier, pour les jours ne faisant pas parti du mois
		for($i=0; $i < $this->first_day($this->month, $this->year); $i++)
		{
			//Colonne vide
			$html .= '<td></td>';
		}
		
		//On affiche tous les jours du mois
		for($i = 1; $i <= self::number_of_days($this->month, $this->year); $i++)
		{
			$html .= $this->renderOneDay($i);
		}
		
					
		//Fermeture de la derniere ligne
		$html .= '</tr>';
		
		//Fermeture du tableau
		$html .= '</table></div>';
		
		return $html;
		
	}
	
	
	
	/**
	 * Render du calendrier pour une seule journée
	 * @param Int $int_day Numero du jour dans le mois a afficher
	 * @return unknown_type
	 */
	private function renderOneDay($int_day)
	{
		$html = '';
		
			
		//Cas ou il s'agit d'un LUNDI, il y a donc un retour à la ligne avant cette journée
		//(sauf si le 1er jour est un lundi)
		if ($int_day != 1 && ($int_day-1 + self::first_day($this->month, $this->year)) % 7 == 0)
		{
			$html .= '</tr><tr>';
		}
		
		//Cas n°1: La journee est le jour d'aujourd'hui
		if($this->isToday($int_day))
		{
			if(array_key_exists($int_day, $this->results))
			{
				//Cas n°1A : La journee est le jour d'aujourd'hui et
				//evenement programme
				$lien = link_to($int_day, self::$evenement_link.'?jour='.$int_day.'&mois='.$this->month.'&annee='.$this->year, array('class' => 'lien', 'title' => 'date événement'));
				$html .= '<td align="center" class="date_event"><div class="date_aujourdhui">'.$lien.'</div></td>';
			}
			else
			{
				//Cas n°1B: Aujourd'hui mais Il n'y a rien de prévu
			    $html .= '<td align="center" class="datejour"><div class="date_aujourdhui">'.$int_day.'</div></td>';
			}
		}
		else
		{
			//Cas n°2: La journee n'est pas aujourd'hui
			
			if(array_key_exists($int_day, $this->results))
			{
				//Cas n°2A : Pas aujourd'hui mais evenement prevu
				$lien = link_to($int_day, self::$evenement_link.'?jour='.$int_day.'&mois='.$this->month.'&annee='.$this->year, array('class' => 'lien', 'title' => 'date événement'));
				$html .= '<td align="center" class="date_event"><div>'.$lien.'</div></td>';
			}
			else
			{
				//Cas n°2B: Pas aujourd'hui et pas d'evenement de prevu
				$html .= '<td align="center" class="date">'.$int_day.'</td>';
			}
		}
		
		
		return $html;
	}
	
	
	
	
	
	
	/**
	 * Retourne le numero du jour (dans la semaine) du 1er jour 
	 * du mois donne
	 * @param Int $month Mois
	 * @param Int $year Annee
	 * @return Int Jour de la semaine (0: Lundi => 6: Dimanche)
	 */
	protected static function first_day($month, $year)
	{
		$premier_jour = date("w",mktime(0,0,0,$month,1,$year));
		if($premier_jour == 0) $premier_jour = 7; // si c'est un dimanche

 		return $premier_jour - 1;
	}
	
	
	
	
	/**
	 * Retourne le nombre de jours d'un mois donne
	 * @param Int $month Mois (1-12)
	 * @param Int $year Annee
	 * @return Int Nombre de jours du mois
	 */
	protected static function number_of_days($month, $year)
	{
		//Combien de jours a le mois de fevrier ?
		$fevrier = 28;
		if( (is_int($year/4) && !is_int($year/100)) || is_int($year/400))
		{
			//L'annee est bissextile
			$fevrier = 29;
		}
		
		$nombre_jours = array(0,31,$fevrier,31,30,31,30,31,31,30,31,30,31);
		
		return $nombre_jours[intval($month)];		
	}
	
	
	
	/**
	 * Verifie si la journee donnee est aujourdhui
	 * @param Int $int_day Numero du jour dans le mois a comparer
	 * @return Boolean
	 */
	private function isToday($int_day)
	{
		$ret = false;
		if($this->year == $this->now_year && $this->month == $this->now_month &&
		   $int_day == $this->now_day)
		{
			$ret = true;	
		}
		return $ret;
	}
	
	
	
	
	
}
?>