<?php

/**

 * This file is part of "AnnecyByNight"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Classe ecPager, qui permet de faire la pagination avec une requette

 * en bases de données, plus leger sur le sFDoctrinePager

 *

 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: ecPager.class.php 284 2009-09-24 11:40:41Z hlecorche $

 */



class ecPager extends sfPager

{

	protected $query = null;

	protected $totalResults = null;



	public function __construct($maxPerPage = 10)

	{

		$this->setMaxPerPage($maxPerPage);

		$this->parameterHolder = new sfParameterHolder();

	}











	public function init()

	{

		//Si le nombre de resultats n'est pas defini, on le calcule, sinon on le passe au pager

		if(is_null($this->totalResults))

		{

			$this->setNbResults($this->query->count());

		}

		else

		{

			$this->setNbResults($this->totalResults);

		}



		$this->query->offset(0);

    	$this->query->limit(0);

		if ($this->getPage() == 0 || $this->getMaxPerPage() == 0 || $this->getNbResults() == 0)

		{

			$this->setLastPage(0);

		}

		else

		{

			$offset = ($this->getPage() - 1) * $this->getMaxPerPage();

			$this->setLastPage(ceil($this->getNbResults() / $this->getMaxPerPage()));

				

			$this->query->offset($offset);

			$this->query->limit($this->getMaxPerPage());

		}

	}



	/**

	 * Get all the results for the pager instance

	 *

	 * @param integer $fetchtype Doctrine::HYDRATE_* constants

	 * @return Doctrine_Collection

	 */

	public function getResults($fetchtype = null)

	{

		$p = $this->getQuery();



		if ($fetchtype == 'array')

		{

			return $p->execute(array(), Doctrine::HYDRATE_ARRAY);

		}



		return $p->execute();

	}







	/**

	 * Retrieve the object for a certain offset

	 *

	 * @param integer $offset

	 * @return Doctrine_Record $record

	 */

	protected function retrieveObject($offset)

	{

		$cForRetrieve = clone $this->getQuery();

		$cForRetrieve->offset($offset - 1);

		$cForRetrieve->limit(1);



		$results = $cForRetrieve->execute();



		return $results[0];

	}





	/**

	 * Get the query for the pager

	 * @return Doctrine_Query $query

	 */

	public function getQuery()

	{

		return $this->query;

	}



	/**

	 * Set the query for the pager

	 * @param Doctrine_Query $query

	 */

	public function setQuery($query)

	{

		$this->query = $query;

	}



	public function getTotalResults()

	{

		return $this->totalResults;

	}



	public function setTotalResults($nbResults)

	{

		$this->totalResults = $nbResults;

	}

}



?>