<?php

/**

 * This file is part of "AnnecyByNight"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * classe qui permet de calculer le signe astrologique du zodiaque et le signe chinois en fonction de la date passé en parametre dans chaque fonction

 *

 * @author   Sylvain JEANDROZ <sjeandroz@e-commit.fr>

 * @version    SVN: $Id: ecSignePersonnalite.class.php 36 2009-07-08 07:34:42Z sjeandroz $

 */





Class ecSignePersonnalite {



	//tableau qui contient tous les jours des nouvels an chinois depuis 1900

	protected static $calendrier_lunaire_jour_nouvel_an= array ("31", "19", "08", "29" ,"16", "04", "25", "13" ,

			"02", "22", "10", "30", "18", "06", "26", "14", "03", "23", "11", "01", "20", "8" ,"28" ,

			"16" ,"05", "25", "13", "02", "23", "10", "30", "17", "06", "26", "14", "04", "24", "11", 

			"31", "19", "08", "27", "15", "05", "25", "13", "02", "22", "10", "29", "17", "06", "27",

			 "14", "03", "24", "12", "31", "18" ,"08", "28", "15", "05" ,"25" ,"13" ,"02", "21", "09",

			 "30", "17","06","27","15","03","23","11","31", "18", "07", "28", "16", "05", "25", "13", 

			 "02", "20", "09", "29", "17", "06", "27", "15", "04", "23", "10", "31", "19", "07", "28",

			 "16", "05", "24", "12", "01", "22", "09", "29", "18", "07", "26", "24", "3", "23", "10", 

			 "31", "19", "08", "28", "16", "05");

	

	//tableau qui contient tous les mois des nouvels ans chinois depuis 1900

	protected static $calendrier_lunaire_mois_nouvel_an= array ("01", "02", "02", "01", "02","02", "01", "02",

			"02", "01", "02", "01", "02", "02", "01", "02", "02", "01", "02", "02", "02", "02", "01",

			"02", "02", "01", "02", "02", "01", "02", "01", "02", "02", "01", "02", "02", "01", "02",

			"01", "02", "02", "01", "02", "02", "01", "01", "02" ,"01", "02","01","02","02","01","02",

			"02","01","02","01","02","02","01","02","02","01","02","02","01","02","01","02","02","01",

			"02","02", "01", "02", "01", "02", "02", "01", "02", "02", "01", "02", "02", "02", "02",

			"01", "02", "02", "01", "02", "02", "01", "02", "01", "02", "02", "01", "02", "02", "01",

			"02", "02", "01", "02", "01", "02", "02", "01", "02", "02", "01", "02", "01", "02", "02", 

			"01", "02", "02");

	

	//tableau qui contient les douzes signes chinois

	protected static $calendrier_lunaire_signe= array("rat","buffle","tigre","lapin","dragon","serpent","cheval",

		"chevre","singe","coq","chien","cochon");





	/**

	 * Retourne le signe du zodiaque en fonction du jour et du mois

	 * @param String $jour le jour de la date dont on veut connaitre le signe

	 * @param String $mois le mois de la date dont on veut connaitre le signe

	 * @return String retourne le signe astrologique qui correspond a la date passé en parametre

	 */

	public static function getSigneAstrologique($jour,$mois){



		//Les signes du zodiaque dans l'ordre

		$signes_zodiaque = array('Verseau','Poisson','Bélier','Taureau','Gémau','Cancer',

		'Lion','Vierge','Balance','Scorpion','Sagitaire','Capricorne');







		//Limite de fin periode pour chaque signe

		$periodes_zodiaque = array(21,20,21,21,22,22,24,24,24,23,23,22);







		//on prend la valeur du mois passé en parametre

		$periode = $periodes_zodiaque[($mois-1)];

	

		//si le jour passé en parametre est inferieur a la date de fin de periode qui correspond

		if($jour < $periode)

		{

			//si le mois est egale a 1, on le change en 13 (pour eviter d'avoir un mois a 0)

			if($mois == 1) $mois=13;

			//alors on recupere le bon signe dans le tableau qui contient les signes

			$signe = $signes_zodiaque[($mois-2)];

		}else{

			$signe = $signes_zodiaque[$mois-1];

		}

		//on retourne le signe qui correspond a la date

		return $signe;

	}

/**

 * retourne le signe chinois en fonction du jour, du mois et de l'année

 * @param String $jour le jour de la date dont on veut connaitre le signe

 * @param String $mois le mois de la date dont on veut connaitre le signe

 * @param Int $annee l'année de la date dont on veut connaitre le signe

 * @return String retourne le signe chinois qui correspond a la date

 */

	public static function getSigneChinois($jour,$mois,$annee){



	//initialisation du tableau des années du calendrier lunaire

		for($i=0;$i<=119;$i++)

		{

			$calendrier_lunaire_annee[$i]=1900+$i;

		}



		//on cherche l'index des tableaux correspondant a l'année

		$ligne=array_search($annee,$calendrier_lunaire_annee);

		//si le mois passé en parametre est inferieur au mois du nouvel an

		if($mois <= self::$calendrier_lunaire_mois_nouvel_an[$ligne])

		{

			//et si le jour passé en parametre est inferieur au jour du nouvel an

			if($jour< self::$calendrier_lunaire_jour_nouvel_an[$ligne])

			{

				//on decremente l'index de l'année car nous sommes encore dans l'année d'avant

				$ligne--;

			}

				



		}



		//on recupere la partie entiere de la division de la ligne par 12

		$partie_entiere=floor($ligne / 12);

		

		//puis on recupere le signe correspondant

		$ligne_finale=$ligne-(12*$partie_entiere);

		

		//on retourne le signe correspondant a l'année

		if($ligne==null)

		{

			return "la date est hors calendrier lunaire";

		}else

		{

			return self::$calendrier_lunaire_signe[$ligne_finale];

		}





	}



}







?>





