<?php

/**

 * This file is part of "Annecy By Night"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Classes d'outils

 *

 * @author     Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: util.php 428 2010-09-27 11:37:31Z hlecorche $

 */



Class Util

{

	/**

	 * Fonction qui retourne l'url racine de l'application SF

	 * => Nécessite la configuration de l'option "url_racine" dans fichier de config

	 * @return string url de type 'http://www.monsite.fr'

	 */

	public static function getRacine()

	{

		return sfConfig::get('app_url_portail');

	}







	/**

	 * Fonction qui retourne l'url d'une image ou d'un CSS, ou d'un JS

	 * => Nécessite la configuration de l'option "url_racine" dans fichier de config

	 * @param $url String de type 'images/mon_image.jpg'

	 * @return String url de type 'http://www.monsite.fr/images/mon_image.jpg'

	 */

	public static function url_for($url)

	{

		$url_racine = self::getRacine();

		return $url_racine.'/'.$url;

	}





	/**

	 * Fonction qui retourne l'affichage d'un message d'info

	 * @param $message String: Le message à afficher

	 * @param $type_message: Type de message: 'ok' / 'error'

	 * @param $width: Longeur du message

	 * @return String

	 */

	public static function MessageInfo($message, $type_message, $width='100%')

	{

		if($type_message == 'ok')

		{

			$class = 'message_infos_ok';

		}

		else

		{

			$class = 'message_infos_error';

		}



		$str = '<div class="'.$class.'" style="width: '.$width.';">';

		$str = $str. '<div class="message_infos_message">';

		$str = $str.$message;

		$str = $str. '</div></div>';



		return $str;

	}







	/**

	 * Fonction qui retourne l'image d'erreur

	 * @return unknown_type

	 */

	public static function getImageErreur()

	{

		return '<img src="'.Util::getRacine().'/images/icones/24/error.png" alt="error" width="12px" height="12px" />&nbsp;&nbsp;';

	}







	/**

	 * Fonction qui supprime les accents d'une chaine

	 * @param $txt string chaine avec accents

	 * @return string chaine sans accents

	 */

	public static function enleveAccents($txt)

	{

		$txt = str_replace('œ', 'oe', $txt);

		$txt = str_replace('Œ', 'Oe', $txt);

		$txt = str_replace('æ', 'ae', $txt);

		$txt = str_replace('Æ', 'Ae', $txt);

		mb_regex_encoding('UTF-8');

		$txt = mb_ereg_replace('[ÀÁÂÃÄÅĀĂǍẠẢẤẦẨẪẬẮẰẲẴẶǺĄ]', 'A', $txt);

		$txt = mb_ereg_replace('[àáâãäåāăǎạảấầẩẫậắằẳẵặǻą]', 'a', $txt);

		$txt = mb_ereg_replace('[ÇĆĈĊČ]', 'C', $txt);

		$txt = mb_ereg_replace('[çćĉċč]', 'c', $txt);

		$txt = mb_ereg_replace('[ÐĎĐ]', 'D', $txt);

		$txt = mb_ereg_replace('[ďđ]', 'd', $txt);

		$txt = mb_ereg_replace('[ÈÉÊËĒĔĖĘĚẸẺẼẾỀỂỄỆ]', 'E', $txt);

		$txt = mb_ereg_replace('[èéêëēĕėęěẹẻẽếềểễệ]', 'e', $txt);

		$txt = mb_ereg_replace('[ĜĞĠĢ]', 'G', $txt);

		$txt = mb_ereg_replace('[ĝğġģ]', 'g', $txt);

		$txt = mb_ereg_replace('[ĤĦ]', 'H', $txt);

		$txt = mb_ereg_replace('[ĥħ]', 'h', $txt);

		$txt = mb_ereg_replace('[ÌÍÎÏĨĪĬĮİǏỈỊ]', 'I', $txt);

		$txt = mb_ereg_replace('[ìíîïĩīĭįıǐỉị]', 'i', $txt);

		$txt = str_replace('Ĵ', 'J', $txt);

		$txt = str_replace('ĵ', 'j', $txt);

		$txt = str_replace('Ķ', 'K', $txt);

		$txt = str_replace('ķ', 'k', $txt);

		$txt = mb_ereg_replace('[ĹĻĽĿŁ]', 'L', $txt);

		$txt = mb_ereg_replace('[ĺļľŀł]', 'l', $txt);

		$txt = mb_ereg_replace('[ÑŃŅŇ]', 'N', $txt);

		$txt = mb_ereg_replace('[ñńņňŉ]', 'n', $txt);

		$txt = mb_ereg_replace('[ÒÓÔÕÖØŌŎŐƠǑǾỌỎỐỒỔỖỘỚỜỞỠỢ]', 'O', $txt);

		$txt = mb_ereg_replace('[òóôõöøōŏőơǒǿọỏốồổỗộớờởỡợð]', 'o', $txt);

		$txt = mb_ereg_replace('[ŔŖŘ]', 'R', $txt);

		$txt = mb_ereg_replace('[ŕŗř]', 'r', $txt);

		$txt = mb_ereg_replace('[ŚŜŞŠ]', 'S', $txt);

		$txt = mb_ereg_replace('[śŝşš]', 's', $txt);

		$txt = mb_ereg_replace('[ŢŤŦ]', 'T', $txt);

		$txt = mb_ereg_replace('[ţťŧ]', 't', $txt);

		$txt = mb_ereg_replace('[ÙÚÛÜŨŪŬŮŰŲƯǓǕǗǙǛỤỦỨỪỬỮỰ]', 'U', $txt);

		$txt = mb_ereg_replace('[ùúûüũūŭůűųưǔǖǘǚǜụủứừửữự]', 'u', $txt);

		$txt = mb_ereg_replace('[ŴẀẂẄ]', 'W', $txt);

		$txt = mb_ereg_replace('[ŵẁẃẅ]', 'w', $txt);

		$txt = mb_ereg_replace('[ÝŶŸỲỸỶỴ]', 'Y', $txt);

		$txt = mb_ereg_replace('[ýÿŷỹỵỷỳ]', 'y', $txt);

		$txt = mb_ereg_replace('[ŹŻŽ]', 'Z', $txt);

		$txt = mb_ereg_replace('[źżž]', 'z', $txt);

		return $txt;

	}





	/**

	 * Fonction qui renvoie l'url d'une image en fonction du fichier img.php

	 * @param String $file Chemin du fichier à afficher

	 * @param Int $width: Largeur de l'image

	 * @param Int $height: Hauteur de l'image

	 * @param Int $opt: Si precisee, taille du cote du plus long (autre cote calcule automatiquement)

	 * @param Bool $truncate: Si TRUE, peut rogner l'image

	 * @return String: Url de l'image

	 * @see getUrlImageWithJpeg

	 */

	public static function getUrlImage($file, $width = null, $height = null, $opt = null, $truncate = false)

	{

		return self::getUrlImageWithJpeg($file, $width, $height, $opt, $truncate);

		

		/*$lien = '/img.php?';

		//Affichage de l'image en fonction du nom

		//Utilisation de rawurlencode() pour que les caractères particuliers (comme le +) soient

		//traduits et pas interpertrés comme un séparateur

		$name_file = rawurlencode(Chiffrement::cryptage($file));

		$lien .= 'pic='.$name_file;





		//Ajout de la taille auto, si précisée

		if(!is_null($opt))

		{

			$opt = rawurlencode(Chiffrement::cryptage($opt.''));

			$lien .= '&amp;opt='.$opt;

		}



		//Ajout de la largeur si précisée

		if(!is_null($width))

		{

			$width = rawurlencode(Chiffrement::cryptage($width.''));

			$lien .= '&amp;w='.$width;

		}

		

		//Ajout de la hauteur si précisée

		if(!is_null($height))

		{

			$height = rawurlencode(Chiffrement::cryptage($height.''));

			$lien .= '&amp;h='.$height;

		}

		

		//Ajout de l'atribut truncate, si precise

		if($truncate)

		{

			$truncate = rawurlencode(Chiffrement::cryptage($truncate.''));

			$lien .= '&amp;tr='.$truncate;

		}



		return $lien;

	*/

	}



	/**

	 * Fonction qui renvoie l'url d'une image en fonction du fichier image_anbn_ ... .jpg (img.php)

	 * @param String $file Chemin du fichier à afficher

	 * @param Int $width: Largeur de l'image

	 * @param Int $height: Hauteur de l'image

	 * @param Int $opt: Si precisee, taille du cote du plus long (autre cote calcule automatiquement)

	 * @param Bool $truncate: Si TRUE, peut rogner l'image

	 * @return String: Url de l'image

	 * @see getUrlImage

	 */

	public static function getUrlImageWithJpeg($file, $width = null, $height = null, $opt = null, $truncate = false)

	{

		

		//Affichage de l'image en fonction du nom

		//Utilisation de rawurlencode() pour que les caractères particuliers (comme le +) soient

		//traduits et pas interpertrés comme un séparateur

		$name_file = rawurlencode(Chiffrement::cryptage($file));

		$lien = $name_file;



		//Ajout de la taille auto, si précisée

		if(!is_null($opt))

		{

			$opt = rawurlencode(Chiffrement::cryptage($opt.''));

			$lien .= '&opt='.$opt;

		}



		//Ajout de la largeur si précisée

		if(!is_null($width))

		{

			$width = rawurlencode(Chiffrement::cryptage($width.''));

			$lien .= '&w='.$width;

		}

		

		//Ajout de la hauteur si précisée

		if(!is_null($height))

		{

			$height = rawurlencode(Chiffrement::cryptage($height.''));

			$lien .= '&h='.$height;

		}

		

		//Ajout de l'atribut truncate, si precise

		if($truncate)

		{

			$truncate = rawurlencode(Chiffrement::cryptage($truncate.''));

			$lien .= '&tr='.$truncate;

		}



		return '/image_anbn_'.rawurlencode($lien).'.jpg';

	}





	/**

	 * Fonction de conversion de date/heure du format américain (AAAA-MM-JJ HH:MM:SS) en Timestamp.

	 * @param string $datetime Date/heure au format américain (AAAA-MM-JJ HH:MM:SS)

	 * @return integer Timestamp en seconde

	 */

	public static function datetimeToTime($datetime)

	{

		list($date, $time) = explode(' ', $datetime);

		list($hour, $minute, $second) = explode(':', $time);

		list($year, $month, $day) = explode('-', $date);

		$timestamp = mktime($hour, $minute, $second, $month, $day, $year);

		return $timestamp;

	}



	/**

	 * Fonction de conversion de date du format américain (AAAA-MM-JJ) en Timestamp.

	 * @param string $date Date au format américain (AAAA-MM-JJ)

	 * @return integer Timestamp en seconde

	 */

	public static function dateToTime($date)

	{

		list($year, $month, $day) = explode('-', $date);

		$timestamp = mktime(0, 0, 0, $month, $day, $year);

		return $timestamp;

	}



	/**

	 * Supprime un dossier et son contenu

	 * @param Sting $path_folder Chemin du dossier à supprimer

	 * @param Bool $maintain_folder Si vrai, ne supprime pas le dossier mais que son contenu

	 * @return Bool resultat

	 */

	public static function deleteFolder($path_folder, $maintain_folder = false)

	{

		// ajout du slash a la fin du chemin s'il n'y est pas

		if( !preg_match( "/^.*\/$/", $path_folder ) ) $path_folder .= '/';



		// Ouverture du repertoire demande

		$handle = @opendir( $path_folder );



		// si pas d'erreur d'ouverture du dossier on lance le scan

		if( $handle != false )

		{



			// Parcours du repertoire

			while (false !== ($item = readdir($handle)))

			{

				if($item != "." && $item != "..")

				{

					if( is_dir( $path_folder.$item ) )

					self::deleteFolder( $path_folder.$item );

					else unlink( $path_folder.$item );

				}

			}



			// Fermeture du repertoire

			closedir($handle);

			

			if(!$maintain_folder)

			{

				// suppression du repertoire

				$res = rmdir( $path_folder );

			}

			else

			{

				$res = true;

			}



		}

		else $res = false;



		return $res;



	}

	

	

	/**

	 * Methode qui retourne l'url de referer a renvoyer apres la connexion

	 * sur le portail

	 * @return String url

	 */

	public static function getRefererConnection()

	{

		//On recupere l'instance

		$instance = sfContext::getInstance();

		

		//Si l'on vient d'une requette en POST, le referer de connexion

		//est la page d'accueil

		if($instance->getRequest()->getMethod() == sfRequest::POST)

		{

			return url_for('@homepage');

		}

		

		//On creer une liste noire d'actions pour lesquelles on ne doit pas rediriger

		//vers elle mais vers la page d'acceuil

		$liste_noire = array('main/oubliMotPasse', 

							 'membres/confirmChangementEmail', 

							 'membres/confirmEmail',

							 'main/confirmInscription');

		//On recupere l'action en cours

		$action = $instance->getModuleName().'/'.$instance->getActionName();

		if(in_array($action, $liste_noire))

		{

			return url_for('@homepage');

		}

		

		//Sinon on retourne l'url de REFERER

		return $_SERVER["REQUEST_URI"];

	}

	

	/**

	 * Retourne le pattern pour une expression rationnelle

	 * pour tester la validité d'une adresse mail

	 * @return String

	 */

	public static function getRegexMail()

	{

		return '/^(?:(?:(?:(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?(?:[a-zA-Z0-9!#\$%&\'\*\+\-\/=\?\^_`\{\}\|~]+(\.[a-zA-Z0-9!#\$%&\'\*\+\-\/=\?\^_`\{\}\|~]+)*)+(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?)|(?:(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?"((?:(?:[ \t]*(?:\r\n))?[ \t])?(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21\x23-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])))*(?:(?:[ \t]*(?:\r\n))?[ \t])?"(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?))@(?:(?:(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?(?:[a-zA-Z0-9!#\$%&\'\*\+\-\/=\?\^_`\{\}\|~]+(\.[a-zA-Z0-9!#\$%&\'\*\+\-\/=\?\^_`\{\}\|~]+)*)+(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?)|(?:(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?\[((?:(?:[ \t]*(?:\r\n))?[ \t])?(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x5A\x5E-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])))*?(?:(?:[ \t]*(?:\r\n))?[ \t])?\](?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))*(?:(?:(?:(?:[ \t]*(?:\r\n))?[ \t])?(\((?:(?:(?:[ \t]*(?:\r\n))?[ \t])|(?:(?:[\x01-\x08\x0B\x0C\x0E-\x19\x7F]|[\x21-\x27\x2A-\x5B\x5D-\x7E])|(?:\\[\x00-\x08\x0B\x0C\x0E-\x7F])|(?1)))*(?:(?:[ \t]*(?:\r\n))?[ \t])?\)))|(?:(?:[ \t]*(?:\r\n))?[ \t])))?)))$/D';

	}

	

	

	/**

	 * Retourne le chemin d'un JS dynmaique

	 * @param String $name_js Nom du JS dynamique

	 * @param String $application Nom de l'application

	 * @return String

	 */

	public static function getDynamiqueJsPath($name_js, $application = null)

	{

		if(is_null($application))

		{

			$application = sfContext::getInstance()->getConfiguration()->getApplication();

		}

		

		$environement = sfConfig::get('sf_environment');

		if($application == 'frontend' && $environement != 'dev')

		{

			$controller = '';

		}

		else

		{

			$controller = '/'.$application;

			if($environement == 'dev')

			{

				$controller .= '_dev';

			}

			$controller .= '.php';

		}

		

		return $controller.'/djs/'.$name_js;

	}



}

?>