<?php

/**

 * This class has been auto-generated by the Doctrine ORM Framework

 */

class EvenementTable extends Doctrine_Table

{

	

	/**

	 * Trouve l'evenement avec l'id donné. Jointure faite avec toutes les tables necessaires

	 * à l'affichage de l'evenement (Type, Lieu, Membre)

	 * @param Int $id Id recherché

	 * @return Evenement Evenement trouvé

	 */

	public function findJoinZoom($id)

	{

		$q = Doctrine::getTable('Evenement')->createQuery('e')

		->where('e.id = ?', $id);

		

		//Jointure avec le type

		$q->innerJoin('e.Type t');

		

		//Jointure avec le lieu

		$q->innerJoin('e.Lieu l');

		

		//Jointure avec le membre

		$q->innerJoin('e.Membre m');

		

		return $q->fetchOne();

	}

	

	

	/**

	 * Creer le pager en fonction des données sauvegardées en session

	 * @param String $nom_session Nom de la session

	 * @param Bool $display_one_day Si VRAI, affiche uniquement une journee, sinon les 30 prochains

	 * @param String $date: Si $display_one_day est VRAI, on affiche cette date. Format aaaa-mm-dd

	 * @return sfDoctrinePager pager

	 */

	public static function generatePager($nom_session, $diplay_one_day, $date)

	{

		$max_results = sfConfig::get('app_agenda_nbre_elements_liste');

		$pager = new sfDoctrinePager('Evenement', $max_results);

		$query = $pager->getQuery();

		$query->innerJoin('Evenement.Lieu l'); //Jointure avec le lieu

		$query->addwhere('Evenement.active = 1');

		

		//On recupere uniquement les champs que l'on souhaite

		$query->select('Evenement.id, Evenement.titre, Evenement.date_debut, Evenement.date_fin, Evenement.image_1, Evenement.image_1_truncate, l.nom');

		

		if($diplay_one_day)

		{

			//On affiche les evenements que d'une seule journee, on l'ajoute dans la requette

			$query->addwhere('Evenement.date_debut <= ? AND ? <= Evenement.date_fin', array($date, $date));

			

		}

		else

		{

			//On affiche les evenements des 30 prochains jours

			$now = date('Y-m-d', time());

			$date_end = date('Y-m-d', time() + 3600 * 24 * 30);

			$query->addWhere('(? <= Evenement.date_debut AND Evenement.date_debut <= ?) OR (? <= Evenement.date_fin AND Evenement.date_fin <= ?) OR (? > Evenement.date_debut AND Evenement.date_fin > ?)', array($now, $date_end, $now, $date_end, $now, $date_end));

		}

		

		$user = sfContext::getInstance()->getUser();



		//On gere le champ "categorie"

		$categorie = $user->getAttribute($nom_session.'_categorie', 0);

		if($categorie != 0)

		{

			//Categorie = 0: Afficher tout. Autre: Categorie specifiee

			$query->addWhere('Evenement.type_id = ?', array($categorie));

		}





		//On gère l'ordre d'affichage

		$ordre =  $user->getAttribute($nom_session.'_ordre', 0);

		if($ordre == 0)

		{

			//Tri croissant

			$ordre = 'ASC';

		}

		else

		{

			//Tri décroissant

			$ordre = 'DESC';

		}



		//On gere le champ 'tri'

		$tri = $user->getAttribute($nom_session.'_tri', 0);

		if($tri == 1)

		{

			//Tri par lieu

			$query->orderBy('l.nom '.$ordre);

		}

		elseif($tri == 2)

		{

			//Tri par auteur

			$query->orderBy('m.pseudo '.$ordre);

		}

		elseif($tri == 3)

		{

			//Tri par titre

			$query->orderBy('Evenement.titre '.$ordre);

		}

		elseif($tri == 4)

		{

			//Tri par date

			$query->orderBy('Evenement.date_debut '.$ordre);

		}

		else

		{

			//Tri par défault

			$query->orderBy('Evenement.date_debut '.$ordre);

		}





		//Gestion du nombre de pages à afficher

		$max_default = sfConfig::get('app_agenda_nbre_elements_liste');

		$nombre_pages = $user->getAttribute($nom_session.'_nombre_pages', $max_default);

		if($nombre_pages == '12' || $nombre_pages == '24' || $nombre_pages == '64')

		{

			//Nombre de pages valide, on change. Si pas valide, on laisse par défault la valeur du pager

			//donné dans le contructeur

			$pager->setMaxPerPage($nombre_pages);

		}



		//On modifie la requete du pager

		$pager->setQuery($query);

		return $pager;

	}

	

	

	

	

	

	/**

	 * Fonction qui retourne les evenements à afficher sur la page d'accueil.

	 * @return Array

	 */

	public static function getEvenementsIndex()

	{

		$query = Doctrine::getTable('Evenement')->createQuery('e');

		

		//Uniquement les evenements actifs

		$query->where('e.active = 1');

		

		//Uniquement les evenements actifs sur la page d'index

		$query->addWhere('e.active_index = 1');

		

		//Uniquement les evenements non déroulés

		$today= date('Y-m-d', time());

		$query->addWhere('e.date_fin >= ?', $today);

		

		//On précise l'odre

		$query->orderBy('e.date_debut ASC');

		

		//On fait les jointures

		$query->innerJoin('e.Lieu l');

				

		//On récupère uniquement les champs qui nous interessent

		$query->select('e.id, e.titre, e.date_debut, e.date_fin, e.image_1, e.image_1_truncate, l.nom');

		

		//Nombre maxis d'élements

		$max_elements = sfConfig::get('app_annuaire_nbre_elements_index', 10);

		$query->limit($max_elements);

		

		return $query->execute();

		

	}

	

	

	/**

	 * Retourne la liste des evenements non actifs,

	 * pour afficher sur le back-office

	 * @return Array

	 */

	public function getEvenementsNonActifsBo()

	{

		$q = $this->createQuery('e')

		->where('e.active = 0')

		->innerJoin('e.Type t')

		->innerJoin('e.Lieu l')

		->orderby('e.id DESC');

		

		//On recupere uniquement les champs que l'on souhaite

		$q->select('e.titre, e.id, e.active, e.active_index, e.date_debut, e.date_fin, l.nom, t.nom');

		$q->orderBy('e.date_debut DESC');

		return $q->execute();

	}

	

	

	/**

	 * Methode qui genere le pager pour le back-office

	 * @return sfDoctrinePager pager

	 */

	public static function generatePagerBo()

	{

		$max_results = sfConfig::get('app_agenda_nbre_elements_liste');

		$pager = new sfDoctrinePager('Evenement', $max_results);

		$query = $pager->getQuery();

		$query->innerJoin('Evenement.Type t'); //Jointure avec le type d'evenement

		$query->innerJoin('Evenement.Lieu l'); //Jointure avec le lieu

		$query->addwhere('Evenement.active = 1');

		$query->orderby('Evenement.date_debut DESC');

		

		//On recupere uniquement les champs que l'on souhaite

		$query->select('Evenement.titre, Evenement.id, Evenement.active, Evenement.active_index, Evenement.date_debut, Evenement.date_fin, l.nom, t.nom');

		

		//On modifie la requete du pager

		$pager->setQuery($query);

		return $pager;

	}

	

	

	/**

	 * Retourne les evenements qui peuvent être utilises pour l'envoi de

	 * newsletter

	 * @return Array

	 */

	public function getEvenementsNewsLetter()

	{

		$today= date('Y-m-d', time());

				

		$query = $this->createQuery('e')

		->innerJoin('e.Lieu l')

		->where('e.active = 1')

		->addWhere('e.date_fin >= ?', $today)

		->orderBy('e.date_debut ASC')

		->limit(50);

		

		return $query->execute();

	}

}