<?php

/**

 * This class has been auto-generated by the Doctrine ORM Framework

 */

class LieuTable extends Doctrine_Table

{

	/**

	 * Retourne la requete permettant d'afficher les lieux sur la page d'index

	 * @return Doctrine_Query

	 */

	public function getLieuxIndexQuery()

	{

		return $this->createQuery('l')

		->leftJoin('l.Type t')

		->select('l.id, l.nom, t.nom, image_1, image_2')

		->addWhere('l.active = 1 and active_index = 1')

		->orderBy('l.nom ASC')

		->limit('6');

	}

	

	

	/**

	 * Creer la requette en fonction des données sauvegardées en session

	 * @param String $nom_session Nom de la session

	 * @param sfDoctrinePager $pager Pager d'entrée

	 * @param Boolean $filterCategories 

	 * @return sfDoctrinePager pager modife

	 */

	public static function generatePager($nom_session, $pager, $filterCategories = false)

	{

		$user = sfContext::getInstance()->getUser();

		$query = $pager->getQuery();

		if($filterCategories)

		{

			//Notre liste de bon plan est une liste sur les bars & clubs ou divers. Dans le filtre

			//de recherche, il y a donc le champ 'categorie'. On le traite alors ici.

			$categorie = $user->getAttribute($nom_session.'_categorie', 0);

			if($categorie != 0)

			{

				//Categorie = 0: Afficher tout. Autre: Categorie specifiee

				$query->addWhere('Lieu.type_id = ?', array($categorie));

			}

		}

		

		//On gère l'ordre d'affichage

		$ordre =  $user->getAttribute($nom_session.'_ordre', 0);

		if($ordre == 0)

		{

			//Tri croissant

			$ordre = 'ASC';

		}

		else

		{

			//Tri décroissant

			$ordre = 'DESC';

		}

		

		//On gere le champ 'tri'

		$tri = $user->getAttribute($nom_session.'_tri', 0);

		if($tri == 1)

		{

			//Tri par nom

			$query->orderBy('Lieu.nom '.$ordre);

		}

		elseif($tri == 2)

		{

			//Tri par ville

			$query->orderBy('Lieu.ville '.$ordre);

		}

		elseif($tri == 3)

		{

			//Tri par date d'ajout

			$query->orderBy('Lieu.id '.$ordre);

		}

		else

		{

			//Tri par défault

			$query->orderBy('Lieu.nom '.$ordre);

		}

		

		

		//Gestion du nombre de pages à afficher

		$max_default = sfConfig::get('app_annuaire_nbre_elements_liste');

		$nombre_pages = $user->getAttribute($nom_session.'_nombre_pages', $max_default);

		if($nombre_pages == '12' || $nombre_pages == '24' || $nombre_pages == '64')

		{

			//Nombre de pages valide, on change. Si pas valide, on laisse par défault la valeur du pager

			//donné dans le contructeur

			$pager->setMaxPerPage($nombre_pages);

		}

		

		//On modifie la requete du pager

		$pager->setQuery($query);

		return $pager;

	}

	

	

	/**

	 * Retourne la liste des lieux non actifs,

	 * pour afficher sur le back-office

	 * @return Array

	 */

	public function getLieuxNonActifsBo()

	{

		$q = $this->createQuery('l')

		->where('l.active = 0')

		->innerJoin('l.Type t')

		->orderby('l.nom ASC');

		return $q->execute();

	}

	

	

	/**

	 * Methode qui genere le pager pour le back-office

	 * @return sfDoctrinePager pager

	 */

	public static function generatePagerBo()

	{

		$max_results = sfConfig::get('app_lieux_nbre_elements_liste');

		$pager = new sfDoctrinePager('Lieu', $max_results);

		$query = $pager->getQuery();

		$query->innerJoin('Lieu.Type t'); //Jointure avec le type d'evenement

		$query->addwhere('Lieu.active = 1');

		

		//On recupere uniquement les champs que l'on souhaite

		$query->select('Lieu.nom, Lieu.id, Lieu.active, Lieu.active_index, Lieu.nom, Lieu.code_postal, Lieu.ville, t.nom');

		

		$query->orderBy('Lieu.nom ASC');

		

		//On modifie la requete du pager

		$pager->setQuery($query);

		return $pager;

	}

	

	

	

	/**

	 * Retourne un lieu en fonction de l'id passé. Jointure faite

	 * avec la table type

	 * @param Int $id		ID du lieu recherché

	 * @return Lieu			Lieu trouvé

	 */

	public function findJoinType($id)

	{

		$q = Doctrine::getTable('Lieu')->createQuery('l')

		->leftJoin('l.Type t')

		->where('l.id = ?', $id);

		

		return $q->fetchOne();

	}

	

	/**

	 * Retourne un lieu en fonction de l'id passé. Jointure faite

	 * avec toutes les tables necessaire pour l'affichage

	 * @param Int $id		ID du lieu recherché

	 * @return Lieu			Lieu trouvé

	 */

	public function findJoinAllDisplay($id)

	{

		$q = Doctrine::getTable('Lieu')->createQuery('l')

		->leftJoin('l.Type t')

		->leftJoin('l.LieuGalerieMedias gm')

		->leftJoin('l.LieuStaffMedias s')

		->leftJoin('l.LieuMetierMedias m')

		->leftJoin('l.LieuVideos v')

		->where('l.id = ?', $id);

		

		return $q->fetchOne();

	}

}