<?php



/**

 * This class has been auto-generated by the Doctrine ORM Framework

 */

class Membre extends BaseMembre

{

	const HOMME = 1;

	const FEMME = 2;



	public function __toString()

	{

		return $this->getPseudo();

	}

	

	public function setMotPasse($str)

	{

		//Si le mot de passe est nul ou vide, on le change pas.

		//Protection utilisé lorsque l'on modifie son profil

		if(!is_null($str) && $str != '')

		{

			$this->_set('mot_passe_crypte', Chiffrement::cryptage($str));

			$this->_set('mot_passe', md5($str));

		}

	}





	/**

	 * Retourne vrai si la personne courrante est ami de la personne donnée (le membre courant est

	 * dans la liste d'ami de $membre)

	 * @param Membre $membre

	 * @return Bool

	 */

	public function estAmi($membre)

	{

		$query = Doctrine::getTable('MembreAmis')->createQuery()

		->where('membre_id = ?', $membre->getId())

		->addWhere('ami_membre_id = ?', $this->getId());



		if(count($query->execute()) > 0)

		{

			return true;

		}

		return false;

	}

	

/**

	 * Retourne vrai si la personne courrante a pour ami de la personne donnée ($membre est dans la liste

	 * d'ami du membre courant)

	 * @param Membre $membre

	 * @return Bool

	 */

	public function aPourAmi($membre)

	{

		$query = Doctrine::getTable('MembreAmis')->createQuery()

		->where('membre_id = ?', $this->getId())

		->addWhere('ami_membre_id = ?', $membre->getId());



		if(count($query->execute()) > 0)

		{

			return true;

		}

		return false;

	}





	/**

	 * Retourne la requete pour trouver la liste des amis avec les infos sur ceux-ci

	 * @return Doctrine_Query

	 */

	public function getListeAmisQuery()

	{

		$query = Doctrine::getTable('Membre')->createQuery('m')

		->innerJoin('m.Amis a ON (a.membre_id = ? and m.id = a.ami_membre_id)', $this->getId());

		return $query;

	}



	/**

	 * Retourne la requete pour trouver la liste des membres (avec les infos sur ceux-ci) dont la personne

	 * est ami avec

	 * @return Doctrine_Query

	 */

	public function getListeEstAmiQuery()

	{

		$query = Doctrine::getTable('Membre')->createQuery('m')

		->innerJoin('m.EstAmi a ON (a.ami_membre_id = ? and m.id = a.membre_id)', $this->getId());

		return $query;

	}



	/**

	 * Retourne la liste des images favorites de la personne, avec la jointure sur les dossiers

	 * correspondants

	 * @return Array ReportageFavorites

	 */

	public function getListeImagesFavorites()

	{

		$query = Doctrine::getTable('ReportageMedia')->createQuery('m')

		->innerJoin('m.ReportagesFavoris f ON (f.membre_id = ? and m.id = f.reportage_media_id)', $this->getId())

		->innerJoin('m.Reportage r');

		return $query->execute();

	}





	/**

	 * Retourne un tableau contenant tous les id des images favorites de la personne

	 * @return Array

	 */

	public function getTableImagesFavorites()

	{

		$query = Doctrine::getTable('ReportageFavori')->createQuery('f')

		->select('f.reportage_media_id')

		->where('f.membre_id = ?', $this->getId());



		$results = $query->fetchArray();

		$table = array();

		foreach($results as $result)

		{

			$table[] = $result['reportage_media_id'];

		}

		return $table;

	}





	/**

	 * Fonction qui retourne l'image de profil à afficher

	 * @return unknown_type

	 */

	public function getFichierImageProfil()

	{

		$image_profil = $this->getImageProfil();

		if(!empty($image_profil))

		{

			return $this->getImageProfil();

		}

		else

		{

			if($this->getSexe() == 1)

			{

				return '0homme.jpg';

			}

			else

			{

				return '0femme.jpg';

			}

		}

	}

	/**

	 * fonction qui retourne le signe du zodiaque du membre

	 * @return string retourne le signe astrologique de la date de naissance du membre

	 */

	public function getSigneAstrologique(){



		$date_naissance=$this->getDateNaissance();



		$timestamp=Util::dateToTime($date_naissance);



		$jour=date("d",$timestamp);

		$mois=date("m",$timestamp);



		$signe=ecSignePersonnalite::getSigneAstrologique($jour,$mois);



		return $signe;



	}



	/**

	 * fonction qui retourne le signe chinois du membre

	 * @return string retourne le signe chinois de la date de naissance du membre

	 */

	public function getSigneChinois(){



		$date_naissance=$this->getDateNaissance();



		$timestamp=Util::dateToTime($date_naissance);



		$jour=date("d",$timestamp);

		$mois=date("m",$timestamp);

		$annee=date("Y",$timestamp);



		$signe=ecSignePersonnalite::getSigneChinois($jour,$mois,$annee);



		return $signe;



	}



	/**

	 * Retourne la liste des messages de la boite de reception de la personne

	 * avec les jointures sur l'expediteur

	 * @return Array Message

	 */

	public function getBoiteReception()

	{

		$query = Doctrine::getTable('Message')->createQuery('m')

		->innerJoin('m.ExpediteurMembre e ON (m.destinataire_membre_id = ? and m.expediteur_membre_id = e.id)', $this->getId())

		->orderBy('m.created_at DESC');

		return $query->execute();

	}

	

	/**

	 * retourne la liste des messages du livre d'or du membre avec la jointure sur le posteur

	 * @return Array Message

	 */

	public function getGuestbooksRecusJoinPosteurMembre()

	{	

		$q = Doctrine_Query::create()

		->from('MembreGuestbook mg');

		$q->addWhere('mg.membre_id = ?', $this->getId());

		$q->innerJoin('mg.PosteurMembre m');

		$q->orderBy('mg.created_at DESC');

		

		return $q->execute();

	}

	













}