<?php

/**

 * This class has been auto-generated by the Doctrine ORM Framework

 */

class ReportageTable extends Doctrine_Table

{

	/**

	 * Retrouve un objet Reportage en fonction de son id

	 * Jointure avec les tables evenement (si précisé) lieu et membre

	 * @param Int $id id du reportage recherche

	 * @return Reportage

	 */

	public function findReportageJoinAll($id)

	{

		$q = Doctrine::getTable('Reportage')->createQuery('r')

		->where('r.id = ?', $id);

		

		//Jointure avec la table lieu

		$q->innerJoin('r.Lieu l');

		

		//Jointure avec le type de lieu

		$q->innerJoin('l.Type t');

		

		//Jointure avec la table membre

		$q->innerJoin('r.Reporters m');

		

		//Jointure avec la table evenement, si precise

		$q->leftJoin('r.Evenement e');

		

		return $q->fetchOne();

	}

	

	

	/**

	 * Cree la meme requete que "Doctrine::getTable('Reportage')->createQuery()", sauf que rajoute les 

	 * colonnes suivantes dans les objets Reportage retournes:

	 * image1 du reportage (colonne image_1), image2 du reportage (colonne image_2), nombre de commentaires sur 

	 * le reportage (colonne nombre_commentaires), nombre de medias (colonne nombre_medias).

	 * Pour acceder à ces nouvelles colonnes, il suffira de faire $reportage->getImage_1() par exemple.

	 * @return Doctrine_Query

	 */

	public function createQueryWithPersonalizedColumns()

	{

		$q = Doctrine::getTable('Reportage')->createQuery('r')



		->addselect('r.*')

		->addselect('(SELECT m1.nom_fichier FROM ReportageMedia m1 WHERE m1.reportage_id = r.id and m1.is_video = 0 ORDER BY m1.id ASC LIMIT 1) as image_1')

		->addselect('(SELECT m2.nom_fichier FROM ReportageMedia m2 WHERE m2.reportage_id = r.id and m2.is_video = 0 ORDER BY m2.id ASC LIMIT 1 OFFSET 1) as image_2')

		->addselect('(SELECT count(c1.id) FROM ReportageComment c1 INNER JOIN c1.ReportageMedia m3 WHERE m3.reportage_id = r.id) as nombre_commentaires')

		->addselect('(SELECT count(m4.id) FROM ReportageMedia m4 WHERE m4.reportage_id = r.id) as nombre_medias');

		

		return $q;

	}

	

	

	/**

	 * Cree le pager en fonction des données sauvegardées en session

	 * @param String $nom_session Nom de la session

	 * @param Bool $is_video: Si $is_video est VRAI, affiche uniquement les reportages videos. Sinon affiche

	 * uniquement les reportages photos

	 * @return sfDoctrinePager pager

	 */

	public function generatePager($nom_session, $is_video)

	{

		$max_results = sfConfig::get('app_reportages_nbre_elements_liste');

		$pager = new ecPager($max_results);

		$query = $this->createQueryWithPersonalizedColumns();

		$query->innerJoin('r.Lieu l'); //Jointure avec le lieu

		$query->innerJoin('l.Type t'); //Jointure avec le type de lieu

		//$query->innerJoin('r.Reporters m'); //Jointure avec les auteurs  //Desactive

		$query->addwhere('r.active = 1');

		

		$query->addSelect('l.id, l.type_id, l.nom');

		//$query->addSelect('m.*'); //Desactive

		$query->addSelect('t.*');

		

		//Requete pour recuperer le nombre de resultats (pour augmenter la rapidié du pager car

		//les colonnes du createQueryWithPersonalizedColumns sont longues sur toute la table

		$query_nb_results = Doctrine::getTable('Reportage')->createQuery('r');

		$query_nb_results->innerJoin('r.Lieu l'); //Jointure avec le lieu

		$query_nb_results->innerJoin('l.Type t'); //Jointure avec le type de lieu

		//$query_nb_results->innerJoin('r.Reporters m'); //Jointure avec les auteurs  --- Desactive

		$query_nb_results->addwhere('r.active = 1');

			

		if($is_video)

		{

			//Afiche uniquement les reportages video

			$query->addWhere('r.is_reportage_video = 1');

			$query_nb_results->addWhere('r.is_reportage_video = 1');

		}

		else

		{

			//Affiche uniquement les reportages photos

			$query->addWhere('r.is_reportage_video = 0');

			$query_nb_results->addWhere('r.is_reportage_video = 0');

		}

		

		$user = sfContext::getInstance()->getUser();



		//On gere le champ "categorie"

		$categorie = $user->getAttribute($nom_session.'_categorie', 0);

		if($categorie != 0)

		{

			//Categorie = 0: Afficher tout. Autre: Categorie specifiee

			$query->addWhere('t.id = ?', array($categorie));

			$query_nb_results->addWhere('t.id = ?', array($categorie));

		}





		//On gère l'ordre d'affichage

		$ordre =  $user->getAttribute($nom_session.'_ordre', 1);

		if($ordre == 0)

		{

			//Tri croissant

			$ordre = 'ASC';

		}

		else

		{

			//Tri décroissant

			$ordre = 'DESC';

		}



		//On gere le champ 'tri'

		$tri = $user->getAttribute($nom_session.'_tri', 0);

		if($tri == 1)

		{

			//Tri par lieu

			$query->orderBy('l.nom '.$ordre);

		}

		elseif($tri == 2)

		{

			//Tri par date

			$query->orderBy('r.date '.$ordre);

		}

		else

		{

			//Tri par défault

			$query->orderBy('r.date '.$ordre);

		}





		//Gestion du nombre de pages à afficher

		$max_default = sfConfig::get('app_reportages_nbre_elements_liste');

		$nombre_pages = $user->getAttribute($nom_session.'_nombre_pages', $max_default);

		if($nombre_pages == '12' || $nombre_pages == '24' || $nombre_pages == '64')

		{

			//Nombre de pages valide, on change. Si pas valide, on laisse par défault la valeur du pager

			//donné dans le contructeur

			$pager->setMaxPerPage($nombre_pages);

		}



		//On modifie la requete du pager

		$pager->setQuery($query);

		$pager->setTotalResults($query_nb_results->count());

		return $pager;

	}

	

	

	

	/**

	 * Fonction qui retourne les reportages à afficher sur la page d'accueil.

	 * @return Array

	 */

	public function getReportagesIndex()

	{

		$query = $this->createQueryWithPersonalizedColumns();

		

		//Uniquement les evenements actifs

		$query->addWhere('r.active = 1');

		

		//Uniquement les evenements actifs sur la page index

		$query->addWhere('r.active_index = 1');

		

		//On précise l'odre de tri

		$query->addOrderBy('r.date DESC');

		

		//Jointures

		$query->innerJoin('r.Lieu l'); //Jointure avec le lieu

		

		$query->addSelect('l.id, l.nom');

		

		//Nombre maxis d'élements

		$max_elements = sfConfig::get('app_reportages_nbre_elements_index', 10);

		$query->limit($max_elements);

		

		return $query->execute();

	}

	

	

	

	

	/**

	 * Retourne la liste des reportages non actifs,

	 * pour afficher sur le back-office

	 * @return Array

	 */

	public function getReportagesNonActifsBo()

	{

		$q = $this->createQuery('r')

		->where('r.active = 0')

		->innerJoin('r.Lieu l')

		->orderby('r.id DESC');

		

		//On recupere uniquement les champs que l'on souhaite

		$q->select('r.titre, r.id, r.active, r.active_index, r.date, r.is_reportage_video, l.nom');

		return $q->execute();

	}

	

	

	/**

	 * Methode qui genere le pager pour le back-office

	 * @return sfDoctrinePager pager

	 */

	public static function generatePagerBo()

	{

		$max_results = sfConfig::get('app_reportages_nbre_elements_liste');

		$pager = new sfDoctrinePager('Reportage', $max_results);

		$query = $pager->getQuery();

		$query->innerJoin('Reportage.Lieu l'); //Jointure avec le lieu

		$query->addwhere('Reportage.active = 1');

		$query->orderby('Reportage.id DESC');

		

		//On recupere uniquement les champs que l'on souhaite

		$query->select('Reportage.titre, Reportage.id, Reportage.active, Reportage.active_index, Reportage.date, Reportage.is_reportage_video, l.nom');

		

		//On modifie la requete du pager

		$pager->setQuery($query);

		return $pager;

	}

	

}