<?php





class VideoTable extends Doctrine_Table

{

    
    public static function getInstance()
    {
        return Doctrine_Core::getTable('Video');
    }

    

	/**

	 * Retrouve un objet Video en fonction de son id

	 * Jointure avec la table video_categorie

	 * @param Int $id id de la video recherche

	 * @return Video

	 */

	public function findVideoJoinAll($id)

	{

		$q = Doctrine::getTable('Video')->createQuery('v')

		->where('v.id = ?', $id);

		

		//Jointure avec la table video_categorie

		$q->innerJoin('v.VideoCategorie c');		

		

		return $q->fetchOne();

	}

	

	

	/**

	 * Cree le pager en fonction des données sauvegardées en session

	 * @param String $nom_session Nom de la session

	 * @return sfDoctrinePager pager

	 */

	public function generatePager($nom_session)

	{

		$max_results = sfConfig::get('app_videos_nbre_elements_liste');

		$pager = new ecPager($max_results);

		$query = Doctrine::getTable('Video')->createQuery('v');

		$query->innerJoin('v.VideoCategorie c'); //Jointure avec la categorie

		$query->addwhere('v.active = 1');

		

		$query->addSelect('c.*');

		$query->addSelect('v.*');

		

		$user = sfContext::getInstance()->getUser();



		//On gere le champ "categorie"

		$categorie = $user->getAttribute($nom_session.'_categorie', 0);

		if($categorie != 0)

		{

			//Categorie = 0: Afficher tout. Autre: Categorie specifiee

			$query->addWhere('c.id = ?', array($categorie));

		}





		//On gère l'ordre d'affichage

		$ordre =  $user->getAttribute($nom_session.'_ordre', 1);

		if($ordre == 0)

		{

			//Tri croissant

			$ordre = 'ASC';

		}

		else

		{

			//Tri décroissant

			$ordre = 'DESC';

		}



		//On gere le champ 'tri'

		$tri = $user->getAttribute($nom_session.'_tri', 0);

		if($tri == 1)

		{

			//Tri par titre

			$query->orderBy('v.titre '.$ordre);

		}

		elseif($tri == 2)

		{

			//Tri par date

			$query->orderBy('v.created_at '.$ordre);

		}

		else

		{

			//Tri par défault

			$query->orderBy('v.created_at '.$ordre);

		}





		//Gestion du nombre de pages à afficher

		$max_default = sfConfig::get('app_videos_nbre_elements_liste');

		$nombre_pages = $user->getAttribute($nom_session.'_nombre_pages', $max_default);

		if($nombre_pages == '12' || $nombre_pages == '24' || $nombre_pages == '64')

		{

			//Nombre de pages valide, on change. Si pas valide, on laisse par défault la valeur du pager

			//donné dans le contructeur

			$pager->setMaxPerPage($nombre_pages);

		}



		//On modifie la requete du pager

		$pager->setQuery($query);

		return $pager;

	}

	

	

	

	/**

	 * Retourne la liste des videos non actives,

	 * pour afficher sur le back-office

	 * @return Array

	 */

	public function getVideosNonActivesBo()

	{

		$q = $this->createQuery('v')

		->where('v.active = 0')

		->innerJoin('v.VideoCategorie c')

		->orderby('v.id DESC');



		return $q->execute();

	}





	/**

	 * Methode qui genere le pager pour le back-office

	 * @return sfDoctrinePager pager

	 */

	public static function generatePagerBo()

	{

		$max_results = sfConfig::get('app_videos_nbre_elements_liste');

		$pager = new sfDoctrinePager('Video', $max_results);

		$query = $pager->getQuery();

		$query->innerJoin('Video.VideoCategorie c'); //Jointure avec la categorie

		$query->addwhere('Video.active = 1');

		$query->orderby('Video.id DESC');



		//On modifie la requete du pager

		$pager->setQuery($query);

		return $pager;

	}

}