<?php

class myUser extends sfBasicSecurityUser
{
	/**
	 * Provoque une tentative de connexion
	 * @param String $login Login
	 * @param String $password Mot de passe en MD5
	 * @return bool True ou false en fonction du résultat
	 */
	public function Login($login, $password)
	{
		
		//On regarde si le pseudo existe ou non
		if(is_null($login) || is_null($password))
		{
			return false;
		}
		$membre = Doctrine::getTable('Membre')->findOneByPseudo($login);
		if(!$membre)
		{
			return false;
		}
		
		//On regarde si la personne a bien son compte actif
		if(!$membre->getConfirmation())
		{
			return false;
		}
		
		//On vérifie que le mot de passe est correct
		if($membre->getMotPasse() == $password)
		{
			//Mot de passe correct, on connecte la personne
			$this->setAuthenticated(true);
			
			//On sauvegarde l'Id et le pseudo de la personne en session
			$this->setAttribute('MembreId', $membre->getId());
			$this->setAttribute('MembrePseudo', $membre->getPseudo());
			
			//On affecte les droits à l'utilisateur
			$this->AffecteDroits($membre);
		
			//On change la dernière requête de l'utilisateur
			$dateFormat = new sfDateFormat();
			$now = $dateFormat->format(time(), 'I');
			$membre->setDerniereRequete($now);
			$membre->save();
			
			//On supprime le cache de la liste de connectes
			$this->EmptyCacheUsersConnected();
			
			//on appelle la fonction qui verifie si l'adresse mail est validée et envoi un mail si non
			$this->verificationMail();
			
			//on appelle la fonction qui compte le nombre de messages non lus
			$this->CheckMessagerie();
			
			return true;
		}
		else
		{
			//Mot de passe incorrect
			return false;
		}
		
		
		
	}
	
	
	/**
	 * Méthode qui affecte des droits à un utilisateur
	 * @param Membre $membre
	 * @return unknown_type
	 */
	public function AffecteDroits($membre)
	{
		if($membre->getLevelId() == Level::LEVEL_ADMIN)
		{
			$this->addCredential('ADMIN');
		}
		elseif($membre->getLevelId() == Level::LEVEL_REPORTER)
		{
			$this->addCredential('REPORTER');
		}
		elseif($membre->getLevelId() == Level::LEVEL_MANAGER)
		{
			$this->addCredential('MANAGER');
		}
		elseif($membre->getLevelId() == Level::LEVEL_EXPO)
		{
			$this->addCredential('EXPO');
		}
		elseif($membre->getLevelId() == Level::LEVEL_PUBLICITE)
		{
			$this->addCredential('PUBLICITE');
		}
		elseif($membre->getLevelId() == Level::LEVEL_BONNES_ADRESSES)
		{
				$this->addCredential('BONNES_ADRESSES');
		}
		elseif($membre->getLevelId() == Level::LEVEL_REPORTER_EX)
		{
			$this->addCredential('REPORTER_EX');
		}
		elseif($membre->getLevelId() == Level::LEVEL_STAFF)
		{
			$this->addCredential('STAFF');
		}
		else
		{
			$this->addCredential('UTILISATEUR');
		}
	}
	
	
	//Méthode qui déconnecte la personne
	public function LogOut()
	{
		$this->setAttribute('MembreId', null);
		$this->setAttribute('MembrePseudo', null);
		$this->clearCredentials();
		$this->setAuthenticated(false);
		
		//On désactive la connexion auto
		$cookie_name = sfConfig::get('app_remember_me_cookie_name');
		$response = sfContext::getInstance()->getResponse();
		$response->setCookie($cookie_name, null);
	}
	
	/**
	 * fonction qui verifie si l'adresse mail du membre qui se connecte est bien validée.
	 * si non, envi d'un mail pour validation
	 * @return unknown_type
	 */
	private function verificationMail()
	{
	
		//on recupere l'id du membre et l'objet du membre
		$membre_id = MembreTable::getMembreIdConnecte();
		$membre = MembreTable::getMembreConnecte();
		
		//on cherche dans la table "membre" si le champ "notification_newsletter" est a 1
		$notification_newsletter=$membre->getNotificationNewsletter();
		
		
		if($notification_newsletter==='1')
		{
			$membre->setNotificationNewsletter('0');
			
			//on verifie dans la table "newsletter_abonnement" que le membre ne soit pas deja abonné
			$newsletter=Doctrine::getTable('NewsletterAbonnement')->findOneByMembreId($membre_id);
			//si on a un enregistrement dans la table "newsletter_abonnement" qui correspond au membre connecté
			if(is_object($newsletter))
			{
				//on test si la valeur de active est 1 (le membre est deja abonné)
				$newsletter_abonne=$newsletter->getActive();
				if($newsletter_abonne=='1')
				{
					//le membre est déjà abonné, son email est donc verifié, on ne fait rien
					
				}else //sinon, si le membre n'est pas encore abonné
				{
					//on l'abonne
					$newsletter->setActive('1');
					$newsletter->save();	
				
				}
			}
			else //si il n'y a pas encore d'enregistrement dans la table "newsletter_abonnement"
			{
				//On se positionne dans une action pour pouvoir appeler un parial (partial
				//utilise pour l'envoi de mail
				$action = sfContext::getInstance()->getController()->getAction('main', 'index');
		
				//On creer le code de confirmation
				$code = md5(rand(0, 99999).time().'anbnws');
				
				//on recupere le membre connecté dans la table membre pour y enregistrer le nouveau code de confirmation
				$membre->setConfirmationCode($code);
				
				
				//On prepare le mail de confirmation à la personne
				$expediteur = sfConfig::get('app_email_expediteur', 'contact@annecybynight.com');
				$destinataire = $membre->getEmail();
				$sujet = sfConfig::get('app_email_sujet_confirmation_email', 'Confirmation adresse e-mail');
				$lien_confirmation = 'membres/confirmEmail?id='.$membre_id.'&cle='.$code.'&origine=1';
				$mailBody = $action->getPartial('mailConfirmation', array('lien_confirmation' => $lien_confirmation,
																				  				 'pseudo' => $membre->getPseudo()));
	
				// On cree le mail
				$message = Swift_Message::newInstance()
				->setFrom($expediteur)
				->setTo($destinataire)
				->setSubject($sujet)
				->setBody($mailBody, 'text/html');
		
				// On envoie le mail
				sfContext::getInstance()->getMailer()->send($message);
				
			}
			//on enregistre les modifications apportées a l'objet membre
			$membre->save();
		}
	
	}


	/**
	 * Fonction qui vide le cache du cadre des personnes connectees
	 */
	public function EmptyCacheUsersConnected()
	{
		$cacheManager = sfContext::getInstance()->getViewCacheManager();
	 	$cacheManager->remove('@sf_cache_partial?module=main&action=_stats&sf_cache_key=*','*');
	}
	
	

	/**
	 * fonction qui compte le nombre de messages non lus du membre et qui stock ce nombre dans une variable de
	 * session
	 * @return unknown_type
	 */
	public function CheckMessagerie()
	{
		//on recupere l'id du membre connecté
		$membre_id = MembreTable::getMembreIdConnecte();
		
		//on créer la requete qui recupere le nombre de messages recus, non lus
		$nbre_messages_non_lus = Doctrine::getTable('Message')->createQuery()
			->select('Message.id')
			->where('Message.destinataire_membre_id = ?', $membre_id)
			->addWhere('Message.lu = ?', '0')
			->count();
	
		$this->setAttribute('nbre_messages_non_lus', $nbre_messages_non_lus);
	}
	

}
