<?php

/**

 * This file is part of "AnnecyByNight"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Widget de date, utilisant JqueryUI

 *

 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: ecWidgetFormDateRich.php 70 2009-07-15 11:52:03Z hlecorche $

 */



class ecWidgetFormDateRich extends sfWidgetForm

{

	/**

	 * Configures the current widget.

	 *

	 * Available options:

	 *

	 *  * date_format_input:     	Date d'entrée, sous forme d'expression reguliere (celle qui est stockée en BDD)

	 *  							(@(?P<day>\d{2}).(?P<month>\d{2}).(?P<year>\d{4})@ par defaut)

	 *  * date_format_output_jq	    Format de date (Format JQUERY) de sortie, qui doit etre affichee (dd/mm/yy par defaut)

	 *  * date_format_output_php    Format de date (Format PHP) de sortie, qui doit etre affichee (d/m/Y by par defaut)

	 *  * showOn				    Détermine comment doit apparaite la date ('focus' 'button' ou 'both' par defaut: button)

	 *  * buttonImage				Image du bouton (null par defaut)

	 *  * dayNames					Tableau qui contient les jours de la semaine complets (à partir du dimanche)

	 *  * dayNamesMin				Idem mais noms minimums

	 *  * dayNamesShort				Idem mais taille moyenne

	 *  * monthNames				Tableau qui contient les mois complet (à partir du dimanche)

	 *  * monthNamesShort			Idem mais taille moyenne

	 *  * firstDay					Numéro du premier jour de la semaine (0: Dimanche - Par defaut: 1 - Lundi)

	 *  * options_jquery		    Options supplementaires Jquery du datepiker (sous forme d'un tableau).

	 *  

	 *

	 * @param array $options     An array of options

	 * @param array $attributes  An array of default HTML attributes

	 *

	 * @see sfWidgetForm

	 */

	protected function configure($options = array(), $attributes = array())

	{

		$this->addOption('date_format_input', '@(?P<year>\d{4}).(?P<month>\d{2}).(?P<day>\d{2})@');

		$this->addOption('date_format_output_jq', 'dd/mm/yy');

		$this->addOption('date_format_output_php', 'd/m/Y');

		$this->addOption('showOn', 'button');

		$this->addOption('buttonImage', null);

		$this->addOption('dayNames', "['Dimanche', 'Lundi', 'Mardi', 'Mercredi', 'Jeudi', 'Vendredi', 'Samedi', 'Dimanche']");

		$this->addOption('dayNamesMin', "['Di', 'Lu', 'Ma', 'Me', 'Je', 'Ve', 'Sa', 'Di']");

		$this->addOption('dayNamesShort', "['Dim', 'Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam', 'Dim']");

		$this->addOption('monthNames', "['Janvier', 'Février', 'Mars', 'Avril', 'Mai', 'Juin', 'Juillet', 'Août', 'Septembre', 'Octobre', 'Novembre', 'Décembre']");

		$this->addOption('monthNamesShort', "['Jan', 'Feb', 'Mar', 'Avr', 'Mai', 'Jui', 'Juil', 'Aou', 'Sep', 'Oct', 'Nov', 'Dec']");

		$this->addOption('firstDay', 1);

		$this->addOption('options_jquery', array());



	}

	

	/**

	 * @param  string $name        The element name

	 * @param  string $value       The date displayed in this widget

	 * @param  array  $attributes  An array of HTML attributes to be merged with the default HTML attributes

	 * @param  array  $errors      An array of errors for the field

	 *

	 * @return string An HTML tag string

	 *

	 * @see sfWidgetForm

	 */

	public function render($name, $value = null, $attributes = array(), $errors = array())

	{

		//On ajoute les fichiers necessaires

		require_once(dirname(__FILE__).'/../../plugins/sfJqueryReloadedPlugin/lib/helper/jQueryHelper.php');

		jq_add_plugin();

		jq_add_plugin_ui();

		

		if(count($errors) > 0)

		{

			//Il y a des erreurs sur le champ, on affiche donc notre valeur fausse

			$value_str = $value;

		}

		else

		{

			// On convertie la date (donnée par $value) en tableau

			if (preg_match($this->getOption('date_format_input'), $value, $matches))

			{

				$value = $matches;

				$value_str = date($this->getOption('date_format_output_php'), mktime(0, 0, 0, $value['month'], $value['day'], $value['year']));

			}

			else

			{

				//Impossible à parser la date, on affiche la valeur brute

				//Ne pas changer cela car: Si jamais un formulaire contient 2 champs: Un champ texte et apres

				//ce widget: Si la presonne rentre une date (et correcte), mais que le 1er champ renvoie une

				//erreur, le validateur de la date ne sera pas apelé, et donc la date ne sera pas transformee,

				//donc quand on repassera dans cette fonction, la date ne sera pas parsee.

				//Or il faut que la personne retrouve sa date (qui est peut etre correcte)

				$value_str = $value;

			}

			

		}

		

		

		//On recupere l'ID de notre input

		$id = $this->generateId($name);

		

		//On ajoute les options du Picker

		$options_jquery = '{ ';

		$options_jquery .= 'dateFormat: \''.$this->getOption('date_format_output_jq').'\' ';

		$liste_options = $this->getOption('options_jquery');

		

		if(!is_null($this->getOption('showOn')))

		{

			$liste_options['showOn'] = "'".$this->getOption('showOn')."'";

		}

		if(!is_null($this->getOption('buttonImage')))

		{

			$liste_options['buttonImage'] = "'".$this->getOption('buttonImage')."'";

			$liste_options['buttonImageOnly'] = 'true';

		}

		if(!is_null($this->getOption('dayNames')))

		{

			$liste_options['dayNames'] = $this->getOption('dayNames');

		}

		if(!is_null($this->getOption('dayNamesMin')))

		{

			$liste_options['dayNamesMin'] = $this->getOption('dayNamesMin');

		}

		if(!is_null($this->getOption('dayNamesShort')))

		{

			$liste_options['dayNamesShort'] = $this->getOption('dayNamesShort');

		}

		if(!is_null($this->getOption('monthNames')))

		{

			$liste_options['monthNames'] = $this->getOption('monthNames');

		}

		if(!is_null($this->getOption('monthNamesShort')))

		{

			$liste_options['monthNamesShort'] = $this->getOption('monthNamesShort');

		}

		if(!is_null($this->getOption('firstDay')))

		{

			$liste_options['firstDay'] = $this->getOption('firstDay');

		}

		

		foreach($liste_options as $cle => $op)

		{

			$options_jquery .= ', '.$cle.': '.$op.' ';

		}

		$options_jquery .= '}';

		

		//On cree le code JS pour notre date

		$javascript = '<script type="text/javascript">

						$(function() {

						$("#'.$id.'").datepicker('.$options_jquery.');

						});

					</script>';

						

		

		

		//On ajoute les options au INPUT

		$options = array_merge(array('type' => 'text', 'name' => $name, 'value' => $value_str), $attributes);

		

		return $this->renderTag('input', $options).$javascript;

	}

}

?>