<?php

/**

 * This file is part of "anbnws"

 * Copyright (c) 2009-2010 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Widget qui ajoute un editeur de texte riche (RTE)

 *

 * Liste des options / plugins à consulter sur :

 * http://wiki.moxiecode.com/index.php/TinyMCE:Index

 *

 * @author    Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: ecWidgetFormTextareaTinyMCE.class.php 450 2010-09-30 07:54:08Z hlecorche $

 */





class ecWidgetFormTextareaTinyMCE extends sfWidgetFormTextarea

{

	/**

	 *

	 * Options disponibles

	 *  * sript_url: Chemin vers le fichier JS de TinyMCE

	 *  * jquery_script_url: Chemin vers le plugin TinyMCE de Jquery

	 *  * theme:  Theme TinyMCE

	 *  * width:  Largeur

	 *  * height: Hauteur

	 *  * language: Langue

	 *  * active_plugins: Plugings activés

	 *  * buttons1: Boutons de la ligne 1

	 *  * buttons2: Boutons de la ligne 2

	 *  * buttons3: Boutons de la ligne 3

	 *  * config: Autres options TinyMCE, sous forme de chaine de caractères

	 *

	 * @param array $options     An array of options

	 * @param array $attributes  An array of default HTML attributes

	 *

	 * @see sfWidgetForm

	 */

	protected function configure($options = array(), $attributes = array())

	{

		$this->addOption('script_url', '/jQuery/js/plugins/tiny_mce/tiny_mce.js');

		$this->addOption('jquery_script_url', '/jQuery/js/plugins/tiny_mce/jquery.tinymce.js');

		$this->addOption('theme', 'advanced');

		$this->addOption('width');

		$this->addOption('height');

		$this->addOption('language', 'fr');

		$this->addOption('active_plugins', 'safari,style,table,advlink,emotions,iespell,inlinepopups,insertdatetime,preview,media,searchreplace,print,contextmenu,paste,directionality,fullscreen,noneditable,visualchars,nonbreaking,xhtmlxtras,template,pagebreak');

		$this->addOption('buttons1', 'newdocument,|,cut,copy,paste,pastetext,pasteword,|,search,replace,|,undo,redo,|,bullist,numlist,|,outdent,indent,|,print,fullscreen,preview');

		$this->addOption('buttons2', 'fontselect,fontsizeselect,|,bold,italic,underline,strikethrough,|,justifyleft,justifycenter,justifyright,justifyfull,|,forecolor,backcolor');

		$this->addOption('buttons3', 'tablecontrols,|,hr,visualaid,|,sub,sup,|,charmap,iespell,advhr,|,link,unlink');

		$this->addOption('config', '');

	}





	/**

	 * @param  string $name        The element name

	 * @param  string $value       The value selected in this widget

	 * @param  array  $attributes  An array of HTML attributes to be merged with the default HTML attributes

	 * @param  array  $errors      An array of errors for the field

	 *

	 * @return string An HTML tag string

	 *

	 * @see sfWidgetForm

	 */

	public function render($name, $value = null, $attributes = array(), $errors = array())

	{

	

		//Ajout le JS (ATTENTION, pas propre, normalement ne pas le faire et utiliser use_js_form dans 

		//le template

		foreach($this->getJavascripts() as $js)

		{

			use_javascript($js);

		}

		

		$textarea = parent::render($name, $value, $attributes, $errors);

		

		$js = sprintf(<<<EOF

<script type="text/javascript">

	$().ready(function() {

	  $('#%s').tinymce({

	  	script_url : '%s',

	    theme:                             "%s",

	    %s

	    %s

	    %s

	    %s

	    %s

	    %s

	    %s

	    relative_urls:					false,

	    theme_advanced_toolbar_location:   "top",

	    theme_advanced_toolbar_align:      "left",

	    theme_advanced_statusbar_location: "bottom",

	    theme_advanced_resizing:           true,

	    doctype : '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">'

	    %s

	  });

	});

</script>

EOF

		,

		$this->generateId($name),

		$this->getOption('script_url'),

		$this->getOption('theme'),

		$this->getOption('language')  ? sprintf('language:                             "%s",', $this->getOption('language')) : '',

		$this->getOption('active_plugins')  ? sprintf('plugins:                             "%s",', $this->getOption('active_plugins')) : '',

		$this->getOption('buttons1')  ? sprintf('theme_advanced_buttons1:                             "%s",', $this->getOption('buttons1')) : '',

		$this->getOption('buttons2')  ? sprintf('theme_advanced_buttons2:                             "%s",', $this->getOption('buttons2')) : '',

		$this->getOption('buttons3')  ? sprintf('theme_advanced_buttons3:                             "%s",', $this->getOption('buttons3')) : '',

		$this->getOption('width')  ? sprintf('width:                             "%s",', $this->getOption('width')) : '',

		$this->getOption('height') ? sprintf('height:                            "%s",', $this->getOption('height')) : '',

		$this->getOption('config') ? ",\n".$this->getOption('config') : ''

		);



		return $textarea.$js;

	}

	

	/**

	* Gets the JavaScript paths associated with the widget.

	*

	* @return array An array of JavaScript paths

	*/

	public function getJavascripts()

	{

    	return array(sfConfig::get('sf_jquery_web_dir').'/js/'.sfConfig::get('sf_jquery_core'),

				 		$this->getOption('jquery_script_url'));

  	

  	}

}

?>