<?php

/**

 * This file is part of "AnnecyByNight"

 * Copyright (c) 2009 Hubert LECORCHE

 *

 * For the full copyright and license information, please view the LICENSE

 * file that was distributed with this source code.

 */





/**

 * Batch qui envoie la newsletter

 *

 * @author   Hubert LECORCHE <hlecorche@e-commit.fr>

 * @version    SVN: $Id: batch_newsletter.php 448 2010-09-29 13:58:35Z hlecorche $

 */



ini_set("memory_limit" , "60M");

set_time_limit(0);

//On récupère l'application 'Backend'

require_once(dirname(__FILE__).'/../../config/ProjectConfiguration.class.php');

$configuration = ProjectConfiguration::getApplicationConfiguration('backend', 'prod', false);



//On creer une instance

$instance=sfContext::createInstance($configuration);



//On recupere la BDD associee a cette instance

$database_manager = $instance->getDatabaseManager();



//On regarde si une newsletter est en cours d'envoi (presence d'une ligne dans table newsletter_contenu

//avec "envoye" à 0 et avec "brouillon" à 0)

$newsletter_contenu = Doctrine::getTable('NewsletterContenu')->createQuery('c')

->where('c.envoye = 0')->addWhere('c.brouillon = 0')

->fetchOne();



if(is_object($newsletter_contenu))

{

	//On regarde si une newsletter a été envoyee dernierement, dans les delais

	$dernier_envoi = Doctrine::getTable('NewsletterEtat')->createQuery('e')

	->orderBy('e.created_at DESC')

	->limit(1)

	->fetchOne();



	//Temps limite que doit avoir le dernier enregistrement, en respectant les délais

	//avec une tollerance de 10s.

	$temps_limite = time() - intval(sfConfig::get('app_newsletter_delai_entre_paquets')) + 10;

	

	if(is_object($dernier_envoi) && Util::datetimeToTime($dernier_envoi->getCreatedAt()) > $temps_limite)

	{

		//Le dernier envoi est trop proche, on n'envoie pas maintenant

		exit();

	}

	



	//On regarde si on n'a pas trop envoye de mails dans la dernière heures

	$temps_limite = date('Y-m-d H:i:s', time() - 3600);

	$nombre_envois_derniere_heure = Doctrine::getTable('NewsletterEtat')->createQuery('e')

	->where('e.created_at >= ?', $temps_limite)

	->count();

	

	$nombre_maxi_envois = ceil(intval(sfConfig::get('app_newsletter_limite_heure')) / intval(sfConfig::get('app_newsletter_nombre_par_paquets')));

		

	if($nombre_envois_derniere_heure > $nombre_maxi_envois)

	{

		//On a trop envoye de mails dans la derniere heure, on n'envoie pas maintenant

		exit();

	}

	

	//On envoie les mails

	

	//On recupere les adresses à envoyer (qui n'ont pas encore recu la newletter)

	//et on leur envoie

	$liste_abonnes = Doctrine::getTable('NewsletterAbonnement')->createQuery('a')

	->where('active = 1')

	->addWhere('chariot = 0')

	->limit(intval(sfConfig::get('app_newsletter_nombre_par_paquets')))

	->execute();



	if(count($liste_abonnes) > 0)

	{

		//Il y a encore des mails à envoyer, on le fait

		

		$expediteur = sfConfig::get('app_newsletter_expediteur', 'contact@annecybynight.com');

		$sujet = sfConfig::get('app_email_sujet_newsletter', 'Newsletter AnnecyByNight');

		$mailBody = $newsletter_contenu->getTexte();

		foreach($liste_abonnes as $abonne)

		{

			$destinataire =  $abonne->getEmail();

			$message = Swift_Message::newInstance()

			->setFrom($expediteur)

			->setTo($destinataire)

			->setSubject($sujet)

			->setBody($mailBody, 'text/html');

			sfContext::getInstance()->getMailer()->send($message);

			

			//On change le chariot de l'abonne (car mail envoye)

			$abonne->setChariot(1);

			$abonne->save();

			

		}

		

		//On ajoute dans l'historique, un envoie effectue

		$historique = new NewsletterEtat();

		$historique->save();

	}

	else

	{

		//Il n'y a plus de newsletter à envoyer, on cloture alors la newsletter

		//en modifiant newsletter_contenu (envoye = 1)

		$newsletter_contenu->setEnvoye(1);

		$newsletter_contenu->save();

	}

	

	

}

?>



